Module: Google::Ads::GoogleAds::Factories::V20::Operations::RemoveResource

Defined in:
lib/google/ads/google_ads/factories/v20/operations.rb

Class Method Summary collapse

Class Method Details

.account_budget_proposal(path) ⇒ Object

A convenience method for creating an AccountBudgetProposalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5276
5277
5278
5279
5280
5281
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5276

def self.(path)
  require "google/ads/google_ads/v20/services/account_budget_proposal_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AccountBudgetProposalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an AccountLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5287
5288
5289
5290
5291
5292
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5287

def self.(path)
  require "google/ads/google_ads/v20/services/account_link_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AccountLinkOperation.new
  op["remove"] = path
  op
end

.ad(path) ⇒ Object

A convenience method for creating an AdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5430
5431
5432
5433
5434
5435
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5430

def self.ad(path)
  require "google/ads/google_ads/v20/services/ad_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdOperation.new
  op["remove"] = path
  op
end

.ad_group(path) ⇒ Object

A convenience method for creating an AdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5408
5409
5410
5411
5412
5413
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5408

def self.ad_group(path)
  require "google/ads/google_ads/v20/services/ad_group_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupOperation.new
  op["remove"] = path
  op
end

.ad_group_ad(path) ⇒ Object

A convenience method for creating an AdGroupAdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5309
5310
5311
5312
5313
5314
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5309

def self.ad_group_ad(path)
  require "google/ads/google_ads/v20/services/ad_group_ad_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupAdOperation.new
  op["remove"] = path
  op
end

.ad_group_ad_label(path) ⇒ Object

A convenience method for creating an AdGroupAdLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5298
5299
5300
5301
5302
5303
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5298

def self.ad_group_ad_label(path)
  require "google/ads/google_ads/v20/services/ad_group_ad_label_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupAdLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_asset(path) ⇒ Object

A convenience method for creating an AdGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5320
5321
5322
5323
5324
5325
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5320

def self.ad_group_asset(path)
  require "google/ads/google_ads/v20/services/ad_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupAssetOperation.new
  op["remove"] = path
  op
end

.ad_group_asset_set(path) ⇒ Object

A convenience method for creating an AdGroupAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5331
5332
5333
5334
5335
5336
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5331

def self.ad_group_asset_set(path)
  require "google/ads/google_ads/v20/services/ad_group_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupAssetSetOperation.new
  op["remove"] = path
  op
end

.ad_group_bid_modifier(path) ⇒ Object

A convenience method for creating an AdGroupBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5342
5343
5344
5345
5346
5347
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5342

def self.ad_group_bid_modifier(path)
  require "google/ads/google_ads/v20/services/ad_group_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupBidModifierOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion(path) ⇒ Object

A convenience method for creating an AdGroupCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5375
5376
5377
5378
5379
5380
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5375

def self.ad_group_criterion(path)
  require "google/ads/google_ads/v20/services/ad_group_criterion_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupCriterionOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCriterionCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5353
5354
5355
5356
5357
5358
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5353

def self.ad_group_criterion_customizer(path)
  require "google/ads/google_ads/v20/services/ad_group_criterion_customizer_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupCriterionCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_label(path) ⇒ Object

A convenience method for creating an AdGroupCriterionLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5364
5365
5366
5367
5368
5369
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5364

def self.ad_group_criterion_label(path)
  require "google/ads/google_ads/v20/services/ad_group_criterion_label_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupCriterionLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5386
5387
5388
5389
5390
5391
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5386

def self.ad_group_customizer(path)
  require "google/ads/google_ads/v20/services/ad_group_customizer_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_label(path) ⇒ Object

A convenience method for creating an AdGroupLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5397
5398
5399
5400
5401
5402
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5397

def self.ad_group_label(path)
  require "google/ads/google_ads/v20/services/ad_group_label_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdGroupLabelOperation.new
  op["remove"] = path
  op
end

.ad_parameter(path) ⇒ Object

A convenience method for creating an AdParameterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5419
5420
5421
5422
5423
5424
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5419

def self.ad_parameter(path)
  require "google/ads/google_ads/v20/services/ad_parameter_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AdParameterOperation.new
  op["remove"] = path
  op
end

.apply_recommendation(path) ⇒ Object

A convenience method for creating an ApplyRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6156
6157
6158
6159
6160
6161
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6156

def self.apply_recommendation(path)
  require "google/ads/google_ads/v20/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::ApplyRecommendationOperation.new
  op["remove"] = path
  op
end

.asset(path) ⇒ Object

A convenience method for creating an AssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5485
5486
5487
5488
5489
5490
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5485

def self.asset(path)
  require "google/ads/google_ads/v20/services/asset_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AssetOperation.new
  op["remove"] = path
  op
end

.asset_group(path) ⇒ Object

A convenience method for creating an AssetGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5463
5464
5465
5466
5467
5468
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5463

def self.asset_group(path)
  require "google/ads/google_ads/v20/services/asset_group_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AssetGroupOperation.new
  op["remove"] = path
  op
end

.asset_group_asset(path) ⇒ Object

A convenience method for creating an AssetGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5441
5442
5443
5444
5445
5446
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5441

def self.asset_group_asset(path)
  require "google/ads/google_ads/v20/services/asset_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AssetGroupAssetOperation.new
  op["remove"] = path
  op
end

.asset_group_listing_group_filter(path) ⇒ Object

A convenience method for creating an AssetGroupListingGroupFilterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5452
5453
5454
5455
5456
5457
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5452

def self.asset_group_listing_group_filter(path)
  require "google/ads/google_ads/v20/services/asset_group_listing_group_filter_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AssetGroupListingGroupFilterOperation.new
  op["remove"] = path
  op
end

.asset_group_signal(path) ⇒ Object

A convenience method for creating an AssetGroupSignalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5474
5475
5476
5477
5478
5479
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5474

def self.asset_group_signal(path)
  require "google/ads/google_ads/v20/services/asset_group_signal_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AssetGroupSignalOperation.new
  op["remove"] = path
  op
end

.asset_set(path) ⇒ Object

A convenience method for creating an AssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5507
5508
5509
5510
5511
5512
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5507

def self.asset_set(path)
  require "google/ads/google_ads/v20/services/asset_set_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AssetSetOperation.new
  op["remove"] = path
  op
end

.asset_set_asset(path) ⇒ Object

A convenience method for creating an AssetSetAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5496
5497
5498
5499
5500
5501
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5496

def self.asset_set_asset(path)
  require "google/ads/google_ads/v20/services/asset_set_asset_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AssetSetAssetOperation.new
  op["remove"] = path
  op
end

.audience(path) ⇒ Object

A convenience method for creating an AudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5518
5519
5520
5521
5522
5523
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5518

def self.audience(path)
  require "google/ads/google_ads/v20/services/audience_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::AudienceOperation.new
  op["remove"] = path
  op
end

.batch_job(path) ⇒ Object

A convenience method for creating an BatchJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6013
6014
6015
6016
6017
6018
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6013

def self.batch_job(path)
  require "google/ads/google_ads/v20/services/batch_job_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::BatchJobOperation.new
  op["remove"] = path
  op
end

.bidding_data_exclusion(path) ⇒ Object

A convenience method for creating an BiddingDataExclusionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5529
5530
5531
5532
5533
5534
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5529

def self.bidding_data_exclusion(path)
  require "google/ads/google_ads/v20/services/bidding_data_exclusion_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::BiddingDataExclusionOperation.new
  op["remove"] = path
  op
end

.bidding_seasonality_adjustment(path) ⇒ Object

A convenience method for creating an BiddingSeasonalityAdjustmentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5540
5541
5542
5543
5544
5545
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5540

def self.bidding_seasonality_adjustment(path)
  require "google/ads/google_ads/v20/services/bidding_seasonality_adjustment_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::BiddingSeasonalityAdjustmentOperation.new
  op["remove"] = path
  op
end

.bidding_strategy(path) ⇒ Object

A convenience method for creating an BiddingStrategyOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5551
5552
5553
5554
5555
5556
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5551

def self.bidding_strategy(path)
  require "google/ads/google_ads/v20/services/bidding_strategy_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::BiddingStrategyOperation.new
  op["remove"] = path
  op
end

.billing_setup(path) ⇒ Object

A convenience method for creating an BillingSetupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6024
6025
6026
6027
6028
6029
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6024

def self.billing_setup(path)
  require "google/ads/google_ads/v20/services/billing_setup_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::BillingSetupOperation.new
  op["remove"] = path
  op
end

.campaign(path) ⇒ Object

A convenience method for creating an CampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5672
5673
5674
5675
5676
5677
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5672

def self.campaign(path)
  require "google/ads/google_ads/v20/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignOperation.new
  op["remove"] = path
  op
end

.campaign_asset(path) ⇒ Object

A convenience method for creating an CampaignAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5562
5563
5564
5565
5566
5567
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5562

def self.campaign_asset(path)
  require "google/ads/google_ads/v20/services/campaign_asset_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignAssetOperation.new
  op["remove"] = path
  op
end

.campaign_asset_set(path) ⇒ Object

A convenience method for creating an CampaignAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5573
5574
5575
5576
5577
5578
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5573

def self.campaign_asset_set(path)
  require "google/ads/google_ads/v20/services/campaign_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignAssetSetOperation.new
  op["remove"] = path
  op
end

.campaign_bid_modifier(path) ⇒ Object

A convenience method for creating an CampaignBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5584
5585
5586
5587
5588
5589
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5584

def self.campaign_bid_modifier(path)
  require "google/ads/google_ads/v20/services/campaign_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignBidModifierOperation.new
  op["remove"] = path
  op
end

.campaign_budget(path) ⇒ Object

A convenience method for creating an CampaignBudgetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5595
5596
5597
5598
5599
5600
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5595

def self.campaign_budget(path)
  require "google/ads/google_ads/v20/services/campaign_budget_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignBudgetOperation.new
  op["remove"] = path
  op
end

.campaign_conversion_goal(path) ⇒ Object

A convenience method for creating an CampaignConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5606
5607
5608
5609
5610
5611
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5606

def self.campaign_conversion_goal(path)
  require "google/ads/google_ads/v20/services/campaign_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignConversionGoalOperation.new
  op["remove"] = path
  op
end

.campaign_criterion(path) ⇒ Object

A convenience method for creating an CampaignCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5617
5618
5619
5620
5621
5622
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5617

def self.campaign_criterion(path)
  require "google/ads/google_ads/v20/services/campaign_criterion_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignCriterionOperation.new
  op["remove"] = path
  op
end

.campaign_customizer(path) ⇒ Object

A convenience method for creating an CampaignCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5628
5629
5630
5631
5632
5633
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5628

def self.campaign_customizer(path)
  require "google/ads/google_ads/v20/services/campaign_customizer_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignCustomizerOperation.new
  op["remove"] = path
  op
end

.campaign_draft(path) ⇒ Object

A convenience method for creating an CampaignDraftOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5639
5640
5641
5642
5643
5644
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5639

def self.campaign_draft(path)
  require "google/ads/google_ads/v20/services/campaign_draft_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignDraftOperation.new
  op["remove"] = path
  op
end

.campaign_group(path) ⇒ Object

A convenience method for creating an CampaignGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5650
5651
5652
5653
5654
5655
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5650

def self.campaign_group(path)
  require "google/ads/google_ads/v20/services/campaign_group_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignGroupOperation.new
  op["remove"] = path
  op
end

.campaign_label(path) ⇒ Object

A convenience method for creating an CampaignLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5661
5662
5663
5664
5665
5666
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5661

def self.campaign_label(path)
  require "google/ads/google_ads/v20/services/campaign_label_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignLabelOperation.new
  op["remove"] = path
  op
end

.campaign_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CampaignLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6035
6036
6037
6038
6039
6040
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6035

def self.campaign_lifecycle_goal(path)
  require "google/ads/google_ads/v20/services/campaign_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignLifecycleGoalOperation.new
  op["remove"] = path
  op
end

.campaign_shared_set(path) ⇒ Object

A convenience method for creating an CampaignSharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5694
5695
5696
5697
5698
5699
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5694

def self.campaign_shared_set(path)
  require "google/ads/google_ads/v20/services/campaign_shared_set_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CampaignSharedSetOperation.new
  op["remove"] = path
  op
end

.conversion_action(path) ⇒ Object

A convenience method for creating an ConversionActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5705
5706
5707
5708
5709
5710
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5705

def self.conversion_action(path)
  require "google/ads/google_ads/v20/services/conversion_action_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::ConversionActionOperation.new
  op["remove"] = path
  op
end

.conversion_custom_variable(path) ⇒ Object

A convenience method for creating an ConversionCustomVariableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5716
5717
5718
5719
5720
5721
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5716

def self.conversion_custom_variable(path)
  require "google/ads/google_ads/v20/services/conversion_custom_variable_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::ConversionCustomVariableOperation.new
  op["remove"] = path
  op
end

.conversion_goal_campaign_config(path) ⇒ Object

A convenience method for creating an ConversionGoalCampaignConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5727
5728
5729
5730
5731
5732
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5727

def self.conversion_goal_campaign_config(path)
  require "google/ads/google_ads/v20/services/conversion_goal_campaign_config_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::ConversionGoalCampaignConfigOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule(path) ⇒ Object

A convenience method for creating an ConversionValueRuleOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5738
5739
5740
5741
5742
5743
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5738

def self.conversion_value_rule(path)
  require "google/ads/google_ads/v20/services/conversion_value_rule_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::ConversionValueRuleOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule_set(path) ⇒ Object

A convenience method for creating an ConversionValueRuleSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5749
5750
5751
5752
5753
5754
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5749

def self.conversion_value_rule_set(path)
  require "google/ads/google_ads/v20/services/conversion_value_rule_set_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::ConversionValueRuleSetOperation.new
  op["remove"] = path
  op
end

.custom_audience(path) ⇒ Object

A convenience method for creating an CustomAudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6046
6047
6048
6049
6050
6051
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6046

def self.custom_audience(path)
  require "google/ads/google_ads/v20/services/custom_audience_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomAudienceOperation.new
  op["remove"] = path
  op
end

.custom_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5760
5761
5762
5763
5764
5765
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5760

def self.custom_conversion_goal(path)
  require "google/ads/google_ads/v20/services/custom_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomConversionGoalOperation.new
  op["remove"] = path
  op
end

.custom_interest(path) ⇒ Object

A convenience method for creating an CustomInterestOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6057
6058
6059
6060
6061
6062
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6057

def self.custom_interest(path)
  require "google/ads/google_ads/v20/services/custom_interest_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomInterestOperation.new
  op["remove"] = path
  op
end

.customer(path) ⇒ Object

A convenience method for creating an CustomerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5826
5827
5828
5829
5830
5831
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5826

def self.customer(path)
  require "google/ads/google_ads/v20/services/customer_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerOperation.new
  op["remove"] = path
  op
end

.customer_asset(path) ⇒ Object

A convenience method for creating an CustomerAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5771
5772
5773
5774
5775
5776
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5771

def self.customer_asset(path)
  require "google/ads/google_ads/v20/services/customer_asset_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerAssetOperation.new
  op["remove"] = path
  op
end

.customer_asset_set(path) ⇒ Object

A convenience method for creating an CustomerAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6068
6069
6070
6071
6072
6073
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6068

def self.customer_asset_set(path)
  require "google/ads/google_ads/v20/services/customer_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerAssetSetOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerClientLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6079
6080
6081
6082
6083
6084
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6079

def self.customer_client_link(path)
  require "google/ads/google_ads/v20/services/customer_client_link_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerClientLinkOperation.new
  op["remove"] = path
  op
end

.customer_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomerConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5782
5783
5784
5785
5786
5787
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5782

def self.customer_conversion_goal(path)
  require "google/ads/google_ads/v20/services/customer_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerConversionGoalOperation.new
  op["remove"] = path
  op
end

.customer_customizer(path) ⇒ Object

A convenience method for creating an CustomerCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5793
5794
5795
5796
5797
5798
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5793

def self.customer_customizer(path)
  require "google/ads/google_ads/v20/services/customer_customizer_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerCustomizerOperation.new
  op["remove"] = path
  op
end

.customer_label(path) ⇒ Object

A convenience method for creating an CustomerLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5804
5805
5806
5807
5808
5809
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5804

def self.customer_label(path)
  require "google/ads/google_ads/v20/services/customer_label_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerLabelOperation.new
  op["remove"] = path
  op
end

.customer_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CustomerLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6090
6091
6092
6093
6094
6095
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6090

def self.customer_lifecycle_goal(path)
  require "google/ads/google_ads/v20/services/customer_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerLifecycleGoalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerManagerLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6101
6102
6103
6104
6105
6106
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6101

def self.customer_manager_link(path)
  require "google/ads/google_ads/v20/services/customer_manager_link_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerManagerLinkOperation.new
  op["remove"] = path
  op
end

.customer_negative_criterion(path) ⇒ Object

A convenience method for creating an CustomerNegativeCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5815
5816
5817
5818
5819
5820
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5815

def self.customer_negative_criterion(path)
  require "google/ads/google_ads/v20/services/customer_negative_criterion_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerNegativeCriterionOperation.new
  op["remove"] = path
  op
end

.customer_sk_ad_network_conversion_value_schema(path) ⇒ Object

A convenience method for creating an CustomerSkAdNetworkConversionValueSchemaOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6112
6113
6114
6115
6116
6117
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6112

def self.customer_sk_ad_network_conversion_value_schema(path)
  require "google/ads/google_ads/v20/services/customer_sk_ad_network_conversion_value_schema_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerSkAdNetworkConversionValueSchemaOperation.new
  op["remove"] = path
  op
end

.customer_user_access(path) ⇒ Object

A convenience method for creating an CustomerUserAccessOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6134
6135
6136
6137
6138
6139
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6134

def self.customer_user_access(path)
  require "google/ads/google_ads/v20/services/customer_user_access_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerUserAccessOperation.new
  op["remove"] = path
  op
end

.customer_user_access_invitation(path) ⇒ Object

A convenience method for creating an CustomerUserAccessInvitationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6123
6124
6125
6126
6127
6128
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6123

def self.customer_user_access_invitation(path)
  require "google/ads/google_ads/v20/services/customer_user_access_invitation_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomerUserAccessInvitationOperation.new
  op["remove"] = path
  op
end

.customizer_attribute(path) ⇒ Object

A convenience method for creating an CustomizerAttributeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5837
5838
5839
5840
5841
5842
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5837

def self.customizer_attribute(path)
  require "google/ads/google_ads/v20/services/customizer_attribute_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::CustomizerAttributeOperation.new
  op["remove"] = path
  op
end

.dismiss_recommendation(path) ⇒ Object

A convenience method for creating an DismissRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6167
6168
6169
6170
6171
6172
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6167

def self.dismiss_recommendation(path)
  require "google/ads/google_ads/v20/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::DismissRecommendationRequest::DismissRecommendationOperation.new
  op["remove"] = path
  op
end

.enable(path) ⇒ Object

A convenience method for creating an EnableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5683
5684
5685
5686
5687
5688
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5683

def self.enable(path)
  require "google/ads/google_ads/v20/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::EnableOperation.new
  op["remove"] = path
  op
end

.experiment(path) ⇒ Object

A convenience method for creating an ExperimentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5859
5860
5861
5862
5863
5864
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5859

def self.experiment(path)
  require "google/ads/google_ads/v20/services/experiment_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::ExperimentOperation.new
  op["remove"] = path
  op
end

.experiment_arm(path) ⇒ Object

A convenience method for creating an ExperimentArmOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5848
5849
5850
5851
5852
5853
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5848

def self.experiment_arm(path)
  require "google/ads/google_ads/v20/services/experiment_arm_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::ExperimentArmOperation.new
  op["remove"] = path
  op
end

.keyword_plan(path) ⇒ Object

A convenience method for creating an KeywordPlanOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5914
5915
5916
5917
5918
5919
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5914

def self.keyword_plan(path)
  require "google/ads/google_ads/v20/services/keyword_plan_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::KeywordPlanOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5881
5882
5883
5884
5885
5886
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5881

def self.keyword_plan_ad_group(path)
  require "google/ads/google_ads/v20/services/keyword_plan_ad_group_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::KeywordPlanAdGroupOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5870
5871
5872
5873
5874
5875
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5870

def self.keyword_plan_ad_group_keyword(path)
  require "google/ads/google_ads/v20/services/keyword_plan_ad_group_keyword_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::KeywordPlanAdGroupKeywordOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5903
5904
5905
5906
5907
5908
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5903

def self.keyword_plan_campaign(path)
  require "google/ads/google_ads/v20/services/keyword_plan_campaign_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::KeywordPlanCampaignOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5892
5893
5894
5895
5896
5897
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5892

def self.keyword_plan_campaign_keyword(path)
  require "google/ads/google_ads/v20/services/keyword_plan_campaign_keyword_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::KeywordPlanCampaignKeywordOperation.new
  op["remove"] = path
  op
end

.label(path) ⇒ Object

A convenience method for creating an LabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5925
5926
5927
5928
5929
5930
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5925

def self.label(path)
  require "google/ads/google_ads/v20/services/label_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::LabelOperation.new
  op["remove"] = path
  op
end

.mutate(path) ⇒ Object

A convenience method for creating an MutateOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6002
6003
6004
6005
6006
6007
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6002

def self.mutate(path)
  require "google/ads/google_ads/v20/services/google_ads_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::MutateOperation.new
  op["remove"] = path
  op
end

.offline_user_data_job(path) ⇒ Object

A convenience method for creating an OfflineUserDataJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6145
6146
6147
6148
6149
6150
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6145

def self.offline_user_data_job(path)
  require "google/ads/google_ads/v20/services/offline_user_data_job_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::OfflineUserDataJobOperation.new
  op["remove"] = path
  op
end

.recommendation_subscription(path) ⇒ Object

A convenience method for creating an RecommendationSubscriptionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5936
5937
5938
5939
5940
5941
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5936

def self.recommendation_subscription(path)
  require "google/ads/google_ads/v20/services/recommendation_subscription_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::RecommendationSubscriptionOperation.new
  op["remove"] = path
  op
end

.remarketing_action(path) ⇒ Object

A convenience method for creating an RemarketingActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5947
5948
5949
5950
5951
5952
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5947

def self.remarketing_action(path)
  require "google/ads/google_ads/v20/services/remarketing_action_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::RemarketingActionOperation.new
  op["remove"] = path
  op
end

.shared_criterion(path) ⇒ Object

A convenience method for creating an SharedCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5958
5959
5960
5961
5962
5963
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5958

def self.shared_criterion(path)
  require "google/ads/google_ads/v20/services/shared_criterion_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::SharedCriterionOperation.new
  op["remove"] = path
  op
end

.shared_set(path) ⇒ Object

A convenience method for creating an SharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5969
5970
5971
5972
5973
5974
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5969

def self.shared_set(path)
  require "google/ads/google_ads/v20/services/shared_set_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::SharedSetOperation.new
  op["remove"] = path
  op
end

.smart_campaign_setting(path) ⇒ Object

A convenience method for creating an SmartCampaignSettingOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5980
5981
5982
5983
5984
5985
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5980

def self.smart_campaign_setting(path)
  require "google/ads/google_ads/v20/services/smart_campaign_setting_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::SmartCampaignSettingOperation.new
  op["remove"] = path
  op
end

.target_restriction(path) ⇒ Object

A convenience method for creating an TargetRestrictionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5265
5266
5267
5268
5269
5270
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5265

def self.target_restriction(path)
  require "google/ads/google_ads/v20/common/targeting_setting_pb"
  op = Google::Ads::GoogleAds::V20::Common::TargetRestrictionOperation.new
  op["remove"] = path
  op
end

.user_data(path) ⇒ Object

A convenience method for creating an UserDataOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6178
6179
6180
6181
6182
6183
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6178

def self.user_data(path)
  require "google/ads/google_ads/v20/services/user_data_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::UserDataOperation.new
  op["remove"] = path
  op
end

.user_list(path) ⇒ Object

A convenience method for creating an UserListOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5991
5992
5993
5994
5995
5996
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 5991

def self.user_list(path)
  require "google/ads/google_ads/v20/services/user_list_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::UserListOperation.new
  op["remove"] = path
  op
end

.user_list_customer_type(path) ⇒ Object

A convenience method for creating an UserListCustomerTypeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6189
6190
6191
6192
6193
6194
# File 'lib/google/ads/google_ads/factories/v20/operations.rb', line 6189

def self.user_list_customer_type(path)
  require "google/ads/google_ads/v20/services/user_list_customer_type_service_pb"
  op = Google::Ads::GoogleAds::V20::Services::UserListCustomerTypeOperation.new
  op["remove"] = path
  op
end