Module: Google::Ads::GoogleAds::Factories::V21::Operations::RemoveResource

Defined in:
lib/google/ads/google_ads/factories/v21/operations.rb

Class Method Summary collapse

Class Method Details

.account_budget_proposal(path) ⇒ Object

A convenience method for creating an AccountBudgetProposalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5304
5305
5306
5307
5308
5309
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5304

def self.(path)
  require "google/ads/google_ads/v21/services/account_budget_proposal_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AccountBudgetProposalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an AccountLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5315
5316
5317
5318
5319
5320
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5315

def self.(path)
  require "google/ads/google_ads/v21/services/account_link_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AccountLinkOperation.new
  op["remove"] = path
  op
end

.ad(path) ⇒ Object

A convenience method for creating an AdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5458
5459
5460
5461
5462
5463
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5458

def self.ad(path)
  require "google/ads/google_ads/v21/services/ad_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdOperation.new
  op["remove"] = path
  op
end

.ad_group(path) ⇒ Object

A convenience method for creating an AdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5436
5437
5438
5439
5440
5441
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5436

def self.ad_group(path)
  require "google/ads/google_ads/v21/services/ad_group_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupOperation.new
  op["remove"] = path
  op
end

.ad_group_ad(path) ⇒ Object

A convenience method for creating an AdGroupAdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5337
5338
5339
5340
5341
5342
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5337

def self.ad_group_ad(path)
  require "google/ads/google_ads/v21/services/ad_group_ad_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupAdOperation.new
  op["remove"] = path
  op
end

.ad_group_ad_label(path) ⇒ Object

A convenience method for creating an AdGroupAdLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5326
5327
5328
5329
5330
5331
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5326

def self.ad_group_ad_label(path)
  require "google/ads/google_ads/v21/services/ad_group_ad_label_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupAdLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_asset(path) ⇒ Object

A convenience method for creating an AdGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5348
5349
5350
5351
5352
5353
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5348

def self.ad_group_asset(path)
  require "google/ads/google_ads/v21/services/ad_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupAssetOperation.new
  op["remove"] = path
  op
end

.ad_group_asset_set(path) ⇒ Object

A convenience method for creating an AdGroupAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5359
5360
5361
5362
5363
5364
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5359

def self.ad_group_asset_set(path)
  require "google/ads/google_ads/v21/services/ad_group_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupAssetSetOperation.new
  op["remove"] = path
  op
end

.ad_group_bid_modifier(path) ⇒ Object

A convenience method for creating an AdGroupBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5370
5371
5372
5373
5374
5375
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5370

def self.ad_group_bid_modifier(path)
  require "google/ads/google_ads/v21/services/ad_group_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupBidModifierOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion(path) ⇒ Object

A convenience method for creating an AdGroupCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5403
5404
5405
5406
5407
5408
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5403

def self.ad_group_criterion(path)
  require "google/ads/google_ads/v21/services/ad_group_criterion_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupCriterionOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCriterionCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5381
5382
5383
5384
5385
5386
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5381

def self.ad_group_criterion_customizer(path)
  require "google/ads/google_ads/v21/services/ad_group_criterion_customizer_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupCriterionCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_label(path) ⇒ Object

A convenience method for creating an AdGroupCriterionLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5392
5393
5394
5395
5396
5397
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5392

def self.ad_group_criterion_label(path)
  require "google/ads/google_ads/v21/services/ad_group_criterion_label_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupCriterionLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5414
5415
5416
5417
5418
5419
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5414

def self.ad_group_customizer(path)
  require "google/ads/google_ads/v21/services/ad_group_customizer_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_label(path) ⇒ Object

A convenience method for creating an AdGroupLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5425
5426
5427
5428
5429
5430
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5425

def self.ad_group_label(path)
  require "google/ads/google_ads/v21/services/ad_group_label_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdGroupLabelOperation.new
  op["remove"] = path
  op
end

.ad_parameter(path) ⇒ Object

A convenience method for creating an AdParameterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5447
5448
5449
5450
5451
5452
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5447

def self.ad_parameter(path)
  require "google/ads/google_ads/v21/services/ad_parameter_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AdParameterOperation.new
  op["remove"] = path
  op
end

.apply_recommendation(path) ⇒ Object

A convenience method for creating an ApplyRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6206
6207
6208
6209
6210
6211
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6206

def self.apply_recommendation(path)
  require "google/ads/google_ads/v21/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ApplyRecommendationOperation.new
  op["remove"] = path
  op
end

.asset(path) ⇒ Object

A convenience method for creating an AssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5513
5514
5515
5516
5517
5518
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5513

def self.asset(path)
  require "google/ads/google_ads/v21/services/asset_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AssetOperation.new
  op["remove"] = path
  op
end

.asset_group(path) ⇒ Object

A convenience method for creating an AssetGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5491
5492
5493
5494
5495
5496
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5491

def self.asset_group(path)
  require "google/ads/google_ads/v21/services/asset_group_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AssetGroupOperation.new
  op["remove"] = path
  op
end

.asset_group_asset(path) ⇒ Object

A convenience method for creating an AssetGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5469
5470
5471
5472
5473
5474
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5469

def self.asset_group_asset(path)
  require "google/ads/google_ads/v21/services/asset_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AssetGroupAssetOperation.new
  op["remove"] = path
  op
end

.asset_group_listing_group_filter(path) ⇒ Object

A convenience method for creating an AssetGroupListingGroupFilterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5480
5481
5482
5483
5484
5485
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5480

def self.asset_group_listing_group_filter(path)
  require "google/ads/google_ads/v21/services/asset_group_listing_group_filter_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AssetGroupListingGroupFilterOperation.new
  op["remove"] = path
  op
end

.asset_group_signal(path) ⇒ Object

A convenience method for creating an AssetGroupSignalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5502
5503
5504
5505
5506
5507
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5502

def self.asset_group_signal(path)
  require "google/ads/google_ads/v21/services/asset_group_signal_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AssetGroupSignalOperation.new
  op["remove"] = path
  op
end

.asset_set(path) ⇒ Object

A convenience method for creating an AssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5535
5536
5537
5538
5539
5540
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5535

def self.asset_set(path)
  require "google/ads/google_ads/v21/services/asset_set_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AssetSetOperation.new
  op["remove"] = path
  op
end

.asset_set_asset(path) ⇒ Object

A convenience method for creating an AssetSetAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5524
5525
5526
5527
5528
5529
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5524

def self.asset_set_asset(path)
  require "google/ads/google_ads/v21/services/asset_set_asset_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AssetSetAssetOperation.new
  op["remove"] = path
  op
end

.audience(path) ⇒ Object

A convenience method for creating an AudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5546
5547
5548
5549
5550
5551
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5546

def self.audience(path)
  require "google/ads/google_ads/v21/services/audience_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::AudienceOperation.new
  op["remove"] = path
  op
end

.batch_job(path) ⇒ Object

A convenience method for creating an BatchJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6052
6053
6054
6055
6056
6057
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6052

def self.batch_job(path)
  require "google/ads/google_ads/v21/services/batch_job_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::BatchJobOperation.new
  op["remove"] = path
  op
end

.bidding_data_exclusion(path) ⇒ Object

A convenience method for creating an BiddingDataExclusionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5568
5569
5570
5571
5572
5573
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5568

def self.bidding_data_exclusion(path)
  require "google/ads/google_ads/v21/services/bidding_data_exclusion_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::BiddingDataExclusionOperation.new
  op["remove"] = path
  op
end

.bidding_seasonality_adjustment(path) ⇒ Object

A convenience method for creating an BiddingSeasonalityAdjustmentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5579
5580
5581
5582
5583
5584
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5579

def self.bidding_seasonality_adjustment(path)
  require "google/ads/google_ads/v21/services/bidding_seasonality_adjustment_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::BiddingSeasonalityAdjustmentOperation.new
  op["remove"] = path
  op
end

.bidding_strategy(path) ⇒ Object

A convenience method for creating an BiddingStrategyOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5590
5591
5592
5593
5594
5595
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5590

def self.bidding_strategy(path)
  require "google/ads/google_ads/v21/services/bidding_strategy_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::BiddingStrategyOperation.new
  op["remove"] = path
  op
end

.billing_setup(path) ⇒ Object

A convenience method for creating an BillingSetupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6063
6064
6065
6066
6067
6068
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6063

def self.billing_setup(path)
  require "google/ads/google_ads/v21/services/billing_setup_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::BillingSetupOperation.new
  op["remove"] = path
  op
end

.campaign(path) ⇒ Object

A convenience method for creating an CampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5711
5712
5713
5714
5715
5716
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5711

def self.campaign(path)
  require "google/ads/google_ads/v21/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignOperation.new
  op["remove"] = path
  op
end

.campaign_asset(path) ⇒ Object

A convenience method for creating an CampaignAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5601
5602
5603
5604
5605
5606
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5601

def self.campaign_asset(path)
  require "google/ads/google_ads/v21/services/campaign_asset_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignAssetOperation.new
  op["remove"] = path
  op
end

.campaign_asset_set(path) ⇒ Object

A convenience method for creating an CampaignAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5612
5613
5614
5615
5616
5617
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5612

def self.campaign_asset_set(path)
  require "google/ads/google_ads/v21/services/campaign_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignAssetSetOperation.new
  op["remove"] = path
  op
end

.campaign_bid_modifier(path) ⇒ Object

A convenience method for creating an CampaignBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5623
5624
5625
5626
5627
5628
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5623

def self.campaign_bid_modifier(path)
  require "google/ads/google_ads/v21/services/campaign_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignBidModifierOperation.new
  op["remove"] = path
  op
end

.campaign_budget(path) ⇒ Object

A convenience method for creating an CampaignBudgetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5634
5635
5636
5637
5638
5639
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5634

def self.campaign_budget(path)
  require "google/ads/google_ads/v21/services/campaign_budget_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignBudgetOperation.new
  op["remove"] = path
  op
end

.campaign_conversion_goal(path) ⇒ Object

A convenience method for creating an CampaignConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5645
5646
5647
5648
5649
5650
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5645

def self.campaign_conversion_goal(path)
  require "google/ads/google_ads/v21/services/campaign_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignConversionGoalOperation.new
  op["remove"] = path
  op
end

.campaign_criterion(path) ⇒ Object

A convenience method for creating an CampaignCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5656
5657
5658
5659
5660
5661
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5656

def self.campaign_criterion(path)
  require "google/ads/google_ads/v21/services/campaign_criterion_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignCriterionOperation.new
  op["remove"] = path
  op
end

.campaign_customizer(path) ⇒ Object

A convenience method for creating an CampaignCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5667
5668
5669
5670
5671
5672
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5667

def self.campaign_customizer(path)
  require "google/ads/google_ads/v21/services/campaign_customizer_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignCustomizerOperation.new
  op["remove"] = path
  op
end

.campaign_draft(path) ⇒ Object

A convenience method for creating an CampaignDraftOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5678
5679
5680
5681
5682
5683
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5678

def self.campaign_draft(path)
  require "google/ads/google_ads/v21/services/campaign_draft_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignDraftOperation.new
  op["remove"] = path
  op
end

.campaign_group(path) ⇒ Object

A convenience method for creating an CampaignGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5689
5690
5691
5692
5693
5694
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5689

def self.campaign_group(path)
  require "google/ads/google_ads/v21/services/campaign_group_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignGroupOperation.new
  op["remove"] = path
  op
end

.campaign_label(path) ⇒ Object

A convenience method for creating an CampaignLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5700
5701
5702
5703
5704
5705
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5700

def self.campaign_label(path)
  require "google/ads/google_ads/v21/services/campaign_label_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignLabelOperation.new
  op["remove"] = path
  op
end

.campaign_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CampaignLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6074
6075
6076
6077
6078
6079
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6074

def self.campaign_lifecycle_goal(path)
  require "google/ads/google_ads/v21/services/campaign_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignLifecycleGoalOperation.new
  op["remove"] = path
  op
end

.campaign_shared_set(path) ⇒ Object

A convenience method for creating an CampaignSharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5733
5734
5735
5736
5737
5738
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5733

def self.campaign_shared_set(path)
  require "google/ads/google_ads/v21/services/campaign_shared_set_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CampaignSharedSetOperation.new
  op["remove"] = path
  op
end

.conversion_action(path) ⇒ Object

A convenience method for creating an ConversionActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5744
5745
5746
5747
5748
5749
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5744

def self.conversion_action(path)
  require "google/ads/google_ads/v21/services/conversion_action_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ConversionActionOperation.new
  op["remove"] = path
  op
end

.conversion_custom_variable(path) ⇒ Object

A convenience method for creating an ConversionCustomVariableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5755
5756
5757
5758
5759
5760
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5755

def self.conversion_custom_variable(path)
  require "google/ads/google_ads/v21/services/conversion_custom_variable_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ConversionCustomVariableOperation.new
  op["remove"] = path
  op
end

.conversion_goal_campaign_config(path) ⇒ Object

A convenience method for creating an ConversionGoalCampaignConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5766
5767
5768
5769
5770
5771
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5766

def self.conversion_goal_campaign_config(path)
  require "google/ads/google_ads/v21/services/conversion_goal_campaign_config_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ConversionGoalCampaignConfigOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule(path) ⇒ Object

A convenience method for creating an ConversionValueRuleOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5777
5778
5779
5780
5781
5782
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5777

def self.conversion_value_rule(path)
  require "google/ads/google_ads/v21/services/conversion_value_rule_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ConversionValueRuleOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule_set(path) ⇒ Object

A convenience method for creating an ConversionValueRuleSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5788
5789
5790
5791
5792
5793
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5788

def self.conversion_value_rule_set(path)
  require "google/ads/google_ads/v21/services/conversion_value_rule_set_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ConversionValueRuleSetOperation.new
  op["remove"] = path
  op
end

.custom_audience(path) ⇒ Object

A convenience method for creating an CustomAudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6085
6086
6087
6088
6089
6090
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6085

def self.custom_audience(path)
  require "google/ads/google_ads/v21/services/custom_audience_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomAudienceOperation.new
  op["remove"] = path
  op
end

.custom_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5799
5800
5801
5802
5803
5804
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5799

def self.custom_conversion_goal(path)
  require "google/ads/google_ads/v21/services/custom_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomConversionGoalOperation.new
  op["remove"] = path
  op
end

.custom_interest(path) ⇒ Object

A convenience method for creating an CustomInterestOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6096
6097
6098
6099
6100
6101
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6096

def self.custom_interest(path)
  require "google/ads/google_ads/v21/services/custom_interest_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomInterestOperation.new
  op["remove"] = path
  op
end

.customer(path) ⇒ Object

A convenience method for creating an CustomerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5865
5866
5867
5868
5869
5870
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5865

def self.customer(path)
  require "google/ads/google_ads/v21/services/customer_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerOperation.new
  op["remove"] = path
  op
end

.customer_asset(path) ⇒ Object

A convenience method for creating an CustomerAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5810
5811
5812
5813
5814
5815
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5810

def self.customer_asset(path)
  require "google/ads/google_ads/v21/services/customer_asset_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerAssetOperation.new
  op["remove"] = path
  op
end

.customer_asset_set(path) ⇒ Object

A convenience method for creating an CustomerAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6107
6108
6109
6110
6111
6112
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6107

def self.customer_asset_set(path)
  require "google/ads/google_ads/v21/services/customer_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerAssetSetOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerClientLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6118
6119
6120
6121
6122
6123
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6118

def self.customer_client_link(path)
  require "google/ads/google_ads/v21/services/customer_client_link_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerClientLinkOperation.new
  op["remove"] = path
  op
end

.customer_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomerConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5821
5822
5823
5824
5825
5826
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5821

def self.customer_conversion_goal(path)
  require "google/ads/google_ads/v21/services/customer_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerConversionGoalOperation.new
  op["remove"] = path
  op
end

.customer_customizer(path) ⇒ Object

A convenience method for creating an CustomerCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5832
5833
5834
5835
5836
5837
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5832

def self.customer_customizer(path)
  require "google/ads/google_ads/v21/services/customer_customizer_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerCustomizerOperation.new
  op["remove"] = path
  op
end

.customer_label(path) ⇒ Object

A convenience method for creating an CustomerLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5843
5844
5845
5846
5847
5848
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5843

def self.customer_label(path)
  require "google/ads/google_ads/v21/services/customer_label_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerLabelOperation.new
  op["remove"] = path
  op
end

.customer_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CustomerLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6129
6130
6131
6132
6133
6134
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6129

def self.customer_lifecycle_goal(path)
  require "google/ads/google_ads/v21/services/customer_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerLifecycleGoalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerManagerLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6140
6141
6142
6143
6144
6145
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6140

def self.customer_manager_link(path)
  require "google/ads/google_ads/v21/services/customer_manager_link_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerManagerLinkOperation.new
  op["remove"] = path
  op
end

.customer_negative_criterion(path) ⇒ Object

A convenience method for creating an CustomerNegativeCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5854
5855
5856
5857
5858
5859
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5854

def self.customer_negative_criterion(path)
  require "google/ads/google_ads/v21/services/customer_negative_criterion_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerNegativeCriterionOperation.new
  op["remove"] = path
  op
end

.customer_sk_ad_network_conversion_value_schema(path) ⇒ Object

A convenience method for creating an CustomerSkAdNetworkConversionValueSchemaOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6151
6152
6153
6154
6155
6156
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6151

def self.customer_sk_ad_network_conversion_value_schema(path)
  require "google/ads/google_ads/v21/services/customer_sk_ad_network_conversion_value_schema_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerSkAdNetworkConversionValueSchemaOperation.new
  op["remove"] = path
  op
end

.customer_user_access(path) ⇒ Object

A convenience method for creating an CustomerUserAccessOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6173
6174
6175
6176
6177
6178
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6173

def self.customer_user_access(path)
  require "google/ads/google_ads/v21/services/customer_user_access_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerUserAccessOperation.new
  op["remove"] = path
  op
end

.customer_user_access_invitation(path) ⇒ Object

A convenience method for creating an CustomerUserAccessInvitationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6162
6163
6164
6165
6166
6167
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6162

def self.customer_user_access_invitation(path)
  require "google/ads/google_ads/v21/services/customer_user_access_invitation_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomerUserAccessInvitationOperation.new
  op["remove"] = path
  op
end

.customizer_attribute(path) ⇒ Object

A convenience method for creating an CustomizerAttributeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5876
5877
5878
5879
5880
5881
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5876

def self.customizer_attribute(path)
  require "google/ads/google_ads/v21/services/customizer_attribute_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::CustomizerAttributeOperation.new
  op["remove"] = path
  op
end

.dismiss_recommendation(path) ⇒ Object

A convenience method for creating an DismissRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6217
6218
6219
6220
6221
6222
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6217

def self.dismiss_recommendation(path)
  require "google/ads/google_ads/v21/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::DismissRecommendationRequest::DismissRecommendationOperation.new
  op["remove"] = path
  op
end

.enable(path) ⇒ Object

A convenience method for creating an EnableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5722
5723
5724
5725
5726
5727
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5722

def self.enable(path)
  require "google/ads/google_ads/v21/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::EnableOperation.new
  op["remove"] = path
  op
end

.experiment(path) ⇒ Object

A convenience method for creating an ExperimentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5898
5899
5900
5901
5902
5903
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5898

def self.experiment(path)
  require "google/ads/google_ads/v21/services/experiment_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ExperimentOperation.new
  op["remove"] = path
  op
end

.experiment_arm(path) ⇒ Object

A convenience method for creating an ExperimentArmOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5887
5888
5889
5890
5891
5892
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5887

def self.experiment_arm(path)
  require "google/ads/google_ads/v21/services/experiment_arm_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ExperimentArmOperation.new
  op["remove"] = path
  op
end

.keyword_plan(path) ⇒ Object

A convenience method for creating an KeywordPlanOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5953
5954
5955
5956
5957
5958
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5953

def self.keyword_plan(path)
  require "google/ads/google_ads/v21/services/keyword_plan_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::KeywordPlanOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5920
5921
5922
5923
5924
5925
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5920

def self.keyword_plan_ad_group(path)
  require "google/ads/google_ads/v21/services/keyword_plan_ad_group_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::KeywordPlanAdGroupOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5909
5910
5911
5912
5913
5914
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5909

def self.keyword_plan_ad_group_keyword(path)
  require "google/ads/google_ads/v21/services/keyword_plan_ad_group_keyword_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::KeywordPlanAdGroupKeywordOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5942
5943
5944
5945
5946
5947
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5942

def self.keyword_plan_campaign(path)
  require "google/ads/google_ads/v21/services/keyword_plan_campaign_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::KeywordPlanCampaignOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5931
5932
5933
5934
5935
5936
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5931

def self.keyword_plan_campaign_keyword(path)
  require "google/ads/google_ads/v21/services/keyword_plan_campaign_keyword_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::KeywordPlanCampaignKeywordOperation.new
  op["remove"] = path
  op
end

.label(path) ⇒ Object

A convenience method for creating an LabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5964
5965
5966
5967
5968
5969
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5964

def self.label(path)
  require "google/ads/google_ads/v21/services/label_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::LabelOperation.new
  op["remove"] = path
  op
end

.mutate(path) ⇒ Object

A convenience method for creating an MutateOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6041
6042
6043
6044
6045
6046
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6041

def self.mutate(path)
  require "google/ads/google_ads/v21/services/google_ads_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::MutateOperation.new
  op["remove"] = path
  op
end

.offline_user_data_job(path) ⇒ Object

A convenience method for creating an OfflineUserDataJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6195
6196
6197
6198
6199
6200
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6195

def self.offline_user_data_job(path)
  require "google/ads/google_ads/v21/services/offline_user_data_job_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::OfflineUserDataJobOperation.new
  op["remove"] = path
  op
end

.recommendation_subscription(path) ⇒ Object

A convenience method for creating an RecommendationSubscriptionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5975
5976
5977
5978
5979
5980
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5975

def self.recommendation_subscription(path)
  require "google/ads/google_ads/v21/services/recommendation_subscription_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::RecommendationSubscriptionOperation.new
  op["remove"] = path
  op
end

.remarketing_action(path) ⇒ Object

A convenience method for creating an RemarketingActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5986
5987
5988
5989
5990
5991
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5986

def self.remarketing_action(path)
  require "google/ads/google_ads/v21/services/remarketing_action_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::RemarketingActionOperation.new
  op["remove"] = path
  op
end

.remove_campaign_automatically_created_asset(path) ⇒ Object

A convenience method for creating an RemoveCampaignAutomaticallyCreatedAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5557
5558
5559
5560
5561
5562
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5557

def self.remove_campaign_automatically_created_asset(path)
  require "google/ads/google_ads/v21/services/automatically_created_asset_removal_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::RemoveCampaignAutomaticallyCreatedAssetOperation.new
  op["remove"] = path
  op
end

.resolve_multi_party_auth_review(path) ⇒ Object

A convenience method for creating an ResolveMultiPartyAuthReviewOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6184
6185
6186
6187
6188
6189
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6184

def self.resolve_multi_party_auth_review(path)
  require "google/ads/google_ads/v21/services/multi_party_auth_review_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::ResolveMultiPartyAuthReviewOperation.new
  op["remove"] = path
  op
end

.shared_criterion(path) ⇒ Object

A convenience method for creating an SharedCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5997
5998
5999
6000
6001
6002
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5997

def self.shared_criterion(path)
  require "google/ads/google_ads/v21/services/shared_criterion_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::SharedCriterionOperation.new
  op["remove"] = path
  op
end

.shared_set(path) ⇒ Object

A convenience method for creating an SharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6008
6009
6010
6011
6012
6013
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6008

def self.shared_set(path)
  require "google/ads/google_ads/v21/services/shared_set_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::SharedSetOperation.new
  op["remove"] = path
  op
end

.smart_campaign_setting(path) ⇒ Object

A convenience method for creating an SmartCampaignSettingOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6019
6020
6021
6022
6023
6024
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6019

def self.smart_campaign_setting(path)
  require "google/ads/google_ads/v21/services/smart_campaign_setting_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::SmartCampaignSettingOperation.new
  op["remove"] = path
  op
end

.target_restriction(path) ⇒ Object

A convenience method for creating an TargetRestrictionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5293
5294
5295
5296
5297
5298
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 5293

def self.target_restriction(path)
  require "google/ads/google_ads/v21/common/targeting_setting_pb"
  op = Google::Ads::GoogleAds::V21::Common::TargetRestrictionOperation.new
  op["remove"] = path
  op
end

.user_data(path) ⇒ Object

A convenience method for creating an UserDataOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6228
6229
6230
6231
6232
6233
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6228

def self.user_data(path)
  require "google/ads/google_ads/v21/services/user_data_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::UserDataOperation.new
  op["remove"] = path
  op
end

.user_list(path) ⇒ Object

A convenience method for creating an UserListOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6030
6031
6032
6033
6034
6035
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6030

def self.user_list(path)
  require "google/ads/google_ads/v21/services/user_list_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::UserListOperation.new
  op["remove"] = path
  op
end

.user_list_customer_type(path) ⇒ Object

A convenience method for creating an UserListCustomerTypeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6239
6240
6241
6242
6243
6244
# File 'lib/google/ads/google_ads/factories/v21/operations.rb', line 6239

def self.user_list_customer_type(path)
  require "google/ads/google_ads/v21/services/user_list_customer_type_service_pb"
  op = Google::Ads::GoogleAds::V21::Services::UserListCustomerTypeOperation.new
  op["remove"] = path
  op
end