Module: Google::Ads::GoogleAds::Factories::V22::Operations::RemoveResource

Defined in:
lib/google/ads/google_ads/factories/v22/operations.rb

Class Method Summary collapse

Class Method Details

.account_budget_proposal(path) ⇒ Object

A convenience method for creating an AccountBudgetProposalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5464
5465
5466
5467
5468
5469
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5464

def self.(path)
  require "google/ads/google_ads/v22/services/account_budget_proposal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AccountBudgetProposalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an AccountLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5475
5476
5477
5478
5479
5480
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5475

def self.(path)
  require "google/ads/google_ads/v22/services/account_link_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AccountLinkOperation.new
  op["remove"] = path
  op
end

.ad(path) ⇒ Object

A convenience method for creating an AdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5618
5619
5620
5621
5622
5623
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5618

def self.ad(path)
  require "google/ads/google_ads/v22/services/ad_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdOperation.new
  op["remove"] = path
  op
end

.ad_group(path) ⇒ Object

A convenience method for creating an AdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5596
5597
5598
5599
5600
5601
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5596

def self.ad_group(path)
  require "google/ads/google_ads/v22/services/ad_group_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupOperation.new
  op["remove"] = path
  op
end

.ad_group_ad(path) ⇒ Object

A convenience method for creating an AdGroupAdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5497
5498
5499
5500
5501
5502
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5497

def self.ad_group_ad(path)
  require "google/ads/google_ads/v22/services/ad_group_ad_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupAdOperation.new
  op["remove"] = path
  op
end

.ad_group_ad_label(path) ⇒ Object

A convenience method for creating an AdGroupAdLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5486
5487
5488
5489
5490
5491
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5486

def self.ad_group_ad_label(path)
  require "google/ads/google_ads/v22/services/ad_group_ad_label_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupAdLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_asset(path) ⇒ Object

A convenience method for creating an AdGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5508
5509
5510
5511
5512
5513
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5508

def self.ad_group_asset(path)
  require "google/ads/google_ads/v22/services/ad_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupAssetOperation.new
  op["remove"] = path
  op
end

.ad_group_asset_set(path) ⇒ Object

A convenience method for creating an AdGroupAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5519
5520
5521
5522
5523
5524
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5519

def self.ad_group_asset_set(path)
  require "google/ads/google_ads/v22/services/ad_group_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupAssetSetOperation.new
  op["remove"] = path
  op
end

.ad_group_bid_modifier(path) ⇒ Object

A convenience method for creating an AdGroupBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5530
5531
5532
5533
5534
5535
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5530

def self.ad_group_bid_modifier(path)
  require "google/ads/google_ads/v22/services/ad_group_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupBidModifierOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion(path) ⇒ Object

A convenience method for creating an AdGroupCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5563
5564
5565
5566
5567
5568
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5563

def self.ad_group_criterion(path)
  require "google/ads/google_ads/v22/services/ad_group_criterion_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupCriterionOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCriterionCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5541
5542
5543
5544
5545
5546
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5541

def self.ad_group_criterion_customizer(path)
  require "google/ads/google_ads/v22/services/ad_group_criterion_customizer_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupCriterionCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_label(path) ⇒ Object

A convenience method for creating an AdGroupCriterionLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5552
5553
5554
5555
5556
5557
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5552

def self.ad_group_criterion_label(path)
  require "google/ads/google_ads/v22/services/ad_group_criterion_label_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupCriterionLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5574
5575
5576
5577
5578
5579
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5574

def self.ad_group_customizer(path)
  require "google/ads/google_ads/v22/services/ad_group_customizer_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_label(path) ⇒ Object

A convenience method for creating an AdGroupLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5585
5586
5587
5588
5589
5590
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5585

def self.ad_group_label(path)
  require "google/ads/google_ads/v22/services/ad_group_label_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdGroupLabelOperation.new
  op["remove"] = path
  op
end

.ad_parameter(path) ⇒ Object

A convenience method for creating an AdParameterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5607
5608
5609
5610
5611
5612
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5607

def self.ad_parameter(path)
  require "google/ads/google_ads/v22/services/ad_parameter_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AdParameterOperation.new
  op["remove"] = path
  op
end

.apply_recommendation(path) ⇒ Object

A convenience method for creating an ApplyRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6388
6389
6390
6391
6392
6393
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6388

def self.apply_recommendation(path)
  require "google/ads/google_ads/v22/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ApplyRecommendationOperation.new
  op["remove"] = path
  op
end

.asset(path) ⇒ Object

A convenience method for creating an AssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5673
5674
5675
5676
5677
5678
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5673

def self.asset(path)
  require "google/ads/google_ads/v22/services/asset_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AssetOperation.new
  op["remove"] = path
  op
end

.asset_group(path) ⇒ Object

A convenience method for creating an AssetGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5651
5652
5653
5654
5655
5656
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5651

def self.asset_group(path)
  require "google/ads/google_ads/v22/services/asset_group_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AssetGroupOperation.new
  op["remove"] = path
  op
end

.asset_group_asset(path) ⇒ Object

A convenience method for creating an AssetGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5629
5630
5631
5632
5633
5634
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5629

def self.asset_group_asset(path)
  require "google/ads/google_ads/v22/services/asset_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AssetGroupAssetOperation.new
  op["remove"] = path
  op
end

.asset_group_listing_group_filter(path) ⇒ Object

A convenience method for creating an AssetGroupListingGroupFilterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5640
5641
5642
5643
5644
5645
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5640

def self.asset_group_listing_group_filter(path)
  require "google/ads/google_ads/v22/services/asset_group_listing_group_filter_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AssetGroupListingGroupFilterOperation.new
  op["remove"] = path
  op
end

.asset_group_signal(path) ⇒ Object

A convenience method for creating an AssetGroupSignalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5662
5663
5664
5665
5666
5667
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5662

def self.asset_group_signal(path)
  require "google/ads/google_ads/v22/services/asset_group_signal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AssetGroupSignalOperation.new
  op["remove"] = path
  op
end

.asset_set(path) ⇒ Object

A convenience method for creating an AssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5695
5696
5697
5698
5699
5700
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5695

def self.asset_set(path)
  require "google/ads/google_ads/v22/services/asset_set_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AssetSetOperation.new
  op["remove"] = path
  op
end

.asset_set_asset(path) ⇒ Object

A convenience method for creating an AssetSetAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5684
5685
5686
5687
5688
5689
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5684

def self.asset_set_asset(path)
  require "google/ads/google_ads/v22/services/asset_set_asset_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AssetSetAssetOperation.new
  op["remove"] = path
  op
end

.audience(path) ⇒ Object

A convenience method for creating an AudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5706
5707
5708
5709
5710
5711
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5706

def self.audience(path)
  require "google/ads/google_ads/v22/services/audience_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::AudienceOperation.new
  op["remove"] = path
  op
end

.batch_job(path) ⇒ Object

A convenience method for creating an BatchJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6212
6213
6214
6215
6216
6217
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6212

def self.batch_job(path)
  require "google/ads/google_ads/v22/services/batch_job_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::BatchJobOperation.new
  op["remove"] = path
  op
end

.bidding_data_exclusion(path) ⇒ Object

A convenience method for creating an BiddingDataExclusionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5728
5729
5730
5731
5732
5733
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5728

def self.bidding_data_exclusion(path)
  require "google/ads/google_ads/v22/services/bidding_data_exclusion_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::BiddingDataExclusionOperation.new
  op["remove"] = path
  op
end

.bidding_seasonality_adjustment(path) ⇒ Object

A convenience method for creating an BiddingSeasonalityAdjustmentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5739
5740
5741
5742
5743
5744
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5739

def self.bidding_seasonality_adjustment(path)
  require "google/ads/google_ads/v22/services/bidding_seasonality_adjustment_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::BiddingSeasonalityAdjustmentOperation.new
  op["remove"] = path
  op
end

.bidding_strategy(path) ⇒ Object

A convenience method for creating an BiddingStrategyOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5750
5751
5752
5753
5754
5755
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5750

def self.bidding_strategy(path)
  require "google/ads/google_ads/v22/services/bidding_strategy_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::BiddingStrategyOperation.new
  op["remove"] = path
  op
end

.billing_setup(path) ⇒ Object

A convenience method for creating an BillingSetupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6223
6224
6225
6226
6227
6228
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6223

def self.billing_setup(path)
  require "google/ads/google_ads/v22/services/billing_setup_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::BillingSetupOperation.new
  op["remove"] = path
  op
end

.campaign(path) ⇒ Object

A convenience method for creating an CampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5871
5872
5873
5874
5875
5876
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5871

def self.campaign(path)
  require "google/ads/google_ads/v22/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignOperation.new
  op["remove"] = path
  op
end

.campaign_asset(path) ⇒ Object

A convenience method for creating an CampaignAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5761
5762
5763
5764
5765
5766
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5761

def self.campaign_asset(path)
  require "google/ads/google_ads/v22/services/campaign_asset_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignAssetOperation.new
  op["remove"] = path
  op
end

.campaign_asset_set(path) ⇒ Object

A convenience method for creating an CampaignAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5772
5773
5774
5775
5776
5777
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5772

def self.campaign_asset_set(path)
  require "google/ads/google_ads/v22/services/campaign_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignAssetSetOperation.new
  op["remove"] = path
  op
end

.campaign_bid_modifier(path) ⇒ Object

A convenience method for creating an CampaignBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5783
5784
5785
5786
5787
5788
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5783

def self.campaign_bid_modifier(path)
  require "google/ads/google_ads/v22/services/campaign_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignBidModifierOperation.new
  op["remove"] = path
  op
end

.campaign_budget(path) ⇒ Object

A convenience method for creating an CampaignBudgetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5794
5795
5796
5797
5798
5799
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5794

def self.campaign_budget(path)
  require "google/ads/google_ads/v22/services/campaign_budget_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignBudgetOperation.new
  op["remove"] = path
  op
end

.campaign_conversion_goal(path) ⇒ Object

A convenience method for creating an CampaignConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5805
5806
5807
5808
5809
5810
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5805

def self.campaign_conversion_goal(path)
  require "google/ads/google_ads/v22/services/campaign_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignConversionGoalOperation.new
  op["remove"] = path
  op
end

.campaign_criterion(path) ⇒ Object

A convenience method for creating an CampaignCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5816
5817
5818
5819
5820
5821
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5816

def self.campaign_criterion(path)
  require "google/ads/google_ads/v22/services/campaign_criterion_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignCriterionOperation.new
  op["remove"] = path
  op
end

.campaign_customizer(path) ⇒ Object

A convenience method for creating an CampaignCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5827
5828
5829
5830
5831
5832
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5827

def self.campaign_customizer(path)
  require "google/ads/google_ads/v22/services/campaign_customizer_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignCustomizerOperation.new
  op["remove"] = path
  op
end

.campaign_draft(path) ⇒ Object

A convenience method for creating an CampaignDraftOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5838
5839
5840
5841
5842
5843
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5838

def self.campaign_draft(path)
  require "google/ads/google_ads/v22/services/campaign_draft_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignDraftOperation.new
  op["remove"] = path
  op
end

.campaign_goal_config(path) ⇒ Object

A convenience method for creating an CampaignGoalConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6234
6235
6236
6237
6238
6239
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6234

def self.campaign_goal_config(path)
  require "google/ads/google_ads/v22/services/campaign_goal_config_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignGoalConfigOperation.new
  op["remove"] = path
  op
end

.campaign_group(path) ⇒ Object

A convenience method for creating an CampaignGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5849
5850
5851
5852
5853
5854
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5849

def self.campaign_group(path)
  require "google/ads/google_ads/v22/services/campaign_group_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignGroupOperation.new
  op["remove"] = path
  op
end

.campaign_label(path) ⇒ Object

A convenience method for creating an CampaignLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5860
5861
5862
5863
5864
5865
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5860

def self.campaign_label(path)
  require "google/ads/google_ads/v22/services/campaign_label_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignLabelOperation.new
  op["remove"] = path
  op
end

.campaign_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CampaignLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6245
6246
6247
6248
6249
6250
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6245

def self.campaign_lifecycle_goal(path)
  require "google/ads/google_ads/v22/services/campaign_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignLifecycleGoalOperation.new
  op["remove"] = path
  op
end

.campaign_shared_set(path) ⇒ Object

A convenience method for creating an CampaignSharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5893
5894
5895
5896
5897
5898
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5893

def self.campaign_shared_set(path)
  require "google/ads/google_ads/v22/services/campaign_shared_set_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CampaignSharedSetOperation.new
  op["remove"] = path
  op
end

.conversion_action(path) ⇒ Object

A convenience method for creating an ConversionActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5904
5905
5906
5907
5908
5909
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5904

def self.conversion_action(path)
  require "google/ads/google_ads/v22/services/conversion_action_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ConversionActionOperation.new
  op["remove"] = path
  op
end

.conversion_custom_variable(path) ⇒ Object

A convenience method for creating an ConversionCustomVariableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5915
5916
5917
5918
5919
5920
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5915

def self.conversion_custom_variable(path)
  require "google/ads/google_ads/v22/services/conversion_custom_variable_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ConversionCustomVariableOperation.new
  op["remove"] = path
  op
end

.conversion_goal_campaign_config(path) ⇒ Object

A convenience method for creating an ConversionGoalCampaignConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5926
5927
5928
5929
5930
5931
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5926

def self.conversion_goal_campaign_config(path)
  require "google/ads/google_ads/v22/services/conversion_goal_campaign_config_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ConversionGoalCampaignConfigOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule(path) ⇒ Object

A convenience method for creating an ConversionValueRuleOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5937
5938
5939
5940
5941
5942
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5937

def self.conversion_value_rule(path)
  require "google/ads/google_ads/v22/services/conversion_value_rule_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ConversionValueRuleOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule_set(path) ⇒ Object

A convenience method for creating an ConversionValueRuleSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5948
5949
5950
5951
5952
5953
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5948

def self.conversion_value_rule_set(path)
  require "google/ads/google_ads/v22/services/conversion_value_rule_set_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ConversionValueRuleSetOperation.new
  op["remove"] = path
  op
end

.custom_audience(path) ⇒ Object

A convenience method for creating an CustomAudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6256
6257
6258
6259
6260
6261
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6256

def self.custom_audience(path)
  require "google/ads/google_ads/v22/services/custom_audience_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomAudienceOperation.new
  op["remove"] = path
  op
end

.custom_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5959
5960
5961
5962
5963
5964
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5959

def self.custom_conversion_goal(path)
  require "google/ads/google_ads/v22/services/custom_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomConversionGoalOperation.new
  op["remove"] = path
  op
end

.custom_interest(path) ⇒ Object

A convenience method for creating an CustomInterestOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6267
6268
6269
6270
6271
6272
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6267

def self.custom_interest(path)
  require "google/ads/google_ads/v22/services/custom_interest_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomInterestOperation.new
  op["remove"] = path
  op
end

.customer(path) ⇒ Object

A convenience method for creating an CustomerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6025
6026
6027
6028
6029
6030
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6025

def self.customer(path)
  require "google/ads/google_ads/v22/services/customer_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerOperation.new
  op["remove"] = path
  op
end

.customer_asset(path) ⇒ Object

A convenience method for creating an CustomerAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5970
5971
5972
5973
5974
5975
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5970

def self.customer_asset(path)
  require "google/ads/google_ads/v22/services/customer_asset_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerAssetOperation.new
  op["remove"] = path
  op
end

.customer_asset_set(path) ⇒ Object

A convenience method for creating an CustomerAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6278
6279
6280
6281
6282
6283
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6278

def self.customer_asset_set(path)
  require "google/ads/google_ads/v22/services/customer_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerAssetSetOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerClientLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6289
6290
6291
6292
6293
6294
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6289

def self.customer_client_link(path)
  require "google/ads/google_ads/v22/services/customer_client_link_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerClientLinkOperation.new
  op["remove"] = path
  op
end

.customer_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomerConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5981
5982
5983
5984
5985
5986
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5981

def self.customer_conversion_goal(path)
  require "google/ads/google_ads/v22/services/customer_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerConversionGoalOperation.new
  op["remove"] = path
  op
end

.customer_customizer(path) ⇒ Object

A convenience method for creating an CustomerCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5992
5993
5994
5995
5996
5997
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5992

def self.customer_customizer(path)
  require "google/ads/google_ads/v22/services/customer_customizer_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerCustomizerOperation.new
  op["remove"] = path
  op
end

.customer_label(path) ⇒ Object

A convenience method for creating an CustomerLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6003
6004
6005
6006
6007
6008
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6003

def self.customer_label(path)
  require "google/ads/google_ads/v22/services/customer_label_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerLabelOperation.new
  op["remove"] = path
  op
end

.customer_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CustomerLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6300
6301
6302
6303
6304
6305
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6300

def self.customer_lifecycle_goal(path)
  require "google/ads/google_ads/v22/services/customer_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerLifecycleGoalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerManagerLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6311
6312
6313
6314
6315
6316
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6311

def self.customer_manager_link(path)
  require "google/ads/google_ads/v22/services/customer_manager_link_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerManagerLinkOperation.new
  op["remove"] = path
  op
end

.customer_negative_criterion(path) ⇒ Object

A convenience method for creating an CustomerNegativeCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6014
6015
6016
6017
6018
6019
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6014

def self.customer_negative_criterion(path)
  require "google/ads/google_ads/v22/services/customer_negative_criterion_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerNegativeCriterionOperation.new
  op["remove"] = path
  op
end

.customer_sk_ad_network_conversion_value_schema(path) ⇒ Object

A convenience method for creating an CustomerSkAdNetworkConversionValueSchemaOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6322
6323
6324
6325
6326
6327
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6322

def self.customer_sk_ad_network_conversion_value_schema(path)
  require "google/ads/google_ads/v22/services/customer_sk_ad_network_conversion_value_schema_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerSkAdNetworkConversionValueSchemaOperation.new
  op["remove"] = path
  op
end

.customer_user_access(path) ⇒ Object

A convenience method for creating an CustomerUserAccessOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6344
6345
6346
6347
6348
6349
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6344

def self.customer_user_access(path)
  require "google/ads/google_ads/v22/services/customer_user_access_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerUserAccessOperation.new
  op["remove"] = path
  op
end

.customer_user_access_invitation(path) ⇒ Object

A convenience method for creating an CustomerUserAccessInvitationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6333
6334
6335
6336
6337
6338
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6333

def self.customer_user_access_invitation(path)
  require "google/ads/google_ads/v22/services/customer_user_access_invitation_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomerUserAccessInvitationOperation.new
  op["remove"] = path
  op
end

.customizer_attribute(path) ⇒ Object

A convenience method for creating an CustomizerAttributeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6036
6037
6038
6039
6040
6041
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6036

def self.customizer_attribute(path)
  require "google/ads/google_ads/v22/services/customizer_attribute_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::CustomizerAttributeOperation.new
  op["remove"] = path
  op
end

.dismiss_recommendation(path) ⇒ Object

A convenience method for creating an DismissRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6399
6400
6401
6402
6403
6404
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6399

def self.dismiss_recommendation(path)
  require "google/ads/google_ads/v22/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::DismissRecommendationRequest::DismissRecommendationOperation.new
  op["remove"] = path
  op
end

.enable(path) ⇒ Object

A convenience method for creating an EnableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5882
5883
5884
5885
5886
5887
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5882

def self.enable(path)
  require "google/ads/google_ads/v22/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::EnableOperation.new
  op["remove"] = path
  op
end

.experiment(path) ⇒ Object

A convenience method for creating an ExperimentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6058
6059
6060
6061
6062
6063
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6058

def self.experiment(path)
  require "google/ads/google_ads/v22/services/experiment_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ExperimentOperation.new
  op["remove"] = path
  op
end

.experiment_arm(path) ⇒ Object

A convenience method for creating an ExperimentArmOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6047
6048
6049
6050
6051
6052
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6047

def self.experiment_arm(path)
  require "google/ads/google_ads/v22/services/experiment_arm_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ExperimentArmOperation.new
  op["remove"] = path
  op
end

.goal(path) ⇒ Object

A convenience method for creating an GoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6355
6356
6357
6358
6359
6360
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6355

def self.goal(path)
  require "google/ads/google_ads/v22/services/goal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::GoalOperation.new
  op["remove"] = path
  op
end

.keyword_plan(path) ⇒ Object

A convenience method for creating an KeywordPlanOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6113
6114
6115
6116
6117
6118
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6113

def self.keyword_plan(path)
  require "google/ads/google_ads/v22/services/keyword_plan_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::KeywordPlanOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6080
6081
6082
6083
6084
6085
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6080

def self.keyword_plan_ad_group(path)
  require "google/ads/google_ads/v22/services/keyword_plan_ad_group_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::KeywordPlanAdGroupOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6069
6070
6071
6072
6073
6074
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6069

def self.keyword_plan_ad_group_keyword(path)
  require "google/ads/google_ads/v22/services/keyword_plan_ad_group_keyword_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::KeywordPlanAdGroupKeywordOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6102
6103
6104
6105
6106
6107
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6102

def self.keyword_plan_campaign(path)
  require "google/ads/google_ads/v22/services/keyword_plan_campaign_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::KeywordPlanCampaignOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6091
6092
6093
6094
6095
6096
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6091

def self.keyword_plan_campaign_keyword(path)
  require "google/ads/google_ads/v22/services/keyword_plan_campaign_keyword_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::KeywordPlanCampaignKeywordOperation.new
  op["remove"] = path
  op
end

.label(path) ⇒ Object

A convenience method for creating an LabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6124
6125
6126
6127
6128
6129
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6124

def self.label(path)
  require "google/ads/google_ads/v22/services/label_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::LabelOperation.new
  op["remove"] = path
  op
end

.mutate(path) ⇒ Object

A convenience method for creating an MutateOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6201
6202
6203
6204
6205
6206
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6201

def self.mutate(path)
  require "google/ads/google_ads/v22/services/google_ads_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::MutateOperation.new
  op["remove"] = path
  op
end

.offline_user_data_job(path) ⇒ Object

A convenience method for creating an OfflineUserDataJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6377
6378
6379
6380
6381
6382
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6377

def self.offline_user_data_job(path)
  require "google/ads/google_ads/v22/services/offline_user_data_job_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::OfflineUserDataJobOperation.new
  op["remove"] = path
  op
end

.recommendation_subscription(path) ⇒ Object

A convenience method for creating an RecommendationSubscriptionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6135
6136
6137
6138
6139
6140
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6135

def self.recommendation_subscription(path)
  require "google/ads/google_ads/v22/services/recommendation_subscription_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::RecommendationSubscriptionOperation.new
  op["remove"] = path
  op
end

.remarketing_action(path) ⇒ Object

A convenience method for creating an RemarketingActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6146
6147
6148
6149
6150
6151
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6146

def self.remarketing_action(path)
  require "google/ads/google_ads/v22/services/remarketing_action_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::RemarketingActionOperation.new
  op["remove"] = path
  op
end

.remove_campaign_automatically_created_asset(path) ⇒ Object

A convenience method for creating an RemoveCampaignAutomaticallyCreatedAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5717
5718
5719
5720
5721
5722
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5717

def self.remove_campaign_automatically_created_asset(path)
  require "google/ads/google_ads/v22/services/automatically_created_asset_removal_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::RemoveCampaignAutomaticallyCreatedAssetOperation.new
  op["remove"] = path
  op
end

.resolve_multi_party_auth_review(path) ⇒ Object

A convenience method for creating an ResolveMultiPartyAuthReviewOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6366
6367
6368
6369
6370
6371
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6366

def self.resolve_multi_party_auth_review(path)
  require "google/ads/google_ads/v22/services/multi_party_auth_review_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::ResolveMultiPartyAuthReviewOperation.new
  op["remove"] = path
  op
end

.shared_criterion(path) ⇒ Object

A convenience method for creating an SharedCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6157
6158
6159
6160
6161
6162
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6157

def self.shared_criterion(path)
  require "google/ads/google_ads/v22/services/shared_criterion_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::SharedCriterionOperation.new
  op["remove"] = path
  op
end

.shared_set(path) ⇒ Object

A convenience method for creating an SharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6168
6169
6170
6171
6172
6173
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6168

def self.shared_set(path)
  require "google/ads/google_ads/v22/services/shared_set_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::SharedSetOperation.new
  op["remove"] = path
  op
end

.smart_campaign_setting(path) ⇒ Object

A convenience method for creating an SmartCampaignSettingOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6179
6180
6181
6182
6183
6184
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6179

def self.smart_campaign_setting(path)
  require "google/ads/google_ads/v22/services/smart_campaign_setting_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::SmartCampaignSettingOperation.new
  op["remove"] = path
  op
end

.target_restriction(path) ⇒ Object

A convenience method for creating an TargetRestrictionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5453
5454
5455
5456
5457
5458
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 5453

def self.target_restriction(path)
  require "google/ads/google_ads/v22/common/targeting_setting_pb"
  op = Google::Ads::GoogleAds::V22::Common::TargetRestrictionOperation.new
  op["remove"] = path
  op
end

.user_data(path) ⇒ Object

A convenience method for creating an UserDataOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6410
6411
6412
6413
6414
6415
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6410

def self.user_data(path)
  require "google/ads/google_ads/v22/services/user_data_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::UserDataOperation.new
  op["remove"] = path
  op
end

.user_list(path) ⇒ Object

A convenience method for creating an UserListOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6190
6191
6192
6193
6194
6195
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6190

def self.user_list(path)
  require "google/ads/google_ads/v22/services/user_list_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::UserListOperation.new
  op["remove"] = path
  op
end

.user_list_customer_type(path) ⇒ Object

A convenience method for creating an UserListCustomerTypeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6421
6422
6423
6424
6425
6426
# File 'lib/google/ads/google_ads/factories/v22/operations.rb', line 6421

def self.user_list_customer_type(path)
  require "google/ads/google_ads/v22/services/user_list_customer_type_service_pb"
  op = Google::Ads::GoogleAds::V22::Services::UserListCustomerTypeOperation.new
  op["remove"] = path
  op
end