Module: Google::Ads::GoogleAds::Factories::V23::Operations::RemoveResource

Defined in:
lib/google/ads/google_ads/factories/v23/operations.rb

Class Method Summary collapse

Class Method Details

.account_budget_proposal(path) ⇒ Object

A convenience method for creating an AccountBudgetProposalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5478
5479
5480
5481
5482
5483
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5478

def self.(path)
  require "google/ads/google_ads/v23/services/account_budget_proposal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AccountBudgetProposalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an AccountLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5489
5490
5491
5492
5493
5494
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5489

def self.(path)
  require "google/ads/google_ads/v23/services/account_link_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AccountLinkOperation.new
  op["remove"] = path
  op
end

.ad(path) ⇒ Object

A convenience method for creating an AdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5632
5633
5634
5635
5636
5637
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5632

def self.ad(path)
  require "google/ads/google_ads/v23/services/ad_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdOperation.new
  op["remove"] = path
  op
end

.ad_group(path) ⇒ Object

A convenience method for creating an AdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5610
5611
5612
5613
5614
5615
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5610

def self.ad_group(path)
  require "google/ads/google_ads/v23/services/ad_group_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupOperation.new
  op["remove"] = path
  op
end

.ad_group_ad(path) ⇒ Object

A convenience method for creating an AdGroupAdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5511
5512
5513
5514
5515
5516
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5511

def self.ad_group_ad(path)
  require "google/ads/google_ads/v23/services/ad_group_ad_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupAdOperation.new
  op["remove"] = path
  op
end

.ad_group_ad_label(path) ⇒ Object

A convenience method for creating an AdGroupAdLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5500
5501
5502
5503
5504
5505
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5500

def self.ad_group_ad_label(path)
  require "google/ads/google_ads/v23/services/ad_group_ad_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupAdLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_asset(path) ⇒ Object

A convenience method for creating an AdGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5522
5523
5524
5525
5526
5527
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5522

def self.ad_group_asset(path)
  require "google/ads/google_ads/v23/services/ad_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupAssetOperation.new
  op["remove"] = path
  op
end

.ad_group_asset_set(path) ⇒ Object

A convenience method for creating an AdGroupAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5533
5534
5535
5536
5537
5538
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5533

def self.ad_group_asset_set(path)
  require "google/ads/google_ads/v23/services/ad_group_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupAssetSetOperation.new
  op["remove"] = path
  op
end

.ad_group_bid_modifier(path) ⇒ Object

A convenience method for creating an AdGroupBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5544
5545
5546
5547
5548
5549
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5544

def self.ad_group_bid_modifier(path)
  require "google/ads/google_ads/v23/services/ad_group_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupBidModifierOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion(path) ⇒ Object

A convenience method for creating an AdGroupCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5577
5578
5579
5580
5581
5582
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5577

def self.ad_group_criterion(path)
  require "google/ads/google_ads/v23/services/ad_group_criterion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupCriterionOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCriterionCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5555
5556
5557
5558
5559
5560
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5555

def self.ad_group_criterion_customizer(path)
  require "google/ads/google_ads/v23/services/ad_group_criterion_customizer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupCriterionCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_label(path) ⇒ Object

A convenience method for creating an AdGroupCriterionLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5566
5567
5568
5569
5570
5571
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5566

def self.ad_group_criterion_label(path)
  require "google/ads/google_ads/v23/services/ad_group_criterion_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupCriterionLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5588
5589
5590
5591
5592
5593
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5588

def self.ad_group_customizer(path)
  require "google/ads/google_ads/v23/services/ad_group_customizer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_label(path) ⇒ Object

A convenience method for creating an AdGroupLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5599
5600
5601
5602
5603
5604
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5599

def self.ad_group_label(path)
  require "google/ads/google_ads/v23/services/ad_group_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupLabelOperation.new
  op["remove"] = path
  op
end

.ad_parameter(path) ⇒ Object

A convenience method for creating an AdParameterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5621
5622
5623
5624
5625
5626
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5621

def self.ad_parameter(path)
  require "google/ads/google_ads/v23/services/ad_parameter_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdParameterOperation.new
  op["remove"] = path
  op
end

.apply_recommendation(path) ⇒ Object

A convenience method for creating an ApplyRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6413
6414
6415
6416
6417
6418
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6413

def self.apply_recommendation(path)
  require "google/ads/google_ads/v23/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ApplyRecommendationOperation.new
  op["remove"] = path
  op
end

.asset(path) ⇒ Object

A convenience method for creating an AssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5687
5688
5689
5690
5691
5692
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5687

def self.asset(path)
  require "google/ads/google_ads/v23/services/asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetOperation.new
  op["remove"] = path
  op
end

.asset_group(path) ⇒ Object

A convenience method for creating an AssetGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5665
5666
5667
5668
5669
5670
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5665

def self.asset_group(path)
  require "google/ads/google_ads/v23/services/asset_group_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetGroupOperation.new
  op["remove"] = path
  op
end

.asset_group_asset(path) ⇒ Object

A convenience method for creating an AssetGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5643
5644
5645
5646
5647
5648
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5643

def self.asset_group_asset(path)
  require "google/ads/google_ads/v23/services/asset_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetGroupAssetOperation.new
  op["remove"] = path
  op
end

.asset_group_listing_group_filter(path) ⇒ Object

A convenience method for creating an AssetGroupListingGroupFilterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5654
5655
5656
5657
5658
5659
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5654

def self.asset_group_listing_group_filter(path)
  require "google/ads/google_ads/v23/services/asset_group_listing_group_filter_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetGroupListingGroupFilterOperation.new
  op["remove"] = path
  op
end

.asset_group_signal(path) ⇒ Object

A convenience method for creating an AssetGroupSignalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5676
5677
5678
5679
5680
5681
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5676

def self.asset_group_signal(path)
  require "google/ads/google_ads/v23/services/asset_group_signal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetGroupSignalOperation.new
  op["remove"] = path
  op
end

.asset_set(path) ⇒ Object

A convenience method for creating an AssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5709
5710
5711
5712
5713
5714
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5709

def self.asset_set(path)
  require "google/ads/google_ads/v23/services/asset_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetSetOperation.new
  op["remove"] = path
  op
end

.asset_set_asset(path) ⇒ Object

A convenience method for creating an AssetSetAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5698
5699
5700
5701
5702
5703
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5698

def self.asset_set_asset(path)
  require "google/ads/google_ads/v23/services/asset_set_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetSetAssetOperation.new
  op["remove"] = path
  op
end

.audience(path) ⇒ Object

A convenience method for creating an AudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5720
5721
5722
5723
5724
5725
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5720

def self.audience(path)
  require "google/ads/google_ads/v23/services/audience_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AudienceOperation.new
  op["remove"] = path
  op
end

.batch_job(path) ⇒ Object

A convenience method for creating an BatchJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6248
6249
6250
6251
6252
6253
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6248

def self.batch_job(path)
  require "google/ads/google_ads/v23/services/batch_job_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BatchJobOperation.new
  op["remove"] = path
  op
end

.bidding_data_exclusion(path) ⇒ Object

A convenience method for creating an BiddingDataExclusionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5764
5765
5766
5767
5768
5769
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5764

def self.bidding_data_exclusion(path)
  require "google/ads/google_ads/v23/services/bidding_data_exclusion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BiddingDataExclusionOperation.new
  op["remove"] = path
  op
end

.bidding_seasonality_adjustment(path) ⇒ Object

A convenience method for creating an BiddingSeasonalityAdjustmentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5775
5776
5777
5778
5779
5780
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5775

def self.bidding_seasonality_adjustment(path)
  require "google/ads/google_ads/v23/services/bidding_seasonality_adjustment_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BiddingSeasonalityAdjustmentOperation.new
  op["remove"] = path
  op
end

.bidding_strategy(path) ⇒ Object

A convenience method for creating an BiddingStrategyOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5786
5787
5788
5789
5790
5791
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5786

def self.bidding_strategy(path)
  require "google/ads/google_ads/v23/services/bidding_strategy_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BiddingStrategyOperation.new
  op["remove"] = path
  op
end

.billing_setup(path) ⇒ Object

A convenience method for creating an BillingSetupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6259
6260
6261
6262
6263
6264
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6259

def self.billing_setup(path)
  require "google/ads/google_ads/v23/services/billing_setup_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BillingSetupOperation.new
  op["remove"] = path
  op
end

.book_campaigns(path) ⇒ Object

A convenience method for creating an BookCampaignsOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5742
5743
5744
5745
5746
5747
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5742

def self.book_campaigns(path)
  require "google/ads/google_ads/v23/actions/book_campaigns_pb"
  op = Google::Ads::GoogleAds::V23::Actions::BookCampaignsOperation.new
  op["remove"] = path
  op
end

.campaign(path) ⇒ Object

A convenience method for creating an CampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5907
5908
5909
5910
5911
5912
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5907

def self.campaign(path)
  require "google/ads/google_ads/v23/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignOperation.new
  op["remove"] = path
  op
end

.campaign_asset(path) ⇒ Object

A convenience method for creating an CampaignAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5797
5798
5799
5800
5801
5802
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5797

def self.campaign_asset(path)
  require "google/ads/google_ads/v23/services/campaign_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignAssetOperation.new
  op["remove"] = path
  op
end

.campaign_asset_set(path) ⇒ Object

A convenience method for creating an CampaignAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5808
5809
5810
5811
5812
5813
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5808

def self.campaign_asset_set(path)
  require "google/ads/google_ads/v23/services/campaign_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignAssetSetOperation.new
  op["remove"] = path
  op
end

.campaign_bid_modifier(path) ⇒ Object

A convenience method for creating an CampaignBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5819
5820
5821
5822
5823
5824
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5819

def self.campaign_bid_modifier(path)
  require "google/ads/google_ads/v23/services/campaign_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignBidModifierOperation.new
  op["remove"] = path
  op
end

.campaign_budget(path) ⇒ Object

A convenience method for creating an CampaignBudgetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5830
5831
5832
5833
5834
5835
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5830

def self.campaign_budget(path)
  require "google/ads/google_ads/v23/services/campaign_budget_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignBudgetOperation.new
  op["remove"] = path
  op
end

.campaign_conversion_goal(path) ⇒ Object

A convenience method for creating an CampaignConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5841
5842
5843
5844
5845
5846
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5841

def self.campaign_conversion_goal(path)
  require "google/ads/google_ads/v23/services/campaign_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignConversionGoalOperation.new
  op["remove"] = path
  op
end

.campaign_criterion(path) ⇒ Object

A convenience method for creating an CampaignCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5852
5853
5854
5855
5856
5857
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5852

def self.campaign_criterion(path)
  require "google/ads/google_ads/v23/services/campaign_criterion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignCriterionOperation.new
  op["remove"] = path
  op
end

.campaign_customizer(path) ⇒ Object

A convenience method for creating an CampaignCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5863
5864
5865
5866
5867
5868
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5863

def self.campaign_customizer(path)
  require "google/ads/google_ads/v23/services/campaign_customizer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignCustomizerOperation.new
  op["remove"] = path
  op
end

.campaign_draft(path) ⇒ Object

A convenience method for creating an CampaignDraftOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5874
5875
5876
5877
5878
5879
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5874

def self.campaign_draft(path)
  require "google/ads/google_ads/v23/services/campaign_draft_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignDraftOperation.new
  op["remove"] = path
  op
end

.campaign_goal_config(path) ⇒ Object

A convenience method for creating an CampaignGoalConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6270
6271
6272
6273
6274
6275
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6270

def self.campaign_goal_config(path)
  require "google/ads/google_ads/v23/services/campaign_goal_config_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignGoalConfigOperation.new
  op["remove"] = path
  op
end

.campaign_group(path) ⇒ Object

A convenience method for creating an CampaignGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5885
5886
5887
5888
5889
5890
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5885

def self.campaign_group(path)
  require "google/ads/google_ads/v23/services/campaign_group_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignGroupOperation.new
  op["remove"] = path
  op
end

.campaign_label(path) ⇒ Object

A convenience method for creating an CampaignLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5896
5897
5898
5899
5900
5901
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5896

def self.campaign_label(path)
  require "google/ads/google_ads/v23/services/campaign_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignLabelOperation.new
  op["remove"] = path
  op
end

.campaign_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CampaignLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6281
6282
6283
6284
6285
6286
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6281

def self.campaign_lifecycle_goal(path)
  require "google/ads/google_ads/v23/services/campaign_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignLifecycleGoalOperation.new
  op["remove"] = path
  op
end

.campaign_shared_set(path) ⇒ Object

A convenience method for creating an CampaignSharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5929
5930
5931
5932
5933
5934
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5929

def self.campaign_shared_set(path)
  require "google/ads/google_ads/v23/services/campaign_shared_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignSharedSetOperation.new
  op["remove"] = path
  op
end

.conversion_action(path) ⇒ Object

A convenience method for creating an ConversionActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5940
5941
5942
5943
5944
5945
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5940

def self.conversion_action(path)
  require "google/ads/google_ads/v23/services/conversion_action_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionActionOperation.new
  op["remove"] = path
  op
end

.conversion_custom_variable(path) ⇒ Object

A convenience method for creating an ConversionCustomVariableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5951
5952
5953
5954
5955
5956
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5951

def self.conversion_custom_variable(path)
  require "google/ads/google_ads/v23/services/conversion_custom_variable_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionCustomVariableOperation.new
  op["remove"] = path
  op
end

.conversion_goal_campaign_config(path) ⇒ Object

A convenience method for creating an ConversionGoalCampaignConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5962
5963
5964
5965
5966
5967
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5962

def self.conversion_goal_campaign_config(path)
  require "google/ads/google_ads/v23/services/conversion_goal_campaign_config_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionGoalCampaignConfigOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule(path) ⇒ Object

A convenience method for creating an ConversionValueRuleOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5973
5974
5975
5976
5977
5978
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5973

def self.conversion_value_rule(path)
  require "google/ads/google_ads/v23/services/conversion_value_rule_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionValueRuleOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule_set(path) ⇒ Object

A convenience method for creating an ConversionValueRuleSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5984
5985
5986
5987
5988
5989
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5984

def self.conversion_value_rule_set(path)
  require "google/ads/google_ads/v23/services/conversion_value_rule_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionValueRuleSetOperation.new
  op["remove"] = path
  op
end

.custom_audience(path) ⇒ Object

A convenience method for creating an CustomAudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6292
6293
6294
6295
6296
6297
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6292

def self.custom_audience(path)
  require "google/ads/google_ads/v23/services/custom_audience_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomAudienceOperation.new
  op["remove"] = path
  op
end

.custom_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5995
5996
5997
5998
5999
6000
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5995

def self.custom_conversion_goal(path)
  require "google/ads/google_ads/v23/services/custom_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomConversionGoalOperation.new
  op["remove"] = path
  op
end

.custom_interest(path) ⇒ Object

A convenience method for creating an CustomInterestOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6303
6304
6305
6306
6307
6308
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6303

def self.custom_interest(path)
  require "google/ads/google_ads/v23/services/custom_interest_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomInterestOperation.new
  op["remove"] = path
  op
end

.customer(path) ⇒ Object

A convenience method for creating an CustomerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6061
6062
6063
6064
6065
6066
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6061

def self.customer(path)
  require "google/ads/google_ads/v23/services/customer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerOperation.new
  op["remove"] = path
  op
end

.customer_asset(path) ⇒ Object

A convenience method for creating an CustomerAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6006
6007
6008
6009
6010
6011
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6006

def self.customer_asset(path)
  require "google/ads/google_ads/v23/services/customer_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerAssetOperation.new
  op["remove"] = path
  op
end

.customer_asset_set(path) ⇒ Object

A convenience method for creating an CustomerAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6314
6315
6316
6317
6318
6319
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6314

def self.customer_asset_set(path)
  require "google/ads/google_ads/v23/services/customer_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerAssetSetOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerClientLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6325
6326
6327
6328
6329
6330
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6325

def self.customer_client_link(path)
  require "google/ads/google_ads/v23/services/customer_client_link_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerClientLinkOperation.new
  op["remove"] = path
  op
end

.customer_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomerConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6017
6018
6019
6020
6021
6022
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6017

def self.customer_conversion_goal(path)
  require "google/ads/google_ads/v23/services/customer_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerConversionGoalOperation.new
  op["remove"] = path
  op
end

.customer_customizer(path) ⇒ Object

A convenience method for creating an CustomerCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6028
6029
6030
6031
6032
6033
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6028

def self.customer_customizer(path)
  require "google/ads/google_ads/v23/services/customer_customizer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerCustomizerOperation.new
  op["remove"] = path
  op
end

.customer_label(path) ⇒ Object

A convenience method for creating an CustomerLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6039
6040
6041
6042
6043
6044
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6039

def self.customer_label(path)
  require "google/ads/google_ads/v23/services/customer_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerLabelOperation.new
  op["remove"] = path
  op
end

.customer_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CustomerLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6336
6337
6338
6339
6340
6341
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6336

def self.customer_lifecycle_goal(path)
  require "google/ads/google_ads/v23/services/customer_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerLifecycleGoalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerManagerLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6347
6348
6349
6350
6351
6352
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6347

def self.customer_manager_link(path)
  require "google/ads/google_ads/v23/services/customer_manager_link_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerManagerLinkOperation.new
  op["remove"] = path
  op
end

.customer_negative_criterion(path) ⇒ Object

A convenience method for creating an CustomerNegativeCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6050
6051
6052
6053
6054
6055
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6050

def self.customer_negative_criterion(path)
  require "google/ads/google_ads/v23/services/customer_negative_criterion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerNegativeCriterionOperation.new
  op["remove"] = path
  op
end

.customer_sk_ad_network_conversion_value_schema(path) ⇒ Object

A convenience method for creating an CustomerSkAdNetworkConversionValueSchemaOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6358
6359
6360
6361
6362
6363
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6358

def self.customer_sk_ad_network_conversion_value_schema(path)
  require "google/ads/google_ads/v23/services/customer_sk_ad_network_conversion_value_schema_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerSkAdNetworkConversionValueSchemaOperation.new
  op["remove"] = path
  op
end

.customer_user_access(path) ⇒ Object

A convenience method for creating an CustomerUserAccessOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6380
6381
6382
6383
6384
6385
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6380

def self.customer_user_access(path)
  require "google/ads/google_ads/v23/services/customer_user_access_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerUserAccessOperation.new
  op["remove"] = path
  op
end

.customer_user_access_invitation(path) ⇒ Object

A convenience method for creating an CustomerUserAccessInvitationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6369
6370
6371
6372
6373
6374
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6369

def self.customer_user_access_invitation(path)
  require "google/ads/google_ads/v23/services/customer_user_access_invitation_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerUserAccessInvitationOperation.new
  op["remove"] = path
  op
end

.customizer_attribute(path) ⇒ Object

A convenience method for creating an CustomizerAttributeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6072
6073
6074
6075
6076
6077
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6072

def self.customizer_attribute(path)
  require "google/ads/google_ads/v23/services/customizer_attribute_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomizerAttributeOperation.new
  op["remove"] = path
  op
end

.dismiss_recommendation(path) ⇒ Object

A convenience method for creating an DismissRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6424
6425
6426
6427
6428
6429
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6424

def self.dismiss_recommendation(path)
  require "google/ads/google_ads/v23/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::DismissRecommendationRequest::DismissRecommendationOperation.new
  op["remove"] = path
  op
end

.enable(path) ⇒ Object

A convenience method for creating an EnableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5918
5919
5920
5921
5922
5923
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5918

def self.enable(path)
  require "google/ads/google_ads/v23/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::EnableOperation.new
  op["remove"] = path
  op
end

.experiment(path) ⇒ Object

A convenience method for creating an ExperimentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6094
6095
6096
6097
6098
6099
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6094

def self.experiment(path)
  require "google/ads/google_ads/v23/services/experiment_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ExperimentOperation.new
  op["remove"] = path
  op
end

.experiment_arm(path) ⇒ Object

A convenience method for creating an ExperimentArmOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6083
6084
6085
6086
6087
6088
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6083

def self.experiment_arm(path)
  require "google/ads/google_ads/v23/services/experiment_arm_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ExperimentArmOperation.new
  op["remove"] = path
  op
end

.goal(path) ⇒ Object

A convenience method for creating an GoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6391
6392
6393
6394
6395
6396
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6391

def self.goal(path)
  require "google/ads/google_ads/v23/services/goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::GoalOperation.new
  op["remove"] = path
  op
end

.keyword_plan(path) ⇒ Object

A convenience method for creating an KeywordPlanOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6149
6150
6151
6152
6153
6154
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6149

def self.keyword_plan(path)
  require "google/ads/google_ads/v23/services/keyword_plan_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6116
6117
6118
6119
6120
6121
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6116

def self.keyword_plan_ad_group(path)
  require "google/ads/google_ads/v23/services/keyword_plan_ad_group_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanAdGroupOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6105
6106
6107
6108
6109
6110
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6105

def self.keyword_plan_ad_group_keyword(path)
  require "google/ads/google_ads/v23/services/keyword_plan_ad_group_keyword_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanAdGroupKeywordOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6138
6139
6140
6141
6142
6143
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6138

def self.keyword_plan_campaign(path)
  require "google/ads/google_ads/v23/services/keyword_plan_campaign_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanCampaignOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6127
6128
6129
6130
6131
6132
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6127

def self.keyword_plan_campaign_keyword(path)
  require "google/ads/google_ads/v23/services/keyword_plan_campaign_keyword_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanCampaignKeywordOperation.new
  op["remove"] = path
  op
end

.label(path) ⇒ Object

A convenience method for creating an LabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6160
6161
6162
6163
6164
6165
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6160

def self.label(path)
  require "google/ads/google_ads/v23/services/label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::LabelOperation.new
  op["remove"] = path
  op
end

.mutate(path) ⇒ Object

A convenience method for creating an MutateOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6237
6238
6239
6240
6241
6242
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6237

def self.mutate(path)
  require "google/ads/google_ads/v23/services/google_ads_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::MutateOperation.new
  op["remove"] = path
  op
end

.offline_user_data_job(path) ⇒ Object

A convenience method for creating an OfflineUserDataJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6402
6403
6404
6405
6406
6407
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6402

def self.offline_user_data_job(path)
  require "google/ads/google_ads/v23/services/offline_user_data_job_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::OfflineUserDataJobOperation.new
  op["remove"] = path
  op
end

.quote_campaigns(path) ⇒ Object

A convenience method for creating an QuoteCampaignsOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5753
5754
5755
5756
5757
5758
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5753

def self.quote_campaigns(path)
  require "google/ads/google_ads/v23/actions/quote_campaigns_pb"
  op = Google::Ads::GoogleAds::V23::Actions::QuoteCampaignsOperation.new
  op["remove"] = path
  op
end

.recommendation_subscription(path) ⇒ Object

A convenience method for creating an RecommendationSubscriptionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6171
6172
6173
6174
6175
6176
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6171

def self.recommendation_subscription(path)
  require "google/ads/google_ads/v23/services/recommendation_subscription_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::RecommendationSubscriptionOperation.new
  op["remove"] = path
  op
end

.remarketing_action(path) ⇒ Object

A convenience method for creating an RemarketingActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6182
6183
6184
6185
6186
6187
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6182

def self.remarketing_action(path)
  require "google/ads/google_ads/v23/services/remarketing_action_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::RemarketingActionOperation.new
  op["remove"] = path
  op
end

.remove_campaign_automatically_created_asset(path) ⇒ Object

A convenience method for creating an RemoveCampaignAutomaticallyCreatedAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5731
5732
5733
5734
5735
5736
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5731

def self.remove_campaign_automatically_created_asset(path)
  require "google/ads/google_ads/v23/services/automatically_created_asset_removal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::RemoveCampaignAutomaticallyCreatedAssetOperation.new
  op["remove"] = path
  op
end

.shared_criterion(path) ⇒ Object

A convenience method for creating an SharedCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6193
6194
6195
6196
6197
6198
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6193

def self.shared_criterion(path)
  require "google/ads/google_ads/v23/services/shared_criterion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::SharedCriterionOperation.new
  op["remove"] = path
  op
end

.shared_set(path) ⇒ Object

A convenience method for creating an SharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6204
6205
6206
6207
6208
6209
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6204

def self.shared_set(path)
  require "google/ads/google_ads/v23/services/shared_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::SharedSetOperation.new
  op["remove"] = path
  op
end

.smart_campaign_setting(path) ⇒ Object

A convenience method for creating an SmartCampaignSettingOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6215
6216
6217
6218
6219
6220
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6215

def self.smart_campaign_setting(path)
  require "google/ads/google_ads/v23/services/smart_campaign_setting_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::SmartCampaignSettingOperation.new
  op["remove"] = path
  op
end

.target_restriction(path) ⇒ Object

A convenience method for creating an TargetRestrictionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5467
5468
5469
5470
5471
5472
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5467

def self.target_restriction(path)
  require "google/ads/google_ads/v23/common/targeting_setting_pb"
  op = Google::Ads::GoogleAds::V23::Common::TargetRestrictionOperation.new
  op["remove"] = path
  op
end

.user_data(path) ⇒ Object

A convenience method for creating an UserDataOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6435
6436
6437
6438
6439
6440
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6435

def self.user_data(path)
  require "google/ads/google_ads/v23/services/user_data_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::UserDataOperation.new
  op["remove"] = path
  op
end

.user_list(path) ⇒ Object

A convenience method for creating an UserListOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6226
6227
6228
6229
6230
6231
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6226

def self.user_list(path)
  require "google/ads/google_ads/v23/services/user_list_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::UserListOperation.new
  op["remove"] = path
  op
end

.user_list_customer_type(path) ⇒ Object

A convenience method for creating an UserListCustomerTypeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6446
6447
6448
6449
6450
6451
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6446

def self.user_list_customer_type(path)
  require "google/ads/google_ads/v23/services/user_list_customer_type_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::UserListCustomerTypeOperation.new
  op["remove"] = path
  op
end