Module: Google::Ads::GoogleAds::Factories::V24::Operations::RemoveResource

Defined in:
lib/google/ads/google_ads/factories/v24/operations.rb

Class Method Summary collapse

Class Method Details

.account_budget_proposal(path) ⇒ Object

A convenience method for creating an AccountBudgetProposalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5506
5507
5508
5509
5510
5511
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5506

def self.(path)
  require "google/ads/google_ads/v24/services/account_budget_proposal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AccountBudgetProposalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an AccountLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5517
5518
5519
5520
5521
5522
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5517

def self.(path)
  require "google/ads/google_ads/v24/services/account_link_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AccountLinkOperation.new
  op["remove"] = path
  op
end

.ad(path) ⇒ Object

A convenience method for creating an AdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5660
5661
5662
5663
5664
5665
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5660

def self.ad(path)
  require "google/ads/google_ads/v24/services/ad_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdOperation.new
  op["remove"] = path
  op
end

.ad_group(path) ⇒ Object

A convenience method for creating an AdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5638
5639
5640
5641
5642
5643
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5638

def self.ad_group(path)
  require "google/ads/google_ads/v24/services/ad_group_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupOperation.new
  op["remove"] = path
  op
end

.ad_group_ad(path) ⇒ Object

A convenience method for creating an AdGroupAdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5539
5540
5541
5542
5543
5544
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5539

def self.ad_group_ad(path)
  require "google/ads/google_ads/v24/services/ad_group_ad_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupAdOperation.new
  op["remove"] = path
  op
end

.ad_group_ad_label(path) ⇒ Object

A convenience method for creating an AdGroupAdLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5528
5529
5530
5531
5532
5533
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5528

def self.ad_group_ad_label(path)
  require "google/ads/google_ads/v24/services/ad_group_ad_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupAdLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_asset(path) ⇒ Object

A convenience method for creating an AdGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5550
5551
5552
5553
5554
5555
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5550

def self.ad_group_asset(path)
  require "google/ads/google_ads/v24/services/ad_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupAssetOperation.new
  op["remove"] = path
  op
end

.ad_group_asset_set(path) ⇒ Object

A convenience method for creating an AdGroupAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5561
5562
5563
5564
5565
5566
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5561

def self.ad_group_asset_set(path)
  require "google/ads/google_ads/v24/services/ad_group_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupAssetSetOperation.new
  op["remove"] = path
  op
end

.ad_group_bid_modifier(path) ⇒ Object

A convenience method for creating an AdGroupBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5572
5573
5574
5575
5576
5577
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5572

def self.ad_group_bid_modifier(path)
  require "google/ads/google_ads/v24/services/ad_group_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupBidModifierOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion(path) ⇒ Object

A convenience method for creating an AdGroupCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5605
5606
5607
5608
5609
5610
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5605

def self.ad_group_criterion(path)
  require "google/ads/google_ads/v24/services/ad_group_criterion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupCriterionOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCriterionCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5583
5584
5585
5586
5587
5588
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5583

def self.ad_group_criterion_customizer(path)
  require "google/ads/google_ads/v24/services/ad_group_criterion_customizer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupCriterionCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_label(path) ⇒ Object

A convenience method for creating an AdGroupCriterionLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5594
5595
5596
5597
5598
5599
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5594

def self.ad_group_criterion_label(path)
  require "google/ads/google_ads/v24/services/ad_group_criterion_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupCriterionLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5616
5617
5618
5619
5620
5621
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5616

def self.ad_group_customizer(path)
  require "google/ads/google_ads/v24/services/ad_group_customizer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_label(path) ⇒ Object

A convenience method for creating an AdGroupLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5627
5628
5629
5630
5631
5632
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5627

def self.ad_group_label(path)
  require "google/ads/google_ads/v24/services/ad_group_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupLabelOperation.new
  op["remove"] = path
  op
end

.ad_parameter(path) ⇒ Object

A convenience method for creating an AdParameterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5649
5650
5651
5652
5653
5654
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5649

def self.ad_parameter(path)
  require "google/ads/google_ads/v24/services/ad_parameter_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdParameterOperation.new
  op["remove"] = path
  op
end

.apply_recommendation(path) ⇒ Object

A convenience method for creating an ApplyRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6452
6453
6454
6455
6456
6457
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6452

def self.apply_recommendation(path)
  require "google/ads/google_ads/v24/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ApplyRecommendationOperation.new
  op["remove"] = path
  op
end

.asset(path) ⇒ Object

A convenience method for creating an AssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5715
5716
5717
5718
5719
5720
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5715

def self.asset(path)
  require "google/ads/google_ads/v24/services/asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetOperation.new
  op["remove"] = path
  op
end

.asset_group(path) ⇒ Object

A convenience method for creating an AssetGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5693
5694
5695
5696
5697
5698
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5693

def self.asset_group(path)
  require "google/ads/google_ads/v24/services/asset_group_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetGroupOperation.new
  op["remove"] = path
  op
end

.asset_group_asset(path) ⇒ Object

A convenience method for creating an AssetGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5671
5672
5673
5674
5675
5676
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5671

def self.asset_group_asset(path)
  require "google/ads/google_ads/v24/services/asset_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetGroupAssetOperation.new
  op["remove"] = path
  op
end

.asset_group_listing_group_filter(path) ⇒ Object

A convenience method for creating an AssetGroupListingGroupFilterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5682
5683
5684
5685
5686
5687
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5682

def self.asset_group_listing_group_filter(path)
  require "google/ads/google_ads/v24/services/asset_group_listing_group_filter_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetGroupListingGroupFilterOperation.new
  op["remove"] = path
  op
end

.asset_group_signal(path) ⇒ Object

A convenience method for creating an AssetGroupSignalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5704
5705
5706
5707
5708
5709
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5704

def self.asset_group_signal(path)
  require "google/ads/google_ads/v24/services/asset_group_signal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetGroupSignalOperation.new
  op["remove"] = path
  op
end

.asset_set(path) ⇒ Object

A convenience method for creating an AssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5737
5738
5739
5740
5741
5742
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5737

def self.asset_set(path)
  require "google/ads/google_ads/v24/services/asset_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetSetOperation.new
  op["remove"] = path
  op
end

.asset_set_asset(path) ⇒ Object

A convenience method for creating an AssetSetAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5726
5727
5728
5729
5730
5731
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5726

def self.asset_set_asset(path)
  require "google/ads/google_ads/v24/services/asset_set_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetSetAssetOperation.new
  op["remove"] = path
  op
end

.audience(path) ⇒ Object

A convenience method for creating an AudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5748
5749
5750
5751
5752
5753
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5748

def self.audience(path)
  require "google/ads/google_ads/v24/services/audience_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AudienceOperation.new
  op["remove"] = path
  op
end

.batch_job(path) ⇒ Object

A convenience method for creating an BatchJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6276
6277
6278
6279
6280
6281
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6276

def self.batch_job(path)
  require "google/ads/google_ads/v24/services/batch_job_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BatchJobOperation.new
  op["remove"] = path
  op
end

.bidding_data_exclusion(path) ⇒ Object

A convenience method for creating an BiddingDataExclusionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5792
5793
5794
5795
5796
5797
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5792

def self.bidding_data_exclusion(path)
  require "google/ads/google_ads/v24/services/bidding_data_exclusion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BiddingDataExclusionOperation.new
  op["remove"] = path
  op
end

.bidding_seasonality_adjustment(path) ⇒ Object

A convenience method for creating an BiddingSeasonalityAdjustmentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5803
5804
5805
5806
5807
5808
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5803

def self.bidding_seasonality_adjustment(path)
  require "google/ads/google_ads/v24/services/bidding_seasonality_adjustment_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BiddingSeasonalityAdjustmentOperation.new
  op["remove"] = path
  op
end

.bidding_strategy(path) ⇒ Object

A convenience method for creating an BiddingStrategyOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5814
5815
5816
5817
5818
5819
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5814

def self.bidding_strategy(path)
  require "google/ads/google_ads/v24/services/bidding_strategy_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BiddingStrategyOperation.new
  op["remove"] = path
  op
end

.billing_setup(path) ⇒ Object

A convenience method for creating an BillingSetupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6287
6288
6289
6290
6291
6292
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6287

def self.billing_setup(path)
  require "google/ads/google_ads/v24/services/billing_setup_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BillingSetupOperation.new
  op["remove"] = path
  op
end

.book_campaigns(path) ⇒ Object

A convenience method for creating an BookCampaignsOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5770
5771
5772
5773
5774
5775
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5770

def self.book_campaigns(path)
  require "google/ads/google_ads/v24/actions/book_campaigns_pb"
  op = Google::Ads::GoogleAds::V24::Actions::BookCampaignsOperation.new
  op["remove"] = path
  op
end

.campaign(path) ⇒ Object

A convenience method for creating an CampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5935
5936
5937
5938
5939
5940
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5935

def self.campaign(path)
  require "google/ads/google_ads/v24/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignOperation.new
  op["remove"] = path
  op
end

.campaign_asset(path) ⇒ Object

A convenience method for creating an CampaignAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5825
5826
5827
5828
5829
5830
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5825

def self.campaign_asset(path)
  require "google/ads/google_ads/v24/services/campaign_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignAssetOperation.new
  op["remove"] = path
  op
end

.campaign_asset_set(path) ⇒ Object

A convenience method for creating an CampaignAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5836
5837
5838
5839
5840
5841
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5836

def self.campaign_asset_set(path)
  require "google/ads/google_ads/v24/services/campaign_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignAssetSetOperation.new
  op["remove"] = path
  op
end

.campaign_bid_modifier(path) ⇒ Object

A convenience method for creating an CampaignBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5847
5848
5849
5850
5851
5852
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5847

def self.campaign_bid_modifier(path)
  require "google/ads/google_ads/v24/services/campaign_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignBidModifierOperation.new
  op["remove"] = path
  op
end

.campaign_budget(path) ⇒ Object

A convenience method for creating an CampaignBudgetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5858
5859
5860
5861
5862
5863
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5858

def self.campaign_budget(path)
  require "google/ads/google_ads/v24/services/campaign_budget_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignBudgetOperation.new
  op["remove"] = path
  op
end

.campaign_conversion_goal(path) ⇒ Object

A convenience method for creating an CampaignConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5869
5870
5871
5872
5873
5874
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5869

def self.campaign_conversion_goal(path)
  require "google/ads/google_ads/v24/services/campaign_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignConversionGoalOperation.new
  op["remove"] = path
  op
end

.campaign_criterion(path) ⇒ Object

A convenience method for creating an CampaignCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5880
5881
5882
5883
5884
5885
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5880

def self.campaign_criterion(path)
  require "google/ads/google_ads/v24/services/campaign_criterion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignCriterionOperation.new
  op["remove"] = path
  op
end

.campaign_customizer(path) ⇒ Object

A convenience method for creating an CampaignCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5891
5892
5893
5894
5895
5896
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5891

def self.campaign_customizer(path)
  require "google/ads/google_ads/v24/services/campaign_customizer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignCustomizerOperation.new
  op["remove"] = path
  op
end

.campaign_draft(path) ⇒ Object

A convenience method for creating an CampaignDraftOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5902
5903
5904
5905
5906
5907
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5902

def self.campaign_draft(path)
  require "google/ads/google_ads/v24/services/campaign_draft_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignDraftOperation.new
  op["remove"] = path
  op
end

.campaign_goal_config(path) ⇒ Object

A convenience method for creating an CampaignGoalConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6298
6299
6300
6301
6302
6303
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6298

def self.campaign_goal_config(path)
  require "google/ads/google_ads/v24/services/campaign_goal_config_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignGoalConfigOperation.new
  op["remove"] = path
  op
end

.campaign_group(path) ⇒ Object

A convenience method for creating an CampaignGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5913
5914
5915
5916
5917
5918
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5913

def self.campaign_group(path)
  require "google/ads/google_ads/v24/services/campaign_group_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignGroupOperation.new
  op["remove"] = path
  op
end

.campaign_label(path) ⇒ Object

A convenience method for creating an CampaignLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5924
5925
5926
5927
5928
5929
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5924

def self.campaign_label(path)
  require "google/ads/google_ads/v24/services/campaign_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignLabelOperation.new
  op["remove"] = path
  op
end

.campaign_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CampaignLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6309
6310
6311
6312
6313
6314
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6309

def self.campaign_lifecycle_goal(path)
  require "google/ads/google_ads/v24/services/campaign_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignLifecycleGoalOperation.new
  op["remove"] = path
  op
end

.campaign_shared_set(path) ⇒ Object

A convenience method for creating an CampaignSharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5957
5958
5959
5960
5961
5962
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5957

def self.campaign_shared_set(path)
  require "google/ads/google_ads/v24/services/campaign_shared_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignSharedSetOperation.new
  op["remove"] = path
  op
end

.conversion_action(path) ⇒ Object

A convenience method for creating an ConversionActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5968
5969
5970
5971
5972
5973
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5968

def self.conversion_action(path)
  require "google/ads/google_ads/v24/services/conversion_action_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionActionOperation.new
  op["remove"] = path
  op
end

.conversion_custom_variable(path) ⇒ Object

A convenience method for creating an ConversionCustomVariableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5979
5980
5981
5982
5983
5984
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5979

def self.conversion_custom_variable(path)
  require "google/ads/google_ads/v24/services/conversion_custom_variable_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionCustomVariableOperation.new
  op["remove"] = path
  op
end

.conversion_goal_campaign_config(path) ⇒ Object

A convenience method for creating an ConversionGoalCampaignConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5990
5991
5992
5993
5994
5995
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5990

def self.conversion_goal_campaign_config(path)
  require "google/ads/google_ads/v24/services/conversion_goal_campaign_config_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionGoalCampaignConfigOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule(path) ⇒ Object

A convenience method for creating an ConversionValueRuleOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6001
6002
6003
6004
6005
6006
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6001

def self.conversion_value_rule(path)
  require "google/ads/google_ads/v24/services/conversion_value_rule_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionValueRuleOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule_set(path) ⇒ Object

A convenience method for creating an ConversionValueRuleSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6012
6013
6014
6015
6016
6017
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6012

def self.conversion_value_rule_set(path)
  require "google/ads/google_ads/v24/services/conversion_value_rule_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionValueRuleSetOperation.new
  op["remove"] = path
  op
end

.custom_audience(path) ⇒ Object

A convenience method for creating an CustomAudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6320
6321
6322
6323
6324
6325
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6320

def self.custom_audience(path)
  require "google/ads/google_ads/v24/services/custom_audience_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomAudienceOperation.new
  op["remove"] = path
  op
end

.custom_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6023
6024
6025
6026
6027
6028
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6023

def self.custom_conversion_goal(path)
  require "google/ads/google_ads/v24/services/custom_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomConversionGoalOperation.new
  op["remove"] = path
  op
end

.custom_interest(path) ⇒ Object

A convenience method for creating an CustomInterestOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6331
6332
6333
6334
6335
6336
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6331

def self.custom_interest(path)
  require "google/ads/google_ads/v24/services/custom_interest_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomInterestOperation.new
  op["remove"] = path
  op
end

.customer(path) ⇒ Object

A convenience method for creating an CustomerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6089
6090
6091
6092
6093
6094
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6089

def self.customer(path)
  require "google/ads/google_ads/v24/services/customer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerOperation.new
  op["remove"] = path
  op
end

.customer_asset(path) ⇒ Object

A convenience method for creating an CustomerAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6034
6035
6036
6037
6038
6039
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6034

def self.customer_asset(path)
  require "google/ads/google_ads/v24/services/customer_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerAssetOperation.new
  op["remove"] = path
  op
end

.customer_asset_set(path) ⇒ Object

A convenience method for creating an CustomerAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6342
6343
6344
6345
6346
6347
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6342

def self.customer_asset_set(path)
  require "google/ads/google_ads/v24/services/customer_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerAssetSetOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerClientLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6353
6354
6355
6356
6357
6358
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6353

def self.customer_client_link(path)
  require "google/ads/google_ads/v24/services/customer_client_link_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerClientLinkOperation.new
  op["remove"] = path
  op
end

.customer_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomerConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6045
6046
6047
6048
6049
6050
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6045

def self.customer_conversion_goal(path)
  require "google/ads/google_ads/v24/services/customer_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerConversionGoalOperation.new
  op["remove"] = path
  op
end

.customer_customizer(path) ⇒ Object

A convenience method for creating an CustomerCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6056
6057
6058
6059
6060
6061
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6056

def self.customer_customizer(path)
  require "google/ads/google_ads/v24/services/customer_customizer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerCustomizerOperation.new
  op["remove"] = path
  op
end

.customer_label(path) ⇒ Object

A convenience method for creating an CustomerLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6067
6068
6069
6070
6071
6072
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6067

def self.customer_label(path)
  require "google/ads/google_ads/v24/services/customer_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerLabelOperation.new
  op["remove"] = path
  op
end

.customer_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CustomerLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6364
6365
6366
6367
6368
6369
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6364

def self.customer_lifecycle_goal(path)
  require "google/ads/google_ads/v24/services/customer_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerLifecycleGoalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerManagerLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6375
6376
6377
6378
6379
6380
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6375

def self.customer_manager_link(path)
  require "google/ads/google_ads/v24/services/customer_manager_link_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerManagerLinkOperation.new
  op["remove"] = path
  op
end

.customer_negative_criterion(path) ⇒ Object

A convenience method for creating an CustomerNegativeCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6078
6079
6080
6081
6082
6083
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6078

def self.customer_negative_criterion(path)
  require "google/ads/google_ads/v24/services/customer_negative_criterion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerNegativeCriterionOperation.new
  op["remove"] = path
  op
end

.customer_sk_ad_network_conversion_value_schema(path) ⇒ Object

A convenience method for creating an CustomerSkAdNetworkConversionValueSchemaOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6386
6387
6388
6389
6390
6391
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6386

def self.customer_sk_ad_network_conversion_value_schema(path)
  require "google/ads/google_ads/v24/services/customer_sk_ad_network_conversion_value_schema_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerSkAdNetworkConversionValueSchemaOperation.new
  op["remove"] = path
  op
end

.customer_user_access(path) ⇒ Object

A convenience method for creating an CustomerUserAccessOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6408
6409
6410
6411
6412
6413
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6408

def self.customer_user_access(path)
  require "google/ads/google_ads/v24/services/customer_user_access_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerUserAccessOperation.new
  op["remove"] = path
  op
end

.customer_user_access_invitation(path) ⇒ Object

A convenience method for creating an CustomerUserAccessInvitationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6397
6398
6399
6400
6401
6402
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6397

def self.customer_user_access_invitation(path)
  require "google/ads/google_ads/v24/services/customer_user_access_invitation_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerUserAccessInvitationOperation.new
  op["remove"] = path
  op
end

.customizer_attribute(path) ⇒ Object

A convenience method for creating an CustomizerAttributeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6100
6101
6102
6103
6104
6105
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6100

def self.customizer_attribute(path)
  require "google/ads/google_ads/v24/services/customizer_attribute_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomizerAttributeOperation.new
  op["remove"] = path
  op
end

.dismiss_recommendation(path) ⇒ Object

A convenience method for creating an DismissRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6463
6464
6465
6466
6467
6468
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6463

def self.dismiss_recommendation(path)
  require "google/ads/google_ads/v24/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::DismissRecommendationRequest::DismissRecommendationOperation.new
  op["remove"] = path
  op
end

.enable(path) ⇒ Object

A convenience method for creating an EnableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5946
5947
5948
5949
5950
5951
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5946

def self.enable(path)
  require "google/ads/google_ads/v24/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::EnableOperation.new
  op["remove"] = path
  op
end

.experiment(path) ⇒ Object

A convenience method for creating an ExperimentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6122
6123
6124
6125
6126
6127
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6122

def self.experiment(path)
  require "google/ads/google_ads/v24/services/experiment_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ExperimentOperation.new
  op["remove"] = path
  op
end

.experiment_arm(path) ⇒ Object

A convenience method for creating an ExperimentArmOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6111
6112
6113
6114
6115
6116
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6111

def self.experiment_arm(path)
  require "google/ads/google_ads/v24/services/experiment_arm_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ExperimentArmOperation.new
  op["remove"] = path
  op
end

.generate_shareable_previews(path) ⇒ Object

A convenience method for creating an GenerateShareablePreviewsOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6474
6475
6476
6477
6478
6479
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6474

def self.generate_shareable_previews(path)
  require "google/ads/google_ads/v24/actions/generate_shareable_previews_pb"
  op = Google::Ads::GoogleAds::V24::Actions::GenerateShareablePreviewsOperation.new
  op["remove"] = path
  op
end

.goal(path) ⇒ Object

A convenience method for creating an GoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6419
6420
6421
6422
6423
6424
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6419

def self.goal(path)
  require "google/ads/google_ads/v24/services/goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::GoalOperation.new
  op["remove"] = path
  op
end

.keyword_plan(path) ⇒ Object

A convenience method for creating an KeywordPlanOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6177
6178
6179
6180
6181
6182
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6177

def self.keyword_plan(path)
  require "google/ads/google_ads/v24/services/keyword_plan_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6144
6145
6146
6147
6148
6149
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6144

def self.keyword_plan_ad_group(path)
  require "google/ads/google_ads/v24/services/keyword_plan_ad_group_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanAdGroupOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6133
6134
6135
6136
6137
6138
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6133

def self.keyword_plan_ad_group_keyword(path)
  require "google/ads/google_ads/v24/services/keyword_plan_ad_group_keyword_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanAdGroupKeywordOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6166
6167
6168
6169
6170
6171
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6166

def self.keyword_plan_campaign(path)
  require "google/ads/google_ads/v24/services/keyword_plan_campaign_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanCampaignOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6155
6156
6157
6158
6159
6160
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6155

def self.keyword_plan_campaign_keyword(path)
  require "google/ads/google_ads/v24/services/keyword_plan_campaign_keyword_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanCampaignKeywordOperation.new
  op["remove"] = path
  op
end

.label(path) ⇒ Object

A convenience method for creating an LabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6188
6189
6190
6191
6192
6193
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6188

def self.label(path)
  require "google/ads/google_ads/v24/services/label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::LabelOperation.new
  op["remove"] = path
  op
end

.mutate(path) ⇒ Object

A convenience method for creating an MutateOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6265
6266
6267
6268
6269
6270
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6265

def self.mutate(path)
  require "google/ads/google_ads/v24/services/google_ads_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::MutateOperation.new
  op["remove"] = path
  op
end

.offline_user_data_job(path) ⇒ Object

A convenience method for creating an OfflineUserDataJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6441
6442
6443
6444
6445
6446
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6441

def self.offline_user_data_job(path)
  require "google/ads/google_ads/v24/services/offline_user_data_job_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::OfflineUserDataJobOperation.new
  op["remove"] = path
  op
end

.quote_campaigns(path) ⇒ Object

A convenience method for creating an QuoteCampaignsOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5781
5782
5783
5784
5785
5786
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5781

def self.quote_campaigns(path)
  require "google/ads/google_ads/v24/actions/quote_campaigns_pb"
  op = Google::Ads::GoogleAds::V24::Actions::QuoteCampaignsOperation.new
  op["remove"] = path
  op
end

.recommendation_subscription(path) ⇒ Object

A convenience method for creating an RecommendationSubscriptionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6199
6200
6201
6202
6203
6204
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6199

def self.recommendation_subscription(path)
  require "google/ads/google_ads/v24/services/recommendation_subscription_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::RecommendationSubscriptionOperation.new
  op["remove"] = path
  op
end

.remarketing_action(path) ⇒ Object

A convenience method for creating an RemarketingActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6210
6211
6212
6213
6214
6215
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6210

def self.remarketing_action(path)
  require "google/ads/google_ads/v24/services/remarketing_action_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::RemarketingActionOperation.new
  op["remove"] = path
  op
end

.remove_campaign_automatically_created_asset(path) ⇒ Object

A convenience method for creating an RemoveCampaignAutomaticallyCreatedAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5759
5760
5761
5762
5763
5764
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5759

def self.remove_campaign_automatically_created_asset(path)
  require "google/ads/google_ads/v24/services/automatically_created_asset_removal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::RemoveCampaignAutomaticallyCreatedAssetOperation.new
  op["remove"] = path
  op
end

.resolve_multi_party_auth_review(path) ⇒ Object

A convenience method for creating an ResolveMultiPartyAuthReviewOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6430
6431
6432
6433
6434
6435
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6430

def self.resolve_multi_party_auth_review(path)
  require "google/ads/google_ads/v24/services/multi_party_auth_review_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ResolveMultiPartyAuthReviewOperation.new
  op["remove"] = path
  op
end

.shared_criterion(path) ⇒ Object

A convenience method for creating an SharedCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6221
6222
6223
6224
6225
6226
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6221

def self.shared_criterion(path)
  require "google/ads/google_ads/v24/services/shared_criterion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::SharedCriterionOperation.new
  op["remove"] = path
  op
end

.shared_set(path) ⇒ Object

A convenience method for creating an SharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6232
6233
6234
6235
6236
6237
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6232

def self.shared_set(path)
  require "google/ads/google_ads/v24/services/shared_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::SharedSetOperation.new
  op["remove"] = path
  op
end

.smart_campaign_setting(path) ⇒ Object

A convenience method for creating an SmartCampaignSettingOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6243
6244
6245
6246
6247
6248
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6243

def self.smart_campaign_setting(path)
  require "google/ads/google_ads/v24/services/smart_campaign_setting_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::SmartCampaignSettingOperation.new
  op["remove"] = path
  op
end

.target_restriction(path) ⇒ Object

A convenience method for creating an TargetRestrictionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5495
5496
5497
5498
5499
5500
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5495

def self.target_restriction(path)
  require "google/ads/google_ads/v24/common/targeting_setting_pb"
  op = Google::Ads::GoogleAds::V24::Common::TargetRestrictionOperation.new
  op["remove"] = path
  op
end

.user_data(path) ⇒ Object

A convenience method for creating an UserDataOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6485
6486
6487
6488
6489
6490
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6485

def self.user_data(path)
  require "google/ads/google_ads/v24/services/user_data_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::UserDataOperation.new
  op["remove"] = path
  op
end

.user_list(path) ⇒ Object

A convenience method for creating an UserListOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6254
6255
6256
6257
6258
6259
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6254

def self.user_list(path)
  require "google/ads/google_ads/v24/services/user_list_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::UserListOperation.new
  op["remove"] = path
  op
end

.user_list_customer_type(path) ⇒ Object

A convenience method for creating an UserListCustomerTypeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6496
6497
6498
6499
6500
6501
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6496

def self.user_list_customer_type(path)
  require "google/ads/google_ads/v24/services/user_list_customer_type_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::UserListCustomerTypeOperation.new
  op["remove"] = path
  op
end