Class: Google::Ads::GoogleAds::V21::Services::CustomerLabelService::Service
- Inherits:
-
Object
- Object
- Google::Ads::GoogleAds::V21::Services::CustomerLabelService::Service
- Includes:
- GRPC::GenericService
- Defined in:
- lib/google/ads/google_ads/v21/services/customer_label_service_services_pb.rb
Overview
Proto file describing the Customer Label service.
Service to manage labels on Google Ads customers.
This service is commonly used by manager accounts to apply their own labels to their client accounts. The label entity must exist under the manager account.