Class: Google::Ads::GoogleAds::V21::Services::ShareablePreviewService::Client
- Inherits:
-
Object
- Object
- Google::Ads::GoogleAds::V21::Services::ShareablePreviewService::Client
- Defined in:
- lib/google/ads/google_ads/v21/services/shareable_preview_service/client.rb
Overview
Client for the ShareablePreviewService service.
Service to generate Shareable Previews.
Only Performance Max asset groups are supported. Other ad types, such as Responsive Search Ads or Responsive Display Ads, are not supported and return an ‘UNSUPPORTED_AD_TYPE` error.
The generated preview URLs cannot be embedded in an iframe because the response headers include ‘X-Frame-Options: deny`.
Defined Under Namespace
Classes: Configuration
Constant Summary collapse
- API_VERSION =
""- DEFAULT_ENDPOINT_TEMPLATE =
"googleads.$UNIVERSE_DOMAIN$"
Instance Attribute Summary collapse
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the ShareablePreviewService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the ShareablePreviewService Client instance.
-
#generate_shareable_previews(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::GoogleAds::V21::Services::GenerateShareablePreviewsResponse
Returns the requested Shareable Preview.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new ShareablePreviewService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new ShareablePreviewService client object.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/google/ads/google_ads/v21/services/shareable_preview_service/client.rb', line 128 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/ads/google_ads/v21/services/shareable_preview_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @shareable_preview_service_stub = ::Gapic::ServiceStub.new( ::Google::Ads::GoogleAds::V21::Services::ShareablePreviewService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @shareable_preview_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#shareable_preview_service_stub ⇒ Object (readonly)
48 49 50 |
# File 'lib/google/ads/google_ads/v21/services/shareable_preview_service/client.rb', line 48 def shareable_preview_service_stub @shareable_preview_service_stub end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the ShareablePreviewService Client class.
See Configuration for a description of the configuration fields.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/google/ads/google_ads/v21/services/shareable_preview_service/client.rb', line 68 def self.configure @configure ||= begin default_config = Client::Configuration.new default_config.timeout = 14_400.0 default_config.retry_policy = { initial_delay: 5.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the ShareablePreviewService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
98 99 100 101 |
# File 'lib/google/ads/google_ads/v21/services/shareable_preview_service/client.rb', line 98 def configure yield @config if block_given? @config end |
#generate_shareable_previews(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V21::Services::GenerateShareablePreviewsResponse #generate_shareable_previews(customer_id: nil, shareable_previews: nil) ⇒ ::Google::Ads::GoogleAds::V21::Services::GenerateShareablePreviewsResponse
Returns the requested Shareable Preview.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/google/ads/google_ads/v21/services/shareable_preview_service/client.rb', line 236 def generate_shareable_previews request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V21::Services::GenerateShareablePreviewsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.generate_shareable_previews..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::GoogleAds::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.customer_id header_params["customer_id"] = request.customer_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.generate_shareable_previews.timeout, metadata: , retry_policy: @config.rpcs.generate_shareable_previews.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @shareable_preview_service_stub.call_rpc :generate_shareable_previews, request, options: do |response, operation| yield response, operation if block_given? end # rescue GRPC::BadStatus => grpc_error # raise Google::Ads::GoogleAds::Error.new grpc_error.message end |
#logger ⇒ Logger
The logger used for request/response debug logging.
184 185 186 |
# File 'lib/google/ads/google_ads/v21/services/shareable_preview_service/client.rb', line 184 def logger @shareable_preview_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
108 109 110 |
# File 'lib/google/ads/google_ads/v21/services/shareable_preview_service/client.rb', line 108 def universe_domain @shareable_preview_service_stub.universe_domain end |