Class: Google::Ads::GoogleAds::V21::Services::ShareablePreviewService::Service
- Inherits:
-
Object
- Object
- Google::Ads::GoogleAds::V21::Services::ShareablePreviewService::Service
- Includes:
- GRPC::GenericService
- Defined in:
- lib/google/ads/google_ads/v21/services/shareable_preview_service_services_pb.rb
Overview
Service to generate Shareable Previews.
Only Performance Max asset groups are supported. Other ad types, such as Responsive Search Ads or Responsive Display Ads, are not supported and return an ‘UNSUPPORTED_AD_TYPE` error.
The generated preview URLs cannot be embedded in an iframe because the response headers include ‘X-Frame-Options: deny`.