Module: Google::Ads::GoogleAds::V22::Services::CustomerLabelService

Defined in:
lib/google/ads/google_ads/v22/services/customer_label_service.rb,
lib/google/ads/google_ads/v22/services/customer_label_service/paths.rb,
lib/google/ads/google_ads/v22/services/customer_label_service/client.rb,
lib/google/ads/google_ads/v22/services/customer_label_service/credentials.rb,
lib/google/ads/google_ads/v22/services/customer_label_service_services_pb.rb

Overview

Service to manage labels on Google Ads customers.

This service is commonly used by manager accounts to apply their own labels to their client accounts. The label entity must exist under the manager account.

Examples:

Load this service and instantiate a gRPC client


require "google/ads/google_ads/v22/services/customer_label_service"
client = ::Google::Ads::GoogleAds::V22::Services::CustomerLabelService::Client.new

Defined Under Namespace

Modules: Paths Classes: Client, Credentials, Service

Constant Summary collapse

Stub =
Service.rpc_stub_class