Class: Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb

Overview

Client for the BenchmarksService service.

BenchmarksService helps users compare YouTube advertisement data against industry benchmarks. Accessible to allowlisted customers only.

Defined Under Namespace

Classes: Configuration

Constant Summary collapse

API_VERSION =
""
DEFAULT_ENDPOINT_TEMPLATE =
"googleads.$UNIVERSE_DOMAIN$"

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new BenchmarksService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the BenchmarksService client.

Yield Parameters:



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 122

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/ads/google_ads/v23/services/benchmarks_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @benchmarks_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Ads::GoogleAds::V23::Services::BenchmarksService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @benchmarks_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Instance Attribute Details

#benchmarks_service_stubObject (readonly)



42
43
44
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 42

def benchmarks_service_stub
  @benchmarks_service_stub
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the BenchmarksService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all BenchmarksService clients
::Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 62

def self.configure
  @configure ||= begin
    default_config = Client::Configuration.new

    default_config.timeout = 14_400.0
    default_config.retry_policy = {
      initial_delay: 5.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the BenchmarksService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



92
93
94
95
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 92

def configure
  yield @config if block_given?
  @config
end

#generate_benchmarks_metrics(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::GenerateBenchmarksMetricsResponse #generate_benchmarks_metrics(customer_id: nil, date_range: nil, location: nil, benchmarks_source: nil, product_filter: nil, breakdown_definition: nil, currency_code: nil, customer_benchmarks_group: nil, application_info: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::GenerateBenchmarksMetricsResponse

Returns YouTube advertisement metrics for the given client against industry benchmarks.

List of thrown errors:

[AuthenticationError]()
[AuthorizationError]()
[BenchmarksError]()
[FieldError]()
[HeaderError]()
[InternalError]()
[QuotaError]()
[RangeError]()
[RequestError]()

Examples:

Basic example

require "google/ads/google_ads/v23/services"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::GoogleAds::V23::Services::GenerateBenchmarksMetricsRequest.new

# Call the generate_benchmarks_metrics method.
result = client.generate_benchmarks_metrics request

# The returned object is of type Google::Ads::GoogleAds::V23::Services::GenerateBenchmarksMetricsResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Ads::GoogleAds::Error)

    if the RPC is aborted.



616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 616

def generate_benchmarks_metrics request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::GenerateBenchmarksMetricsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.generate_benchmarks_metrics..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::GoogleAds::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.customer_id
    header_params["customer_id"] = request.customer_id
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.generate_benchmarks_metrics.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.generate_benchmarks_metrics.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @benchmarks_service_stub.call_rpc :generate_benchmarks_metrics, request,
                                    options: options do |response, operation|
    yield response, operation if block_given?
  end
  # rescue GRPC::BadStatus => grpc_error
  #  raise Google::Ads::GoogleAds::Error.new grpc_error.message
end

#list_benchmarks_available_dates(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksAvailableDatesResponse #list_benchmarks_available_dates(application_info: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksAvailableDatesResponse

Returns a date range that supports benchmarks.

List of thrown errors:

[AuthenticationError]()
[AuthorizationError]()
[FieldError]()
[HeaderError]()
[InternalError]()
[QuotaError]()
[RequestError]()

Examples:

Basic example

require "google/ads/google_ads/v23/services"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::GoogleAds::V23::Services::ListBenchmarksAvailableDatesRequest.new

# Call the list_benchmarks_available_dates method.
result = client.list_benchmarks_available_dates request

# The returned object is of type Google::Ads::GoogleAds::V23::Services::ListBenchmarksAvailableDatesResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Ads::GoogleAds::Error)

    if the RPC is aborted.



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 237

def list_benchmarks_available_dates request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksAvailableDatesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_benchmarks_available_dates..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::GoogleAds::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_benchmarks_available_dates.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_benchmarks_available_dates.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @benchmarks_service_stub.call_rpc :list_benchmarks_available_dates, request,
                                    options: options do |response, operation|
    yield response, operation if block_given?
  end
  # rescue GRPC::BadStatus => grpc_error
  #  raise Google::Ads::GoogleAds::Error.new grpc_error.message
end

#list_benchmarks_locations(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksLocationsResponse #list_benchmarks_locations(application_info: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksLocationsResponse

Returns the list of locations that support benchmarks (for example, countries).

List of thrown errors:

[AuthenticationError]()
[AuthorizationError]()
[FieldError]()
[HeaderError]()
[InternalError]()
[QuotaError]()
[RequestError]()

Examples:

Basic example

require "google/ads/google_ads/v23/services"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::GoogleAds::V23::Services::ListBenchmarksLocationsRequest.new

# Call the list_benchmarks_locations method.
result = client.list_benchmarks_locations request

# The returned object is of type Google::Ads::GoogleAds::V23::Services::ListBenchmarksLocationsResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Ads::GoogleAds::Error)

    if the RPC is aborted.



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 325

def list_benchmarks_locations request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksLocationsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_benchmarks_locations..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::GoogleAds::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_benchmarks_locations.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_benchmarks_locations.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @benchmarks_service_stub.call_rpc :list_benchmarks_locations, request,
                                    options: options do |response, operation|
    yield response, operation if block_given?
  end
  # rescue GRPC::BadStatus => grpc_error
  #  raise Google::Ads::GoogleAds::Error.new grpc_error.message
end

#list_benchmarks_products(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksProductsResponse #list_benchmarks_products(application_info: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksProductsResponse

Returns the list of products that supports benchmarks.

List of thrown errors:

[AuthenticationError]()
[AuthorizationError]()
[FieldError]()
[HeaderError]()
[InternalError]()
[QuotaError]()
[RequestError]()

Examples:

Basic example

require "google/ads/google_ads/v23/services"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::GoogleAds::V23::Services::ListBenchmarksProductsRequest.new

# Call the list_benchmarks_products method.
result = client.list_benchmarks_products request

# The returned object is of type Google::Ads::GoogleAds::V23::Services::ListBenchmarksProductsResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Ads::GoogleAds::Error)

    if the RPC is aborted.



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 412

def list_benchmarks_products request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksProductsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_benchmarks_products..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::GoogleAds::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_benchmarks_products.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_benchmarks_products.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @benchmarks_service_stub.call_rpc :list_benchmarks_products, request,
                                    options: options do |response, operation|
    yield response, operation if block_given?
  end
  # rescue GRPC::BadStatus => grpc_error
  #  raise Google::Ads::GoogleAds::Error.new grpc_error.message
end

#list_benchmarks_sources(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksSourcesResponse #list_benchmarks_sources(benchmarks_sources: nil, application_info: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksSourcesResponse

Returns the list of benchmarks sources (for example, Industry Verticals).

List of thrown errors:

[AuthenticationError]()
[AuthorizationError]()
[FieldError]()
[HeaderError]()
[InternalError]()
[QuotaError]()
[RequestError]()

Examples:

Basic example

require "google/ads/google_ads/v23/services"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::GoogleAds::V23::Services::BenchmarksService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::GoogleAds::V23::Services::ListBenchmarksSourcesRequest.new

# Call the list_benchmarks_sources method.
result = client.list_benchmarks_sources request

# The returned object is of type Google::Ads::GoogleAds::V23::Services::ListBenchmarksSourcesResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Ads::GoogleAds::Error)

    if the RPC is aborted.



502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 502

def list_benchmarks_sources request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::ListBenchmarksSourcesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_benchmarks_sources..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::GoogleAds::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_benchmarks_sources.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_benchmarks_sources.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @benchmarks_service_stub.call_rpc :list_benchmarks_sources, request,
                                    options: options do |response, operation|
    yield response, operation if block_given?
  end
  # rescue GRPC::BadStatus => grpc_error
  #  raise Google::Ads::GoogleAds::Error.new grpc_error.message
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


178
179
180
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 178

def logger
  @benchmarks_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


102
103
104
# File 'lib/google/ads/google_ads/v23/services/benchmarks_service/client.rb', line 102

def universe_domain
  @benchmarks_service_stub.universe_domain
end