Class: Google::Ads::GoogleAds::V23::Services::IncentiveService::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/ads/google_ads/v23/services/incentive_service/client.rb

Overview

Client for the IncentiveService service.

Service to support incentive related operations.

Defined Under Namespace

Classes: Configuration

Constant Summary collapse

API_VERSION =
""
DEFAULT_ENDPOINT_TEMPLATE =
"googleads.$UNIVERSE_DOMAIN$"

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new IncentiveService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::GoogleAds::V23::Services::IncentiveService::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::GoogleAds::V23::Services::IncentiveService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the IncentiveService client.

Yield Parameters:



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/google/ads/google_ads/v23/services/incentive_service/client.rb', line 121

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/ads/google_ads/v23/services/incentive_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @incentive_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Ads::GoogleAds::V23::Services::IncentiveService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @incentive_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Instance Attribute Details

#incentive_service_stubObject (readonly)



41
42
43
# File 'lib/google/ads/google_ads/v23/services/incentive_service/client.rb', line 41

def incentive_service_stub
  @incentive_service_stub
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the IncentiveService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all IncentiveService clients
::Google::Ads::GoogleAds::V23::Services::IncentiveService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/google/ads/google_ads/v23/services/incentive_service/client.rb', line 61

def self.configure
  @configure ||= begin
    default_config = Client::Configuration.new

    default_config.timeout = 14_400.0
    default_config.retry_policy = {
      initial_delay: 5.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#apply_incentive(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ApplyIncentiveResponse #apply_incentive(selected_incentive_id: nil, customer_id: nil, country_code: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ApplyIncentiveResponse

Applies the incentive for the ads customer.

Examples:

Basic example

require "google/ads/google_ads/v23/services"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::GoogleAds::V23::Services::IncentiveService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::GoogleAds::V23::Services::ApplyIncentiveRequest.new

# Call the apply_incentive method.
result = client.apply_incentive request

# The returned object is of type Google::Ads::GoogleAds::V23::Services::ApplyIncentiveResponse.
p result

Overloads:

  • #apply_incentive(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ApplyIncentiveResponse

    Pass arguments to ‘apply_incentive` via a request object, either of type ApplyIncentiveRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::GoogleAds::V23::Services::ApplyIncentiveRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #apply_incentive(selected_incentive_id: nil, customer_id: nil, country_code: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::ApplyIncentiveResponse

    Pass arguments to ‘apply_incentive` via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • selected_incentive_id (::Integer) (defaults to: nil)

      The incentive ID of this incentive. This is used to identify which incentive is selected by the user in the CYO flow.

    • customer_id (::String) (defaults to: nil)

      The customer ID of the account that the incentive is being applied to.

    • country_code (::String) (defaults to: nil)

      Required. User’s country code. Required. This field must be equal to the Google Ads account’s billing country. Incentive eligibility, terms of service, and reward values are often country-specific. This country code is used to ensure the selected incentive is applicable to the user. Possible country codes: developers.google.com/google-ads/api/data/codes-formats#country_codes

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Ads::GoogleAds::Error)

    if the RPC is aborted.



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/google/ads/google_ads/v23/services/incentive_service/client.rb', line 330

def apply_incentive request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::ApplyIncentiveRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.apply_incentive..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::GoogleAds::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.customer_id
    header_params["customer_id"] = request.customer_id
  end
  if request.selected_incentive_id
    header_params["selected_incentive_id"] = request.selected_incentive_id
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.apply_incentive.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.apply_incentive.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @incentive_service_stub.call_rpc :apply_incentive, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
  # rescue GRPC::BadStatus => grpc_error
  #  raise Google::Ads::GoogleAds::Error.new grpc_error.message
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the IncentiveService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



91
92
93
94
# File 'lib/google/ads/google_ads/v23/services/incentive_service/client.rb', line 91

def configure
  yield @config if block_given?
  @config
end

#fetch_incentive(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::FetchIncentiveResponse #fetch_incentive(language_code: nil, country_code: nil, email: nil, type: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::FetchIncentiveResponse

Returns incentives for a given user.

Examples:

Basic example

require "google/ads/google_ads/v23/services"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::GoogleAds::V23::Services::IncentiveService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::GoogleAds::V23::Services::FetchIncentiveRequest.new

# Call the fetch_incentive method.
result = client.fetch_incentive request

# The returned object is of type Google::Ads::GoogleAds::V23::Services::FetchIncentiveResponse.
p result

Overloads:

  • #fetch_incentive(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::FetchIncentiveResponse

    Pass arguments to ‘fetch_incentive` via a request object, either of type FetchIncentiveRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::GoogleAds::V23::Services::FetchIncentiveRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #fetch_incentive(language_code: nil, country_code: nil, email: nil, type: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::FetchIncentiveResponse

    Pass arguments to ‘fetch_incentive` via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • language_code (::String) (defaults to: nil)

      Optional. User’s language code. If not provided, the server will default to “en”. Possible language codes: developers.google.com/google-ads/api/data/codes-formats#languages

    • country_code (::String) (defaults to: nil)

      Optional. User’s country code. If not provided, the server will default to “US”. Possible country codes: developers.google.com/google-ads/api/data/codes-formats#country_codes

    • email (::String) (defaults to: nil)

      Optional. Email of the user that the requested incentive is meant for. Will be used for channel partners who do NOT use OAuth to authenticate on behalf of user.

    • type (::Google::Ads::GoogleAds::V23::Services::FetchIncentiveRequest::IncentiveType) (defaults to: nil)

      Optional. The type of incentive to get. Defaults to ACQUISITION.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Ads::GoogleAds::Error)

    if the RPC is aborted.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/google/ads/google_ads/v23/services/incentive_service/client.rb', line 242

def fetch_incentive request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::FetchIncentiveRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.fetch_incentive..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::GoogleAds::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.fetch_incentive.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.fetch_incentive.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @incentive_service_stub.call_rpc :fetch_incentive, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
  # rescue GRPC::BadStatus => grpc_error
  #  raise Google::Ads::GoogleAds::Error.new grpc_error.message
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


177
178
179
# File 'lib/google/ads/google_ads/v23/services/incentive_service/client.rb', line 177

def logger
  @incentive_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


101
102
103
# File 'lib/google/ads/google_ads/v23/services/incentive_service/client.rb', line 101

def universe_domain
  @incentive_service_stub.universe_domain
end