Class: Google::Ads::GoogleAds::V23::Services::ReservationService::Client
- Inherits:
-
Object
- Object
- Google::Ads::GoogleAds::V23::Services::ReservationService::Client
- Defined in:
- lib/google/ads/google_ads/v23/services/reservation_service/client.rb
Overview
Client for the ReservationService service.
Service for reservation related operations. This service is not publicly available.
Defined Under Namespace
Classes: Configuration
Constant Summary collapse
- API_VERSION =
""- DEFAULT_ENDPOINT_TEMPLATE =
"googleads.$UNIVERSE_DOMAIN$"
Instance Attribute Summary collapse
- #reservation_service_stub ⇒ Object readonly
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the ReservationService Client class.
Instance Method Summary collapse
-
#book_campaigns(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::GoogleAds::V23::Services::BookCampaignsResponse
Books the requested campaigns.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the ReservationService Client instance.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new ReservationService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#quote_campaigns(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::GoogleAds::V23::Services::QuoteCampaignsResponse
Proposes quotes for booking campaigns.
-
#universe_domain ⇒ String
The effective universe domain.
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new ReservationService client object.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/google/ads/google_ads/v23/services/reservation_service/client.rb', line 122 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/ads/google_ads/v23/services/reservation_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @reservation_service_stub = ::Gapic::ServiceStub.new( ::Google::Ads::GoogleAds::V23::Services::ReservationService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @reservation_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#reservation_service_stub ⇒ Object (readonly)
42 43 44 |
# File 'lib/google/ads/google_ads/v23/services/reservation_service/client.rb', line 42 def reservation_service_stub @reservation_service_stub end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the ReservationService Client class.
See Configuration for a description of the configuration fields.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/google/ads/google_ads/v23/services/reservation_service/client.rb', line 62 def self.configure @configure ||= begin default_config = Client::Configuration.new default_config.timeout = 14_400.0 default_config.retry_policy = { initial_delay: 5.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#book_campaigns(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::BookCampaignsResponse #book_campaigns(customer_id: nil, operation: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::BookCampaignsResponse
Books the requested campaigns. This request can have a latency of 30 seconds.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/google/ads/google_ads/v23/services/reservation_service/client.rb', line 319 def book_campaigns request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::BookCampaignsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.book_campaigns..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::GoogleAds::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.customer_id header_params["customer_id"] = request.customer_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.book_campaigns.timeout, metadata: , retry_policy: @config.rpcs.book_campaigns.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @reservation_service_stub.call_rpc :book_campaigns, request, options: do |response, operation| yield response, operation if block_given? end # rescue GRPC::BadStatus => grpc_error # raise Google::Ads::GoogleAds::Error.new grpc_error.message end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the ReservationService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
92 93 94 95 |
# File 'lib/google/ads/google_ads/v23/services/reservation_service/client.rb', line 92 def configure yield @config if block_given? @config end |
#logger ⇒ Logger
The logger used for request/response debug logging.
178 179 180 |
# File 'lib/google/ads/google_ads/v23/services/reservation_service/client.rb', line 178 def logger @reservation_service_stub.logger end |
#quote_campaigns(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::QuoteCampaignsResponse #quote_campaigns(customer_id: nil, operation: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::QuoteCampaignsResponse
Proposes quotes for booking campaigns. This request can have a latency of 30 seconds.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/google/ads/google_ads/v23/services/reservation_service/client.rb', line 231 def quote_campaigns request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::QuoteCampaignsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.quote_campaigns..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::GoogleAds::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.customer_id header_params["customer_id"] = request.customer_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.quote_campaigns.timeout, metadata: , retry_policy: @config.rpcs.quote_campaigns.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @reservation_service_stub.call_rpc :quote_campaigns, request, options: do |response, operation| yield response, operation if block_given? end # rescue GRPC::BadStatus => grpc_error # raise Google::Ads::GoogleAds::Error.new grpc_error.message end |
#universe_domain ⇒ String
The effective universe domain
102 103 104 |
# File 'lib/google/ads/google_ads/v23/services/reservation_service/client.rb', line 102 def universe_domain @reservation_service_stub.universe_domain end |