Class: Google::Ads::GoogleAds::V23::Services::ShareablePreviewService::Service

Inherits:
Object
  • Object
show all
Includes:
GRPC::GenericService
Defined in:
lib/google/ads/google_ads/v23/services/shareable_preview_service_services_pb.rb

Overview

Service to generate Shareable Previews.

Only Performance Max asset groups and certain YouTube video/audio ad formats are supported. Other ad types, such as Responsive Search Ads or Responsive Display Ads, are not supported and return an ‘UNSUPPORTED_AD_TYPE` error.

The generated preview URLs cannot be embedded in an iframe because the response headers include ‘X-Frame-Options: deny`.