Class: Google::Ads::GoogleAds::V23::Services::YouTubeVideoUploadService::Client
- Inherits:
-
Object
- Object
- Google::Ads::GoogleAds::V23::Services::YouTubeVideoUploadService::Client
- Includes:
- Paths
- Defined in:
- lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb
Overview
Client for the YouTubeVideoUploadService service.
Service to manage YouTube video uploads.
Defined Under Namespace
Classes: Configuration
Constant Summary collapse
- API_VERSION =
""- DEFAULT_ENDPOINT_TEMPLATE =
"googleads.$UNIVERSE_DOMAIN$"
Instance Attribute Summary collapse
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the YouTubeVideoUploadService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the YouTubeVideoUploadService Client instance.
-
#create_you_tube_video_upload(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::GoogleAds::V23::Services::CreateYouTubeVideoUploadResponse
Uploads a video to Google-managed or advertiser owned (brand) YouTube channel.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new YouTubeVideoUploadService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#remove_you_tube_video_upload(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::GoogleAds::V23::Services::RemoveYouTubeVideoUploadResponse
Removes YouTube videos uploaded using this API.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_you_tube_video_upload(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::GoogleAds::V23::Services::UpdateYouTubeVideoUploadResponse
Updates YouTube video’s metadata, but only for videos uploaded using this API.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new YouTubeVideoUploadService client object.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 123 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/ads/google_ads/v23/services/youtube_video_upload_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @you_tube_video_upload_service_stub = ::Gapic::ServiceStub.new( ::Google::Ads::GoogleAds::V23::Services::YouTubeVideoUploadService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @you_tube_video_upload_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#you_tube_video_upload_service_stub ⇒ Object (readonly)
43 44 45 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 43 def you_tube_video_upload_service_stub @you_tube_video_upload_service_stub end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the YouTubeVideoUploadService Client class.
See Configuration for a description of the configuration fields.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 63 def self.configure @configure ||= begin default_config = Client::Configuration.new default_config.timeout = 14_400.0 default_config.retry_policy = { initial_delay: 5.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the YouTubeVideoUploadService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
93 94 95 96 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 93 def configure yield @config if block_given? @config end |
#create_you_tube_video_upload(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::CreateYouTubeVideoUploadResponse #create_you_tube_video_upload(customer_id: nil, you_tube_video_upload: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::CreateYouTubeVideoUploadResponse
Uploads a video to Google-managed or advertiser owned (brand) YouTube channel.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 232 def create_you_tube_video_upload request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::CreateYouTubeVideoUploadRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_you_tube_video_upload..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::GoogleAds::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.customer_id header_params["customer_id"] = request.customer_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_you_tube_video_upload.timeout, metadata: , retry_policy: @config.rpcs.create_you_tube_video_upload.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @you_tube_video_upload_service_stub.call_rpc :create_you_tube_video_upload, request, options: do |response, operation| yield response, operation if block_given? end # rescue GRPC::BadStatus => grpc_error # raise Google::Ads::GoogleAds::Error.new grpc_error.message end |
#logger ⇒ Logger
The logger used for request/response debug logging.
179 180 181 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 179 def logger @you_tube_video_upload_service_stub.logger end |
#remove_you_tube_video_upload(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::RemoveYouTubeVideoUploadResponse #remove_you_tube_video_upload(customer_id: nil, resource_names: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::RemoveYouTubeVideoUploadResponse
Removes YouTube videos uploaded using this API.
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 415 def remove_you_tube_video_upload request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::RemoveYouTubeVideoUploadRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.remove_you_tube_video_upload..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::GoogleAds::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.customer_id header_params["customer_id"] = request.customer_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.remove_you_tube_video_upload.timeout, metadata: , retry_policy: @config.rpcs.remove_you_tube_video_upload.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @you_tube_video_upload_service_stub.call_rpc :remove_you_tube_video_upload, request, options: do |response, operation| yield response, operation if block_given? end # rescue GRPC::BadStatus => grpc_error # raise Google::Ads::GoogleAds::Error.new grpc_error.message end |
#universe_domain ⇒ String
The effective universe domain
103 104 105 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 103 def universe_domain @you_tube_video_upload_service_stub.universe_domain end |
#update_you_tube_video_upload(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::UpdateYouTubeVideoUploadResponse #update_you_tube_video_upload(customer_id: nil, you_tube_video_upload: nil, update_mask: nil) ⇒ ::Google::Ads::GoogleAds::V23::Services::UpdateYouTubeVideoUploadResponse
Updates YouTube video’s metadata, but only for videos uploaded using this API.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/google/ads/google_ads/v23/services/you_tube_video_upload_service/client.rb', line 326 def update_you_tube_video_upload request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V23::Services::UpdateYouTubeVideoUploadRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_you_tube_video_upload..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::GoogleAds::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.customer_id header_params["customer_id"] = request.customer_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_you_tube_video_upload.timeout, metadata: , retry_policy: @config.rpcs.update_you_tube_video_upload.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @you_tube_video_upload_service_stub.call_rpc :update_you_tube_video_upload, request, options: do |response, operation| yield response, operation if block_given? end # rescue GRPC::BadStatus => grpc_error # raise Google::Ads::GoogleAds::Error.new grpc_error.message end |