Module: Google::Ads::GoogleAds::V24::Services::ContentCreatorInsightsService
- Defined in:
- lib/google/ads/google_ads/v24/services/content_creator_insights_service.rb,
lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb,
lib/google/ads/google_ads/v24/services/content_creator_insights_service/credentials.rb,
lib/google/ads/google_ads/v24/services/content_creator_insights_service_services_pb.rb
Overview
Content Creator Insights Service helps users find information about YouTube Creators and their content and how these creators and their audiences can be reached with Google Ads. Refer to the [YouTube creator insights guide](developers.google.com/google-ads/api/docs/insights/creator-insights) for more details. Accessible to allowlisted customers only.
Defined Under Namespace
Classes: Client, Credentials, Service
Constant Summary collapse
- Stub =
Service.rpc_stub_class