Class: Google::Ads::GoogleAds::V24::Services::ContentCreatorInsightsService::Client
- Inherits:
-
Object
- Object
- Google::Ads::GoogleAds::V24::Services::ContentCreatorInsightsService::Client
- Defined in:
- lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb
Overview
Client for the ContentCreatorInsightsService service.
Content Creator Insights Service helps users find information about YouTube Creators and their content and how these creators and their audiences can be reached with Google Ads. Refer to the [YouTube creator insights guide](developers.google.com/google-ads/api/docs/insights/creator-insights) for more details. Accessible to allowlisted customers only.
Defined Under Namespace
Classes: Configuration
Constant Summary collapse
- API_VERSION =
""- DEFAULT_ENDPOINT_TEMPLATE =
"googleads.$UNIVERSE_DOMAIN$"
Instance Attribute Summary collapse
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the ContentCreatorInsightsService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the ContentCreatorInsightsService Client instance.
-
#generate_creator_insights(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::GoogleAds::V24::Services::GenerateCreatorInsightsResponse
Returns insights for a collection of YouTube Creators and Channels.
-
#generate_trending_insights(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::GoogleAds::V24::Services::GenerateTrendingInsightsResponse
Returns insights for trending content on YouTube.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new ContentCreatorInsightsService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new ContentCreatorInsightsService client object.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb', line 126 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/ads/google_ads/v24/services/content_creator_insights_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @content_creator_insights_service_stub = ::Gapic::ServiceStub.new( ::Google::Ads::GoogleAds::V24::Services::ContentCreatorInsightsService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @content_creator_insights_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#content_creator_insights_service_stub ⇒ Object (readonly)
46 47 48 |
# File 'lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb', line 46 def content_creator_insights_service_stub @content_creator_insights_service_stub end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the ContentCreatorInsightsService Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb', line 66 def self.configure @configure ||= begin default_config = Client::Configuration.new default_config.timeout = 14_400.0 default_config.retry_policy = { initial_delay: 5.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the ContentCreatorInsightsService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
96 97 98 99 |
# File 'lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb', line 96 def configure yield @config if block_given? @config end |
#generate_creator_insights(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V24::Services::GenerateCreatorInsightsResponse #generate_creator_insights(customer_id: nil, customer_insights_group: nil, insights_application_info: nil, country_locations: nil, sub_country_locations: nil, supplemental_data: nil, search_attributes: nil, search_brand: nil, search_channels: nil, search_topics: nil) ⇒ ::Google::Ads::GoogleAds::V24::Services::GenerateCreatorInsightsResponse
Returns insights for a collection of YouTube Creators and Channels.
List of thrown errors:
[AuthenticationError]()
[AuthorizationError]()
[FieldError]()
[HeaderError]()
[InternalError]()
[QuotaError]()
[RangeError]()
[RequestError]()
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb', line 287 def generate_creator_insights request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V24::Services::GenerateCreatorInsightsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.generate_creator_insights..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::GoogleAds::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.customer_id header_params["customer_id"] = request.customer_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.generate_creator_insights.timeout, metadata: , retry_policy: @config.rpcs.generate_creator_insights.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @content_creator_insights_service_stub.call_rpc :generate_creator_insights, request, options: do |response, operation| yield response, operation if block_given? end # rescue GRPC::BadStatus => grpc_error # raise Google::Ads::GoogleAds::Error.new grpc_error.message end |
#generate_trending_insights(request, options = nil) ⇒ ::Google::Ads::GoogleAds::V24::Services::GenerateTrendingInsightsResponse #generate_trending_insights(customer_id: nil, customer_insights_group: nil, insights_application_info: nil, country_location: nil, sub_country_locations: nil, supplemental_data: nil, search_audience: nil, search_topics: nil) ⇒ ::Google::Ads::GoogleAds::V24::Services::GenerateTrendingInsightsResponse
Returns insights for trending content on YouTube.
List of thrown errors:
[AuthenticationError]()
[AuthorizationError]()
[FieldError]()
[HeaderError]()
[InternalError]()
[QuotaError]()
[RangeError]()
[RequestError]()
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb', line 409 def generate_trending_insights request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::GoogleAds::V24::Services::GenerateTrendingInsightsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.generate_trending_insights..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::GoogleAds::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.customer_id header_params["customer_id"] = request.customer_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.generate_trending_insights.timeout, metadata: , retry_policy: @config.rpcs.generate_trending_insights.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @content_creator_insights_service_stub.call_rpc :generate_trending_insights, request, options: do |response, operation| yield response, operation if block_given? end # rescue GRPC::BadStatus => grpc_error # raise Google::Ads::GoogleAds::Error.new grpc_error.message end |
#logger ⇒ Logger
The logger used for request/response debug logging.
182 183 184 |
# File 'lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb', line 182 def logger @content_creator_insights_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
106 107 108 |
# File 'lib/google/ads/google_ads/v24/services/content_creator_insights_service/client.rb', line 106 def universe_domain @content_creator_insights_service_stub.universe_domain end |