Class: Google::Ads::GoogleAds::V24::Services::CustomerLabelService::Service

Inherits:
Object
  • Object
show all
Includes:
GRPC::GenericService
Defined in:
lib/google/ads/google_ads/v24/services/customer_label_service_services_pb.rb

Overview

Proto file describing the Customer Label service.

Service to manage labels on Google Ads customers.

This service is commonly used by manager accounts to apply their own labels to their client accounts. The label entity must exist under the manager account.