Module: Google::Ads::GoogleAds::V24::Services::ShareablePreviewService
- Defined in:
- lib/google/ads/google_ads/v24/services/shareable_preview_service.rb,
lib/google/ads/google_ads/v24/services/shareable_preview_service/client.rb,
lib/google/ads/google_ads/v24/services/shareable_preview_service/credentials.rb,
lib/google/ads/google_ads/v24/services/shareable_preview_service_services_pb.rb
Overview
Service to generate Shareable Previews.
Only Performance Max asset groups and certain YouTube video/audio ad formats
are supported. Other ad types, such as Responsive Search Ads or Responsive
Display Ads, are not supported and return an UNSUPPORTED_AD_TYPE error.
The generated preview URLs cannot be embedded in an iframe because the
response headers include X-Frame-Options: deny.
Defined Under Namespace
Classes: Client, Credentials, Service
Constant Summary collapse
- Stub =
Service.rpc_stub_class