Module: Google::Ads::GoogleAds::Factories::V23::Operations::RemoveResource

Defined in:
lib/google/ads/google_ads/factories/v23/operations.rb

Class Method Summary collapse

Class Method Details

.account_budget_proposal(path) ⇒ Object

A convenience method for creating an AccountBudgetProposalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5450
5451
5452
5453
5454
5455
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5450

def self.(path)
  require "google/ads/google_ads/v23/services/account_budget_proposal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AccountBudgetProposalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an AccountLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5461
5462
5463
5464
5465
5466
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5461

def self.(path)
  require "google/ads/google_ads/v23/services/account_link_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AccountLinkOperation.new
  op["remove"] = path
  op
end

.ad(path) ⇒ Object

A convenience method for creating an AdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5604
5605
5606
5607
5608
5609
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5604

def self.ad(path)
  require "google/ads/google_ads/v23/services/ad_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdOperation.new
  op["remove"] = path
  op
end

.ad_group(path) ⇒ Object

A convenience method for creating an AdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5582
5583
5584
5585
5586
5587
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5582

def self.ad_group(path)
  require "google/ads/google_ads/v23/services/ad_group_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupOperation.new
  op["remove"] = path
  op
end

.ad_group_ad(path) ⇒ Object

A convenience method for creating an AdGroupAdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5483
5484
5485
5486
5487
5488
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5483

def self.ad_group_ad(path)
  require "google/ads/google_ads/v23/services/ad_group_ad_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupAdOperation.new
  op["remove"] = path
  op
end

.ad_group_ad_label(path) ⇒ Object

A convenience method for creating an AdGroupAdLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5472
5473
5474
5475
5476
5477
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5472

def self.ad_group_ad_label(path)
  require "google/ads/google_ads/v23/services/ad_group_ad_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupAdLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_asset(path) ⇒ Object

A convenience method for creating an AdGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5494
5495
5496
5497
5498
5499
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5494

def self.ad_group_asset(path)
  require "google/ads/google_ads/v23/services/ad_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupAssetOperation.new
  op["remove"] = path
  op
end

.ad_group_asset_set(path) ⇒ Object

A convenience method for creating an AdGroupAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5505
5506
5507
5508
5509
5510
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5505

def self.ad_group_asset_set(path)
  require "google/ads/google_ads/v23/services/ad_group_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupAssetSetOperation.new
  op["remove"] = path
  op
end

.ad_group_bid_modifier(path) ⇒ Object

A convenience method for creating an AdGroupBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5516
5517
5518
5519
5520
5521
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5516

def self.ad_group_bid_modifier(path)
  require "google/ads/google_ads/v23/services/ad_group_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupBidModifierOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion(path) ⇒ Object

A convenience method for creating an AdGroupCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5549
5550
5551
5552
5553
5554
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5549

def self.ad_group_criterion(path)
  require "google/ads/google_ads/v23/services/ad_group_criterion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupCriterionOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCriterionCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5527
5528
5529
5530
5531
5532
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5527

def self.ad_group_criterion_customizer(path)
  require "google/ads/google_ads/v23/services/ad_group_criterion_customizer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupCriterionCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_label(path) ⇒ Object

A convenience method for creating an AdGroupCriterionLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5538
5539
5540
5541
5542
5543
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5538

def self.ad_group_criterion_label(path)
  require "google/ads/google_ads/v23/services/ad_group_criterion_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupCriterionLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5560
5561
5562
5563
5564
5565
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5560

def self.ad_group_customizer(path)
  require "google/ads/google_ads/v23/services/ad_group_customizer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_label(path) ⇒ Object

A convenience method for creating an AdGroupLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5571
5572
5573
5574
5575
5576
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5571

def self.ad_group_label(path)
  require "google/ads/google_ads/v23/services/ad_group_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdGroupLabelOperation.new
  op["remove"] = path
  op
end

.ad_parameter(path) ⇒ Object

A convenience method for creating an AdParameterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5593
5594
5595
5596
5597
5598
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5593

def self.ad_parameter(path)
  require "google/ads/google_ads/v23/services/ad_parameter_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AdParameterOperation.new
  op["remove"] = path
  op
end

.apply_recommendation(path) ⇒ Object

A convenience method for creating an ApplyRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6363
6364
6365
6366
6367
6368
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6363

def self.apply_recommendation(path)
  require "google/ads/google_ads/v23/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ApplyRecommendationOperation.new
  op["remove"] = path
  op
end

.asset(path) ⇒ Object

A convenience method for creating an AssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5659
5660
5661
5662
5663
5664
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5659

def self.asset(path)
  require "google/ads/google_ads/v23/services/asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetOperation.new
  op["remove"] = path
  op
end

.asset_group(path) ⇒ Object

A convenience method for creating an AssetGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5637
5638
5639
5640
5641
5642
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5637

def self.asset_group(path)
  require "google/ads/google_ads/v23/services/asset_group_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetGroupOperation.new
  op["remove"] = path
  op
end

.asset_group_asset(path) ⇒ Object

A convenience method for creating an AssetGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5615
5616
5617
5618
5619
5620
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5615

def self.asset_group_asset(path)
  require "google/ads/google_ads/v23/services/asset_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetGroupAssetOperation.new
  op["remove"] = path
  op
end

.asset_group_listing_group_filter(path) ⇒ Object

A convenience method for creating an AssetGroupListingGroupFilterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5626
5627
5628
5629
5630
5631
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5626

def self.asset_group_listing_group_filter(path)
  require "google/ads/google_ads/v23/services/asset_group_listing_group_filter_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetGroupListingGroupFilterOperation.new
  op["remove"] = path
  op
end

.asset_group_signal(path) ⇒ Object

A convenience method for creating an AssetGroupSignalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5648
5649
5650
5651
5652
5653
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5648

def self.asset_group_signal(path)
  require "google/ads/google_ads/v23/services/asset_group_signal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetGroupSignalOperation.new
  op["remove"] = path
  op
end

.asset_set(path) ⇒ Object

A convenience method for creating an AssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5681
5682
5683
5684
5685
5686
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5681

def self.asset_set(path)
  require "google/ads/google_ads/v23/services/asset_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetSetOperation.new
  op["remove"] = path
  op
end

.asset_set_asset(path) ⇒ Object

A convenience method for creating an AssetSetAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5670
5671
5672
5673
5674
5675
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5670

def self.asset_set_asset(path)
  require "google/ads/google_ads/v23/services/asset_set_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AssetSetAssetOperation.new
  op["remove"] = path
  op
end

.audience(path) ⇒ Object

A convenience method for creating an AudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5692
5693
5694
5695
5696
5697
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5692

def self.audience(path)
  require "google/ads/google_ads/v23/services/audience_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::AudienceOperation.new
  op["remove"] = path
  op
end

.batch_job(path) ⇒ Object

A convenience method for creating an BatchJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6198
6199
6200
6201
6202
6203
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6198

def self.batch_job(path)
  require "google/ads/google_ads/v23/services/batch_job_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BatchJobOperation.new
  op["remove"] = path
  op
end

.bidding_data_exclusion(path) ⇒ Object

A convenience method for creating an BiddingDataExclusionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5714
5715
5716
5717
5718
5719
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5714

def self.bidding_data_exclusion(path)
  require "google/ads/google_ads/v23/services/bidding_data_exclusion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BiddingDataExclusionOperation.new
  op["remove"] = path
  op
end

.bidding_seasonality_adjustment(path) ⇒ Object

A convenience method for creating an BiddingSeasonalityAdjustmentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5725
5726
5727
5728
5729
5730
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5725

def self.bidding_seasonality_adjustment(path)
  require "google/ads/google_ads/v23/services/bidding_seasonality_adjustment_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BiddingSeasonalityAdjustmentOperation.new
  op["remove"] = path
  op
end

.bidding_strategy(path) ⇒ Object

A convenience method for creating an BiddingStrategyOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5736
5737
5738
5739
5740
5741
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5736

def self.bidding_strategy(path)
  require "google/ads/google_ads/v23/services/bidding_strategy_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BiddingStrategyOperation.new
  op["remove"] = path
  op
end

.billing_setup(path) ⇒ Object

A convenience method for creating an BillingSetupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6209
6210
6211
6212
6213
6214
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6209

def self.billing_setup(path)
  require "google/ads/google_ads/v23/services/billing_setup_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::BillingSetupOperation.new
  op["remove"] = path
  op
end

.campaign(path) ⇒ Object

A convenience method for creating an CampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5857
5858
5859
5860
5861
5862
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5857

def self.campaign(path)
  require "google/ads/google_ads/v23/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignOperation.new
  op["remove"] = path
  op
end

.campaign_asset(path) ⇒ Object

A convenience method for creating an CampaignAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5747
5748
5749
5750
5751
5752
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5747

def self.campaign_asset(path)
  require "google/ads/google_ads/v23/services/campaign_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignAssetOperation.new
  op["remove"] = path
  op
end

.campaign_asset_set(path) ⇒ Object

A convenience method for creating an CampaignAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5758
5759
5760
5761
5762
5763
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5758

def self.campaign_asset_set(path)
  require "google/ads/google_ads/v23/services/campaign_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignAssetSetOperation.new
  op["remove"] = path
  op
end

.campaign_bid_modifier(path) ⇒ Object

A convenience method for creating an CampaignBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5769
5770
5771
5772
5773
5774
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5769

def self.campaign_bid_modifier(path)
  require "google/ads/google_ads/v23/services/campaign_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignBidModifierOperation.new
  op["remove"] = path
  op
end

.campaign_budget(path) ⇒ Object

A convenience method for creating an CampaignBudgetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5780
5781
5782
5783
5784
5785
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5780

def self.campaign_budget(path)
  require "google/ads/google_ads/v23/services/campaign_budget_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignBudgetOperation.new
  op["remove"] = path
  op
end

.campaign_conversion_goal(path) ⇒ Object

A convenience method for creating an CampaignConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5791
5792
5793
5794
5795
5796
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5791

def self.campaign_conversion_goal(path)
  require "google/ads/google_ads/v23/services/campaign_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignConversionGoalOperation.new
  op["remove"] = path
  op
end

.campaign_criterion(path) ⇒ Object

A convenience method for creating an CampaignCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5802
5803
5804
5805
5806
5807
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5802

def self.campaign_criterion(path)
  require "google/ads/google_ads/v23/services/campaign_criterion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignCriterionOperation.new
  op["remove"] = path
  op
end

.campaign_customizer(path) ⇒ Object

A convenience method for creating an CampaignCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5813
5814
5815
5816
5817
5818
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5813

def self.campaign_customizer(path)
  require "google/ads/google_ads/v23/services/campaign_customizer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignCustomizerOperation.new
  op["remove"] = path
  op
end

.campaign_draft(path) ⇒ Object

A convenience method for creating an CampaignDraftOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5824
5825
5826
5827
5828
5829
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5824

def self.campaign_draft(path)
  require "google/ads/google_ads/v23/services/campaign_draft_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignDraftOperation.new
  op["remove"] = path
  op
end

.campaign_goal_config(path) ⇒ Object

A convenience method for creating an CampaignGoalConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6220
6221
6222
6223
6224
6225
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6220

def self.campaign_goal_config(path)
  require "google/ads/google_ads/v23/services/campaign_goal_config_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignGoalConfigOperation.new
  op["remove"] = path
  op
end

.campaign_group(path) ⇒ Object

A convenience method for creating an CampaignGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5835
5836
5837
5838
5839
5840
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5835

def self.campaign_group(path)
  require "google/ads/google_ads/v23/services/campaign_group_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignGroupOperation.new
  op["remove"] = path
  op
end

.campaign_label(path) ⇒ Object

A convenience method for creating an CampaignLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5846
5847
5848
5849
5850
5851
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5846

def self.campaign_label(path)
  require "google/ads/google_ads/v23/services/campaign_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignLabelOperation.new
  op["remove"] = path
  op
end

.campaign_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CampaignLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6231
6232
6233
6234
6235
6236
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6231

def self.campaign_lifecycle_goal(path)
  require "google/ads/google_ads/v23/services/campaign_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignLifecycleGoalOperation.new
  op["remove"] = path
  op
end

.campaign_shared_set(path) ⇒ Object

A convenience method for creating an CampaignSharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5879
5880
5881
5882
5883
5884
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5879

def self.campaign_shared_set(path)
  require "google/ads/google_ads/v23/services/campaign_shared_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CampaignSharedSetOperation.new
  op["remove"] = path
  op
end

.conversion_action(path) ⇒ Object

A convenience method for creating an ConversionActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5890
5891
5892
5893
5894
5895
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5890

def self.conversion_action(path)
  require "google/ads/google_ads/v23/services/conversion_action_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionActionOperation.new
  op["remove"] = path
  op
end

.conversion_custom_variable(path) ⇒ Object

A convenience method for creating an ConversionCustomVariableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5901
5902
5903
5904
5905
5906
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5901

def self.conversion_custom_variable(path)
  require "google/ads/google_ads/v23/services/conversion_custom_variable_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionCustomVariableOperation.new
  op["remove"] = path
  op
end

.conversion_goal_campaign_config(path) ⇒ Object

A convenience method for creating an ConversionGoalCampaignConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5912
5913
5914
5915
5916
5917
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5912

def self.conversion_goal_campaign_config(path)
  require "google/ads/google_ads/v23/services/conversion_goal_campaign_config_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionGoalCampaignConfigOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule(path) ⇒ Object

A convenience method for creating an ConversionValueRuleOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5923
5924
5925
5926
5927
5928
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5923

def self.conversion_value_rule(path)
  require "google/ads/google_ads/v23/services/conversion_value_rule_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionValueRuleOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule_set(path) ⇒ Object

A convenience method for creating an ConversionValueRuleSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5934
5935
5936
5937
5938
5939
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5934

def self.conversion_value_rule_set(path)
  require "google/ads/google_ads/v23/services/conversion_value_rule_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ConversionValueRuleSetOperation.new
  op["remove"] = path
  op
end

.custom_audience(path) ⇒ Object

A convenience method for creating an CustomAudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6242
6243
6244
6245
6246
6247
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6242

def self.custom_audience(path)
  require "google/ads/google_ads/v23/services/custom_audience_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomAudienceOperation.new
  op["remove"] = path
  op
end

.custom_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5945
5946
5947
5948
5949
5950
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5945

def self.custom_conversion_goal(path)
  require "google/ads/google_ads/v23/services/custom_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomConversionGoalOperation.new
  op["remove"] = path
  op
end

.custom_interest(path) ⇒ Object

A convenience method for creating an CustomInterestOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6253
6254
6255
6256
6257
6258
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6253

def self.custom_interest(path)
  require "google/ads/google_ads/v23/services/custom_interest_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomInterestOperation.new
  op["remove"] = path
  op
end

.customer(path) ⇒ Object

A convenience method for creating an CustomerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6011
6012
6013
6014
6015
6016
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6011

def self.customer(path)
  require "google/ads/google_ads/v23/services/customer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerOperation.new
  op["remove"] = path
  op
end

.customer_asset(path) ⇒ Object

A convenience method for creating an CustomerAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5956
5957
5958
5959
5960
5961
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5956

def self.customer_asset(path)
  require "google/ads/google_ads/v23/services/customer_asset_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerAssetOperation.new
  op["remove"] = path
  op
end

.customer_asset_set(path) ⇒ Object

A convenience method for creating an CustomerAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6264
6265
6266
6267
6268
6269
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6264

def self.customer_asset_set(path)
  require "google/ads/google_ads/v23/services/customer_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerAssetSetOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerClientLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6275
6276
6277
6278
6279
6280
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6275

def self.customer_client_link(path)
  require "google/ads/google_ads/v23/services/customer_client_link_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerClientLinkOperation.new
  op["remove"] = path
  op
end

.customer_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomerConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5967
5968
5969
5970
5971
5972
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5967

def self.customer_conversion_goal(path)
  require "google/ads/google_ads/v23/services/customer_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerConversionGoalOperation.new
  op["remove"] = path
  op
end

.customer_customizer(path) ⇒ Object

A convenience method for creating an CustomerCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5978
5979
5980
5981
5982
5983
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5978

def self.customer_customizer(path)
  require "google/ads/google_ads/v23/services/customer_customizer_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerCustomizerOperation.new
  op["remove"] = path
  op
end

.customer_label(path) ⇒ Object

A convenience method for creating an CustomerLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5989
5990
5991
5992
5993
5994
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5989

def self.customer_label(path)
  require "google/ads/google_ads/v23/services/customer_label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerLabelOperation.new
  op["remove"] = path
  op
end

.customer_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CustomerLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6286
6287
6288
6289
6290
6291
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6286

def self.customer_lifecycle_goal(path)
  require "google/ads/google_ads/v23/services/customer_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerLifecycleGoalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerManagerLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6297
6298
6299
6300
6301
6302
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6297

def self.customer_manager_link(path)
  require "google/ads/google_ads/v23/services/customer_manager_link_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerManagerLinkOperation.new
  op["remove"] = path
  op
end

.customer_negative_criterion(path) ⇒ Object

A convenience method for creating an CustomerNegativeCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6000
6001
6002
6003
6004
6005
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6000

def self.customer_negative_criterion(path)
  require "google/ads/google_ads/v23/services/customer_negative_criterion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerNegativeCriterionOperation.new
  op["remove"] = path
  op
end

.customer_sk_ad_network_conversion_value_schema(path) ⇒ Object

A convenience method for creating an CustomerSkAdNetworkConversionValueSchemaOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6308
6309
6310
6311
6312
6313
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6308

def self.customer_sk_ad_network_conversion_value_schema(path)
  require "google/ads/google_ads/v23/services/customer_sk_ad_network_conversion_value_schema_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerSkAdNetworkConversionValueSchemaOperation.new
  op["remove"] = path
  op
end

.customer_user_access(path) ⇒ Object

A convenience method for creating an CustomerUserAccessOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6330
6331
6332
6333
6334
6335
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6330

def self.customer_user_access(path)
  require "google/ads/google_ads/v23/services/customer_user_access_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerUserAccessOperation.new
  op["remove"] = path
  op
end

.customer_user_access_invitation(path) ⇒ Object

A convenience method for creating an CustomerUserAccessInvitationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6319
6320
6321
6322
6323
6324
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6319

def self.customer_user_access_invitation(path)
  require "google/ads/google_ads/v23/services/customer_user_access_invitation_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomerUserAccessInvitationOperation.new
  op["remove"] = path
  op
end

.customizer_attribute(path) ⇒ Object

A convenience method for creating an CustomizerAttributeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6022
6023
6024
6025
6026
6027
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6022

def self.customizer_attribute(path)
  require "google/ads/google_ads/v23/services/customizer_attribute_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::CustomizerAttributeOperation.new
  op["remove"] = path
  op
end

.dismiss_recommendation(path) ⇒ Object

A convenience method for creating an DismissRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6374
6375
6376
6377
6378
6379
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6374

def self.dismiss_recommendation(path)
  require "google/ads/google_ads/v23/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::DismissRecommendationRequest::DismissRecommendationOperation.new
  op["remove"] = path
  op
end

.enable(path) ⇒ Object

A convenience method for creating an EnableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5868
5869
5870
5871
5872
5873
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5868

def self.enable(path)
  require "google/ads/google_ads/v23/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::EnableOperation.new
  op["remove"] = path
  op
end

.experiment(path) ⇒ Object

A convenience method for creating an ExperimentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6044
6045
6046
6047
6048
6049
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6044

def self.experiment(path)
  require "google/ads/google_ads/v23/services/experiment_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ExperimentOperation.new
  op["remove"] = path
  op
end

.experiment_arm(path) ⇒ Object

A convenience method for creating an ExperimentArmOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6033
6034
6035
6036
6037
6038
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6033

def self.experiment_arm(path)
  require "google/ads/google_ads/v23/services/experiment_arm_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::ExperimentArmOperation.new
  op["remove"] = path
  op
end

.goal(path) ⇒ Object

A convenience method for creating an GoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6341
6342
6343
6344
6345
6346
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6341

def self.goal(path)
  require "google/ads/google_ads/v23/services/goal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::GoalOperation.new
  op["remove"] = path
  op
end

.keyword_plan(path) ⇒ Object

A convenience method for creating an KeywordPlanOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6099
6100
6101
6102
6103
6104
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6099

def self.keyword_plan(path)
  require "google/ads/google_ads/v23/services/keyword_plan_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6066
6067
6068
6069
6070
6071
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6066

def self.keyword_plan_ad_group(path)
  require "google/ads/google_ads/v23/services/keyword_plan_ad_group_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanAdGroupOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6055
6056
6057
6058
6059
6060
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6055

def self.keyword_plan_ad_group_keyword(path)
  require "google/ads/google_ads/v23/services/keyword_plan_ad_group_keyword_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanAdGroupKeywordOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6088
6089
6090
6091
6092
6093
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6088

def self.keyword_plan_campaign(path)
  require "google/ads/google_ads/v23/services/keyword_plan_campaign_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanCampaignOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6077
6078
6079
6080
6081
6082
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6077

def self.keyword_plan_campaign_keyword(path)
  require "google/ads/google_ads/v23/services/keyword_plan_campaign_keyword_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::KeywordPlanCampaignKeywordOperation.new
  op["remove"] = path
  op
end

.label(path) ⇒ Object

A convenience method for creating an LabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6110
6111
6112
6113
6114
6115
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6110

def self.label(path)
  require "google/ads/google_ads/v23/services/label_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::LabelOperation.new
  op["remove"] = path
  op
end

.mutate(path) ⇒ Object

A convenience method for creating an MutateOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6187
6188
6189
6190
6191
6192
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6187

def self.mutate(path)
  require "google/ads/google_ads/v23/services/google_ads_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::MutateOperation.new
  op["remove"] = path
  op
end

.offline_user_data_job(path) ⇒ Object

A convenience method for creating an OfflineUserDataJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6352
6353
6354
6355
6356
6357
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6352

def self.offline_user_data_job(path)
  require "google/ads/google_ads/v23/services/offline_user_data_job_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::OfflineUserDataJobOperation.new
  op["remove"] = path
  op
end

.recommendation_subscription(path) ⇒ Object

A convenience method for creating an RecommendationSubscriptionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6121
6122
6123
6124
6125
6126
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6121

def self.recommendation_subscription(path)
  require "google/ads/google_ads/v23/services/recommendation_subscription_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::RecommendationSubscriptionOperation.new
  op["remove"] = path
  op
end

.remarketing_action(path) ⇒ Object

A convenience method for creating an RemarketingActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6132
6133
6134
6135
6136
6137
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6132

def self.remarketing_action(path)
  require "google/ads/google_ads/v23/services/remarketing_action_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::RemarketingActionOperation.new
  op["remove"] = path
  op
end

.remove_campaign_automatically_created_asset(path) ⇒ Object

A convenience method for creating an RemoveCampaignAutomaticallyCreatedAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5703
5704
5705
5706
5707
5708
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5703

def self.remove_campaign_automatically_created_asset(path)
  require "google/ads/google_ads/v23/services/automatically_created_asset_removal_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::RemoveCampaignAutomaticallyCreatedAssetOperation.new
  op["remove"] = path
  op
end

.shared_criterion(path) ⇒ Object

A convenience method for creating an SharedCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6143
6144
6145
6146
6147
6148
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6143

def self.shared_criterion(path)
  require "google/ads/google_ads/v23/services/shared_criterion_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::SharedCriterionOperation.new
  op["remove"] = path
  op
end

.shared_set(path) ⇒ Object

A convenience method for creating an SharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6154
6155
6156
6157
6158
6159
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6154

def self.shared_set(path)
  require "google/ads/google_ads/v23/services/shared_set_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::SharedSetOperation.new
  op["remove"] = path
  op
end

.smart_campaign_setting(path) ⇒ Object

A convenience method for creating an SmartCampaignSettingOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6165
6166
6167
6168
6169
6170
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6165

def self.smart_campaign_setting(path)
  require "google/ads/google_ads/v23/services/smart_campaign_setting_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::SmartCampaignSettingOperation.new
  op["remove"] = path
  op
end

.target_restriction(path) ⇒ Object

A convenience method for creating an TargetRestrictionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5439
5440
5441
5442
5443
5444
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 5439

def self.target_restriction(path)
  require "google/ads/google_ads/v23/common/targeting_setting_pb"
  op = Google::Ads::GoogleAds::V23::Common::TargetRestrictionOperation.new
  op["remove"] = path
  op
end

.user_data(path) ⇒ Object

A convenience method for creating an UserDataOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6385
6386
6387
6388
6389
6390
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6385

def self.user_data(path)
  require "google/ads/google_ads/v23/services/user_data_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::UserDataOperation.new
  op["remove"] = path
  op
end

.user_list(path) ⇒ Object

A convenience method for creating an UserListOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6176
6177
6178
6179
6180
6181
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6176

def self.user_list(path)
  require "google/ads/google_ads/v23/services/user_list_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::UserListOperation.new
  op["remove"] = path
  op
end

.user_list_customer_type(path) ⇒ Object

A convenience method for creating an UserListCustomerTypeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6396
6397
6398
6399
6400
6401
# File 'lib/google/ads/google_ads/factories/v23/operations.rb', line 6396

def self.user_list_customer_type(path)
  require "google/ads/google_ads/v23/services/user_list_customer_type_service_pb"
  op = Google::Ads::GoogleAds::V23::Services::UserListCustomerTypeOperation.new
  op["remove"] = path
  op
end