Module: Google::Ads::GoogleAds::Factories::V24::Operations::RemoveResource

Defined in:
lib/google/ads/google_ads/factories/v24/operations.rb

Class Method Summary collapse

Class Method Details

.account_budget_proposal(path) ⇒ Object

A convenience method for creating an AccountBudgetProposalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5492
5493
5494
5495
5496
5497
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5492

def self.(path)
  require "google/ads/google_ads/v24/services/account_budget_proposal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AccountBudgetProposalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an AccountLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5503
5504
5505
5506
5507
5508
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5503

def self.(path)
  require "google/ads/google_ads/v24/services/account_link_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AccountLinkOperation.new
  op["remove"] = path
  op
end

.ad(path) ⇒ Object

A convenience method for creating an AdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5646
5647
5648
5649
5650
5651
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5646

def self.ad(path)
  require "google/ads/google_ads/v24/services/ad_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdOperation.new
  op["remove"] = path
  op
end

.ad_group(path) ⇒ Object

A convenience method for creating an AdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5624
5625
5626
5627
5628
5629
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5624

def self.ad_group(path)
  require "google/ads/google_ads/v24/services/ad_group_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupOperation.new
  op["remove"] = path
  op
end

.ad_group_ad(path) ⇒ Object

A convenience method for creating an AdGroupAdOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5525
5526
5527
5528
5529
5530
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5525

def self.ad_group_ad(path)
  require "google/ads/google_ads/v24/services/ad_group_ad_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupAdOperation.new
  op["remove"] = path
  op
end

.ad_group_ad_label(path) ⇒ Object

A convenience method for creating an AdGroupAdLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5514
5515
5516
5517
5518
5519
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5514

def self.ad_group_ad_label(path)
  require "google/ads/google_ads/v24/services/ad_group_ad_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupAdLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_asset(path) ⇒ Object

A convenience method for creating an AdGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5536
5537
5538
5539
5540
5541
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5536

def self.ad_group_asset(path)
  require "google/ads/google_ads/v24/services/ad_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupAssetOperation.new
  op["remove"] = path
  op
end

.ad_group_asset_set(path) ⇒ Object

A convenience method for creating an AdGroupAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5547
5548
5549
5550
5551
5552
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5547

def self.ad_group_asset_set(path)
  require "google/ads/google_ads/v24/services/ad_group_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupAssetSetOperation.new
  op["remove"] = path
  op
end

.ad_group_bid_modifier(path) ⇒ Object

A convenience method for creating an AdGroupBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5558
5559
5560
5561
5562
5563
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5558

def self.ad_group_bid_modifier(path)
  require "google/ads/google_ads/v24/services/ad_group_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupBidModifierOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion(path) ⇒ Object

A convenience method for creating an AdGroupCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5591
5592
5593
5594
5595
5596
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5591

def self.ad_group_criterion(path)
  require "google/ads/google_ads/v24/services/ad_group_criterion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupCriterionOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCriterionCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5569
5570
5571
5572
5573
5574
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5569

def self.ad_group_criterion_customizer(path)
  require "google/ads/google_ads/v24/services/ad_group_criterion_customizer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupCriterionCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_criterion_label(path) ⇒ Object

A convenience method for creating an AdGroupCriterionLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5580
5581
5582
5583
5584
5585
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5580

def self.ad_group_criterion_label(path)
  require "google/ads/google_ads/v24/services/ad_group_criterion_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupCriterionLabelOperation.new
  op["remove"] = path
  op
end

.ad_group_customizer(path) ⇒ Object

A convenience method for creating an AdGroupCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5602
5603
5604
5605
5606
5607
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5602

def self.ad_group_customizer(path)
  require "google/ads/google_ads/v24/services/ad_group_customizer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupCustomizerOperation.new
  op["remove"] = path
  op
end

.ad_group_label(path) ⇒ Object

A convenience method for creating an AdGroupLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5613
5614
5615
5616
5617
5618
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5613

def self.ad_group_label(path)
  require "google/ads/google_ads/v24/services/ad_group_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdGroupLabelOperation.new
  op["remove"] = path
  op
end

.ad_parameter(path) ⇒ Object

A convenience method for creating an AdParameterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5635
5636
5637
5638
5639
5640
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5635

def self.ad_parameter(path)
  require "google/ads/google_ads/v24/services/ad_parameter_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AdParameterOperation.new
  op["remove"] = path
  op
end

.apply_recommendation(path) ⇒ Object

A convenience method for creating an ApplyRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6427
6428
6429
6430
6431
6432
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6427

def self.apply_recommendation(path)
  require "google/ads/google_ads/v24/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ApplyRecommendationOperation.new
  op["remove"] = path
  op
end

.asset(path) ⇒ Object

A convenience method for creating an AssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5701
5702
5703
5704
5705
5706
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5701

def self.asset(path)
  require "google/ads/google_ads/v24/services/asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetOperation.new
  op["remove"] = path
  op
end

.asset_group(path) ⇒ Object

A convenience method for creating an AssetGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5679
5680
5681
5682
5683
5684
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5679

def self.asset_group(path)
  require "google/ads/google_ads/v24/services/asset_group_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetGroupOperation.new
  op["remove"] = path
  op
end

.asset_group_asset(path) ⇒ Object

A convenience method for creating an AssetGroupAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5657
5658
5659
5660
5661
5662
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5657

def self.asset_group_asset(path)
  require "google/ads/google_ads/v24/services/asset_group_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetGroupAssetOperation.new
  op["remove"] = path
  op
end

.asset_group_listing_group_filter(path) ⇒ Object

A convenience method for creating an AssetGroupListingGroupFilterOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5668
5669
5670
5671
5672
5673
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5668

def self.asset_group_listing_group_filter(path)
  require "google/ads/google_ads/v24/services/asset_group_listing_group_filter_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetGroupListingGroupFilterOperation.new
  op["remove"] = path
  op
end

.asset_group_signal(path) ⇒ Object

A convenience method for creating an AssetGroupSignalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5690
5691
5692
5693
5694
5695
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5690

def self.asset_group_signal(path)
  require "google/ads/google_ads/v24/services/asset_group_signal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetGroupSignalOperation.new
  op["remove"] = path
  op
end

.asset_set(path) ⇒ Object

A convenience method for creating an AssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5723
5724
5725
5726
5727
5728
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5723

def self.asset_set(path)
  require "google/ads/google_ads/v24/services/asset_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetSetOperation.new
  op["remove"] = path
  op
end

.asset_set_asset(path) ⇒ Object

A convenience method for creating an AssetSetAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5712
5713
5714
5715
5716
5717
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5712

def self.asset_set_asset(path)
  require "google/ads/google_ads/v24/services/asset_set_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AssetSetAssetOperation.new
  op["remove"] = path
  op
end

.audience(path) ⇒ Object

A convenience method for creating an AudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5734
5735
5736
5737
5738
5739
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5734

def self.audience(path)
  require "google/ads/google_ads/v24/services/audience_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::AudienceOperation.new
  op["remove"] = path
  op
end

.batch_job(path) ⇒ Object

A convenience method for creating an BatchJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6262
6263
6264
6265
6266
6267
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6262

def self.batch_job(path)
  require "google/ads/google_ads/v24/services/batch_job_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BatchJobOperation.new
  op["remove"] = path
  op
end

.bidding_data_exclusion(path) ⇒ Object

A convenience method for creating an BiddingDataExclusionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5778
5779
5780
5781
5782
5783
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5778

def self.bidding_data_exclusion(path)
  require "google/ads/google_ads/v24/services/bidding_data_exclusion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BiddingDataExclusionOperation.new
  op["remove"] = path
  op
end

.bidding_seasonality_adjustment(path) ⇒ Object

A convenience method for creating an BiddingSeasonalityAdjustmentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5789
5790
5791
5792
5793
5794
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5789

def self.bidding_seasonality_adjustment(path)
  require "google/ads/google_ads/v24/services/bidding_seasonality_adjustment_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BiddingSeasonalityAdjustmentOperation.new
  op["remove"] = path
  op
end

.bidding_strategy(path) ⇒ Object

A convenience method for creating an BiddingStrategyOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5800
5801
5802
5803
5804
5805
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5800

def self.bidding_strategy(path)
  require "google/ads/google_ads/v24/services/bidding_strategy_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BiddingStrategyOperation.new
  op["remove"] = path
  op
end

.billing_setup(path) ⇒ Object

A convenience method for creating an BillingSetupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6273
6274
6275
6276
6277
6278
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6273

def self.billing_setup(path)
  require "google/ads/google_ads/v24/services/billing_setup_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::BillingSetupOperation.new
  op["remove"] = path
  op
end

.book_campaigns(path) ⇒ Object

A convenience method for creating an BookCampaignsOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5756
5757
5758
5759
5760
5761
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5756

def self.book_campaigns(path)
  require "google/ads/google_ads/v24/actions/book_campaigns_pb"
  op = Google::Ads::GoogleAds::V24::Actions::BookCampaignsOperation.new
  op["remove"] = path
  op
end

.campaign(path) ⇒ Object

A convenience method for creating an CampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5921
5922
5923
5924
5925
5926
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5921

def self.campaign(path)
  require "google/ads/google_ads/v24/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignOperation.new
  op["remove"] = path
  op
end

.campaign_asset(path) ⇒ Object

A convenience method for creating an CampaignAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5811
5812
5813
5814
5815
5816
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5811

def self.campaign_asset(path)
  require "google/ads/google_ads/v24/services/campaign_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignAssetOperation.new
  op["remove"] = path
  op
end

.campaign_asset_set(path) ⇒ Object

A convenience method for creating an CampaignAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5822
5823
5824
5825
5826
5827
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5822

def self.campaign_asset_set(path)
  require "google/ads/google_ads/v24/services/campaign_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignAssetSetOperation.new
  op["remove"] = path
  op
end

.campaign_bid_modifier(path) ⇒ Object

A convenience method for creating an CampaignBidModifierOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5833
5834
5835
5836
5837
5838
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5833

def self.campaign_bid_modifier(path)
  require "google/ads/google_ads/v24/services/campaign_bid_modifier_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignBidModifierOperation.new
  op["remove"] = path
  op
end

.campaign_budget(path) ⇒ Object

A convenience method for creating an CampaignBudgetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5844
5845
5846
5847
5848
5849
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5844

def self.campaign_budget(path)
  require "google/ads/google_ads/v24/services/campaign_budget_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignBudgetOperation.new
  op["remove"] = path
  op
end

.campaign_conversion_goal(path) ⇒ Object

A convenience method for creating an CampaignConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5855
5856
5857
5858
5859
5860
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5855

def self.campaign_conversion_goal(path)
  require "google/ads/google_ads/v24/services/campaign_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignConversionGoalOperation.new
  op["remove"] = path
  op
end

.campaign_criterion(path) ⇒ Object

A convenience method for creating an CampaignCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5866
5867
5868
5869
5870
5871
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5866

def self.campaign_criterion(path)
  require "google/ads/google_ads/v24/services/campaign_criterion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignCriterionOperation.new
  op["remove"] = path
  op
end

.campaign_customizer(path) ⇒ Object

A convenience method for creating an CampaignCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5877
5878
5879
5880
5881
5882
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5877

def self.campaign_customizer(path)
  require "google/ads/google_ads/v24/services/campaign_customizer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignCustomizerOperation.new
  op["remove"] = path
  op
end

.campaign_draft(path) ⇒ Object

A convenience method for creating an CampaignDraftOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5888
5889
5890
5891
5892
5893
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5888

def self.campaign_draft(path)
  require "google/ads/google_ads/v24/services/campaign_draft_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignDraftOperation.new
  op["remove"] = path
  op
end

.campaign_goal_config(path) ⇒ Object

A convenience method for creating an CampaignGoalConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6284
6285
6286
6287
6288
6289
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6284

def self.campaign_goal_config(path)
  require "google/ads/google_ads/v24/services/campaign_goal_config_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignGoalConfigOperation.new
  op["remove"] = path
  op
end

.campaign_group(path) ⇒ Object

A convenience method for creating an CampaignGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5899
5900
5901
5902
5903
5904
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5899

def self.campaign_group(path)
  require "google/ads/google_ads/v24/services/campaign_group_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignGroupOperation.new
  op["remove"] = path
  op
end

.campaign_label(path) ⇒ Object

A convenience method for creating an CampaignLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5910
5911
5912
5913
5914
5915
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5910

def self.campaign_label(path)
  require "google/ads/google_ads/v24/services/campaign_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignLabelOperation.new
  op["remove"] = path
  op
end

.campaign_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CampaignLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6295
6296
6297
6298
6299
6300
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6295

def self.campaign_lifecycle_goal(path)
  require "google/ads/google_ads/v24/services/campaign_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignLifecycleGoalOperation.new
  op["remove"] = path
  op
end

.campaign_shared_set(path) ⇒ Object

A convenience method for creating an CampaignSharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5943
5944
5945
5946
5947
5948
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5943

def self.campaign_shared_set(path)
  require "google/ads/google_ads/v24/services/campaign_shared_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CampaignSharedSetOperation.new
  op["remove"] = path
  op
end

.conversion_action(path) ⇒ Object

A convenience method for creating an ConversionActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5954
5955
5956
5957
5958
5959
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5954

def self.conversion_action(path)
  require "google/ads/google_ads/v24/services/conversion_action_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionActionOperation.new
  op["remove"] = path
  op
end

.conversion_custom_variable(path) ⇒ Object

A convenience method for creating an ConversionCustomVariableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5965
5966
5967
5968
5969
5970
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5965

def self.conversion_custom_variable(path)
  require "google/ads/google_ads/v24/services/conversion_custom_variable_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionCustomVariableOperation.new
  op["remove"] = path
  op
end

.conversion_goal_campaign_config(path) ⇒ Object

A convenience method for creating an ConversionGoalCampaignConfigOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5976
5977
5978
5979
5980
5981
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5976

def self.conversion_goal_campaign_config(path)
  require "google/ads/google_ads/v24/services/conversion_goal_campaign_config_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionGoalCampaignConfigOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule(path) ⇒ Object

A convenience method for creating an ConversionValueRuleOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5987
5988
5989
5990
5991
5992
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5987

def self.conversion_value_rule(path)
  require "google/ads/google_ads/v24/services/conversion_value_rule_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionValueRuleOperation.new
  op["remove"] = path
  op
end

.conversion_value_rule_set(path) ⇒ Object

A convenience method for creating an ConversionValueRuleSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5998
5999
6000
6001
6002
6003
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5998

def self.conversion_value_rule_set(path)
  require "google/ads/google_ads/v24/services/conversion_value_rule_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ConversionValueRuleSetOperation.new
  op["remove"] = path
  op
end

.custom_audience(path) ⇒ Object

A convenience method for creating an CustomAudienceOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6306
6307
6308
6309
6310
6311
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6306

def self.custom_audience(path)
  require "google/ads/google_ads/v24/services/custom_audience_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomAudienceOperation.new
  op["remove"] = path
  op
end

.custom_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6009
6010
6011
6012
6013
6014
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6009

def self.custom_conversion_goal(path)
  require "google/ads/google_ads/v24/services/custom_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomConversionGoalOperation.new
  op["remove"] = path
  op
end

.custom_interest(path) ⇒ Object

A convenience method for creating an CustomInterestOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6317
6318
6319
6320
6321
6322
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6317

def self.custom_interest(path)
  require "google/ads/google_ads/v24/services/custom_interest_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomInterestOperation.new
  op["remove"] = path
  op
end

.customer(path) ⇒ Object

A convenience method for creating an CustomerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6075
6076
6077
6078
6079
6080
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6075

def self.customer(path)
  require "google/ads/google_ads/v24/services/customer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerOperation.new
  op["remove"] = path
  op
end

.customer_asset(path) ⇒ Object

A convenience method for creating an CustomerAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6020
6021
6022
6023
6024
6025
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6020

def self.customer_asset(path)
  require "google/ads/google_ads/v24/services/customer_asset_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerAssetOperation.new
  op["remove"] = path
  op
end

.customer_asset_set(path) ⇒ Object

A convenience method for creating an CustomerAssetSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6328
6329
6330
6331
6332
6333
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6328

def self.customer_asset_set(path)
  require "google/ads/google_ads/v24/services/customer_asset_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerAssetSetOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerClientLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6339
6340
6341
6342
6343
6344
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6339

def self.customer_client_link(path)
  require "google/ads/google_ads/v24/services/customer_client_link_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerClientLinkOperation.new
  op["remove"] = path
  op
end

.customer_conversion_goal(path) ⇒ Object

A convenience method for creating an CustomerConversionGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6031
6032
6033
6034
6035
6036
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6031

def self.customer_conversion_goal(path)
  require "google/ads/google_ads/v24/services/customer_conversion_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerConversionGoalOperation.new
  op["remove"] = path
  op
end

.customer_customizer(path) ⇒ Object

A convenience method for creating an CustomerCustomizerOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6042
6043
6044
6045
6046
6047
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6042

def self.customer_customizer(path)
  require "google/ads/google_ads/v24/services/customer_customizer_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerCustomizerOperation.new
  op["remove"] = path
  op
end

.customer_label(path) ⇒ Object

A convenience method for creating an CustomerLabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6053
6054
6055
6056
6057
6058
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6053

def self.customer_label(path)
  require "google/ads/google_ads/v24/services/customer_label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerLabelOperation.new
  op["remove"] = path
  op
end

.customer_lifecycle_goal(path) ⇒ Object

A convenience method for creating an CustomerLifecycleGoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6350
6351
6352
6353
6354
6355
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6350

def self.customer_lifecycle_goal(path)
  require "google/ads/google_ads/v24/services/customer_lifecycle_goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerLifecycleGoalOperation.new
  op["remove"] = path
  op
end

A convenience method for creating an CustomerManagerLinkOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6361
6362
6363
6364
6365
6366
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6361

def self.customer_manager_link(path)
  require "google/ads/google_ads/v24/services/customer_manager_link_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerManagerLinkOperation.new
  op["remove"] = path
  op
end

.customer_negative_criterion(path) ⇒ Object

A convenience method for creating an CustomerNegativeCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6064
6065
6066
6067
6068
6069
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6064

def self.customer_negative_criterion(path)
  require "google/ads/google_ads/v24/services/customer_negative_criterion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerNegativeCriterionOperation.new
  op["remove"] = path
  op
end

.customer_sk_ad_network_conversion_value_schema(path) ⇒ Object

A convenience method for creating an CustomerSkAdNetworkConversionValueSchemaOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6372
6373
6374
6375
6376
6377
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6372

def self.customer_sk_ad_network_conversion_value_schema(path)
  require "google/ads/google_ads/v24/services/customer_sk_ad_network_conversion_value_schema_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerSkAdNetworkConversionValueSchemaOperation.new
  op["remove"] = path
  op
end

.customer_user_access(path) ⇒ Object

A convenience method for creating an CustomerUserAccessOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6394
6395
6396
6397
6398
6399
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6394

def self.customer_user_access(path)
  require "google/ads/google_ads/v24/services/customer_user_access_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerUserAccessOperation.new
  op["remove"] = path
  op
end

.customer_user_access_invitation(path) ⇒ Object

A convenience method for creating an CustomerUserAccessInvitationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6383
6384
6385
6386
6387
6388
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6383

def self.customer_user_access_invitation(path)
  require "google/ads/google_ads/v24/services/customer_user_access_invitation_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomerUserAccessInvitationOperation.new
  op["remove"] = path
  op
end

.customizer_attribute(path) ⇒ Object

A convenience method for creating an CustomizerAttributeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6086
6087
6088
6089
6090
6091
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6086

def self.customizer_attribute(path)
  require "google/ads/google_ads/v24/services/customizer_attribute_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::CustomizerAttributeOperation.new
  op["remove"] = path
  op
end

.dismiss_recommendation(path) ⇒ Object

A convenience method for creating an DismissRecommendationOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6438
6439
6440
6441
6442
6443
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6438

def self.dismiss_recommendation(path)
  require "google/ads/google_ads/v24/services/recommendation_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::DismissRecommendationRequest::DismissRecommendationOperation.new
  op["remove"] = path
  op
end

.enable(path) ⇒ Object

A convenience method for creating an EnableOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5932
5933
5934
5935
5936
5937
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5932

def self.enable(path)
  require "google/ads/google_ads/v24/services/campaign_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::EnableOperation.new
  op["remove"] = path
  op
end

.experiment(path) ⇒ Object

A convenience method for creating an ExperimentOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6108
6109
6110
6111
6112
6113
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6108

def self.experiment(path)
  require "google/ads/google_ads/v24/services/experiment_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ExperimentOperation.new
  op["remove"] = path
  op
end

.experiment_arm(path) ⇒ Object

A convenience method for creating an ExperimentArmOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6097
6098
6099
6100
6101
6102
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6097

def self.experiment_arm(path)
  require "google/ads/google_ads/v24/services/experiment_arm_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::ExperimentArmOperation.new
  op["remove"] = path
  op
end

.generate_shareable_previews(path) ⇒ Object

A convenience method for creating an GenerateShareablePreviewsOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6449
6450
6451
6452
6453
6454
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6449

def self.generate_shareable_previews(path)
  require "google/ads/google_ads/v24/actions/generate_shareable_previews_pb"
  op = Google::Ads::GoogleAds::V24::Actions::GenerateShareablePreviewsOperation.new
  op["remove"] = path
  op
end

.goal(path) ⇒ Object

A convenience method for creating an GoalOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6405
6406
6407
6408
6409
6410
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6405

def self.goal(path)
  require "google/ads/google_ads/v24/services/goal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::GoalOperation.new
  op["remove"] = path
  op
end

.keyword_plan(path) ⇒ Object

A convenience method for creating an KeywordPlanOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6163
6164
6165
6166
6167
6168
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6163

def self.keyword_plan(path)
  require "google/ads/google_ads/v24/services/keyword_plan_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6130
6131
6132
6133
6134
6135
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6130

def self.keyword_plan_ad_group(path)
  require "google/ads/google_ads/v24/services/keyword_plan_ad_group_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanAdGroupOperation.new
  op["remove"] = path
  op
end

.keyword_plan_ad_group_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanAdGroupKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6119
6120
6121
6122
6123
6124
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6119

def self.keyword_plan_ad_group_keyword(path)
  require "google/ads/google_ads/v24/services/keyword_plan_ad_group_keyword_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanAdGroupKeywordOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6152
6153
6154
6155
6156
6157
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6152

def self.keyword_plan_campaign(path)
  require "google/ads/google_ads/v24/services/keyword_plan_campaign_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanCampaignOperation.new
  op["remove"] = path
  op
end

.keyword_plan_campaign_keyword(path) ⇒ Object

A convenience method for creating an KeywordPlanCampaignKeywordOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6141
6142
6143
6144
6145
6146
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6141

def self.keyword_plan_campaign_keyword(path)
  require "google/ads/google_ads/v24/services/keyword_plan_campaign_keyword_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::KeywordPlanCampaignKeywordOperation.new
  op["remove"] = path
  op
end

.label(path) ⇒ Object

A convenience method for creating an LabelOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6174
6175
6176
6177
6178
6179
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6174

def self.label(path)
  require "google/ads/google_ads/v24/services/label_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::LabelOperation.new
  op["remove"] = path
  op
end

.mutate(path) ⇒ Object

A convenience method for creating an MutateOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6251
6252
6253
6254
6255
6256
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6251

def self.mutate(path)
  require "google/ads/google_ads/v24/services/google_ads_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::MutateOperation.new
  op["remove"] = path
  op
end

.offline_user_data_job(path) ⇒ Object

A convenience method for creating an OfflineUserDataJobOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6416
6417
6418
6419
6420
6421
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6416

def self.offline_user_data_job(path)
  require "google/ads/google_ads/v24/services/offline_user_data_job_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::OfflineUserDataJobOperation.new
  op["remove"] = path
  op
end

.quote_campaigns(path) ⇒ Object

A convenience method for creating an QuoteCampaignsOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5767
5768
5769
5770
5771
5772
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5767

def self.quote_campaigns(path)
  require "google/ads/google_ads/v24/actions/quote_campaigns_pb"
  op = Google::Ads::GoogleAds::V24::Actions::QuoteCampaignsOperation.new
  op["remove"] = path
  op
end

.recommendation_subscription(path) ⇒ Object

A convenience method for creating an RecommendationSubscriptionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6185
6186
6187
6188
6189
6190
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6185

def self.recommendation_subscription(path)
  require "google/ads/google_ads/v24/services/recommendation_subscription_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::RecommendationSubscriptionOperation.new
  op["remove"] = path
  op
end

.remarketing_action(path) ⇒ Object

A convenience method for creating an RemarketingActionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6196
6197
6198
6199
6200
6201
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6196

def self.remarketing_action(path)
  require "google/ads/google_ads/v24/services/remarketing_action_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::RemarketingActionOperation.new
  op["remove"] = path
  op
end

.remove_campaign_automatically_created_asset(path) ⇒ Object

A convenience method for creating an RemoveCampaignAutomaticallyCreatedAssetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5745
5746
5747
5748
5749
5750
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5745

def self.remove_campaign_automatically_created_asset(path)
  require "google/ads/google_ads/v24/services/automatically_created_asset_removal_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::RemoveCampaignAutomaticallyCreatedAssetOperation.new
  op["remove"] = path
  op
end

.shared_criterion(path) ⇒ Object

A convenience method for creating an SharedCriterionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6207
6208
6209
6210
6211
6212
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6207

def self.shared_criterion(path)
  require "google/ads/google_ads/v24/services/shared_criterion_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::SharedCriterionOperation.new
  op["remove"] = path
  op
end

.shared_set(path) ⇒ Object

A convenience method for creating an SharedSetOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6218
6219
6220
6221
6222
6223
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6218

def self.shared_set(path)
  require "google/ads/google_ads/v24/services/shared_set_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::SharedSetOperation.new
  op["remove"] = path
  op
end

.smart_campaign_setting(path) ⇒ Object

A convenience method for creating an SmartCampaignSettingOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6229
6230
6231
6232
6233
6234
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6229

def self.smart_campaign_setting(path)
  require "google/ads/google_ads/v24/services/smart_campaign_setting_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::SmartCampaignSettingOperation.new
  op["remove"] = path
  op
end

.target_restriction(path) ⇒ Object

A convenience method for creating an TargetRestrictionOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



5481
5482
5483
5484
5485
5486
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 5481

def self.target_restriction(path)
  require "google/ads/google_ads/v24/common/targeting_setting_pb"
  op = Google::Ads::GoogleAds::V24::Common::TargetRestrictionOperation.new
  op["remove"] = path
  op
end

.user_data(path) ⇒ Object

A convenience method for creating an UserDataOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6460
6461
6462
6463
6464
6465
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6460

def self.user_data(path)
  require "google/ads/google_ads/v24/services/user_data_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::UserDataOperation.new
  op["remove"] = path
  op
end

.user_list(path) ⇒ Object

A convenience method for creating an UserListOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6240
6241
6242
6243
6244
6245
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6240

def self.user_list(path)
  require "google/ads/google_ads/v24/services/user_list_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::UserListOperation.new
  op["remove"] = path
  op
end

.user_list_customer_type(path) ⇒ Object

A convenience method for creating an UserListCustomerTypeOperation instance with its “remove” field preopulated with a resource path corresponding to the resource to be removed.

Parameters:

  • path (String)

    the resource name of the resource to delete.



6471
6472
6473
6474
6475
6476
# File 'lib/google/ads/google_ads/factories/v24/operations.rb', line 6471

def self.user_list_customer_type(path)
  require "google/ads/google_ads/v24/services/user_list_customer_type_service_pb"
  op = Google::Ads::GoogleAds::V24::Services::UserListCustomerTypeOperation.new
  op["remove"] = path
  op
end